#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Represents a color from Farrow & Ball, a British manufacturer of paints and wallpapers.

Farrow & Ball specializes in historic color palettes and archives, offering a wide range
of unique colors and finishes. The company is particularly renowned for the distinctive
names of its products, which often reflect their heritage and artistic inspiration.
"""
import typing

from borb.pdf.color.color import Color
from borb.pdf.color.hex_color import HexColor


class FarrowAndBallColor:
    """
    Represents a color from Farrow & Ball, a British manufacturer of paints and wallpapers.

    Farrow & Ball specializes in historic color palettes and archives, offering a wide range
    of unique colors and finishes. The company is particularly renowned for the distinctive
    names of its products, which often reflect their heritage and artistic inspiration.
    """

    #
    # CONSTRUCTOR
    #

    #
    # PRIVATE
    #

    #
    # PUBLIC
    #

    ALL_WHITE = HexColor("#faf9ef")
    ARCHIVE = HexColor("#decbb3")
    ARSENIC = HexColor("#88b49b")

    BABOUCE = HexColor("#eabe67")
    BALLROOM_BLUE = HexColor("#8faba7")
    BALL_GREEN = HexColor("#bab393")
    BERRINGTON_BLUE = HexColor("#7e9495")
    BISCUIT = HexColor("#bca783")
    BLACKENED = HexColor("#dfdfdb")
    BLACK_BLUE = HexColor("#3d4345")
    BLAZER = HexColor("#ac514c")
    BLUE_GRAY = HexColor("#b5b7a7")
    BLUE_GROUND = HexColor("#a7c9c8")
    BONE = HexColor("#cdc4ae")
    BOOK_ROOM_RED = HexColor("#a3695b")
    BORROWED_LIGHT = HexColor("#d8dfdc")
    BREAKFAST_ROOM_GREEN = HexColor("#94a588")
    BRINJAL = HexColor("#5a4348")
    BUFF = HexColor("#b59e82")

    CAGGIAGE_GREEN = HexColor("#434c47")
    CALAMINE = HexColor("#e8d6d1")
    CALKE_GREEN = HexColor("#77866a")
    CANE = HexColor("#caa26c")
    CARD_ROOM_GREEN = HexColor("#899081")
    CASTLE_GRAY = HexColor("#8d988c")
    CHAPPELL_GREEN = HexColor("#93a595")
    CHINESE_BLUE = HexColor("#6f96a6")
    CIARA_YELLOW = HexColor("#e1c17e")
    CITRON = HexColor("#eecc81")
    CLUNCH = HexColor("#e5dcc8")
    COOKING_APPLE_GREEN = HexColor("#c4c3a2")
    COOKS_BLUE = HexColor("#6f94b3")
    CORD = HexColor("#d6c39f")
    CORNFORTH_WHITE = HexColor("#d4cfc7")
    CREAM = HexColor("#e3cea7")

    DAUPHIN = HexColor("#928069")
    DAYROOM_YELLOW = HexColor("#f2dc9e")
    DEAD_SALMON = HexColor("#b09b8c")
    DIMITY = HexColor("#ece2d2")
    DIX_BLUE = HexColor("#9ab1ab")
    DORSET_CREAM = HexColor("#eacfa2")
    DOWN_PIPE = HexColor("#626665")
    DRAB = HexColor("#9b8a6f")
    DUTCH_PINK = HexColor("#d5b08a")

    EATING_ROOM_RED = HexColor("#864e4f")
    ELEPHANTS_BREATH = HexColor("#cdc3b7")
    ENTRANCE_HALL_PINK = HexColor("#c39e80")
    ETRUSCAN_RED = HexColor("#7e534a")

    FARROWS_CREAM = HexColor("#e8d4b0")
    FAWN = HexColor("#ccbfa5")
    FLOWER_PINK = HexColor("#d6a787")
    FOLLY_GREEN = HexColor("#95aa86")
    FOX_RED = HexColor("#a8725d")
    FRENCH_GRAY = HexColor("#b4b19a")

    GERVASE_YELLOW = HexColor("#dcc98f")
    GREAT_WHITE = HexColor("#e6e1dc")
    GREEN_BLUE = HexColor("#aebdb1")
    GREEN_GROUND = HexColor("#dbd8b6")
    GREEN_SMOKE = HexColor("#717b70")
    GREEN_STONE = HexColor("#a59c78")

    HAGUE_BLUE = HexColor("#3e4e56")
    HARDWICK_WHITE = HexColor("#b6b1a1")
    HAY = HexColor("#d8c194")
    HOUND_LEMON = HexColor("#e2d2a4")
    HOUSE_WHITE = HexColor("#f2e7c9")

    INDIA_YELLOW = HexColor("#c09759")

    JAMES_WHITE = HexColor("#ece9d7")
    JOAS_WHITE = HexColor("#e2d4be")

    LAMP_ROOM_GRAY = HexColor("#b7b6ae")
    LICHEN = HexColor("#9e9f87")
    LIGHT_BLUE = HexColor("#b9beb5")
    LIGHT_GRAY = HexColor("#b2a894")
    LIGHT_STONE = HexColor("#d1c1a0")
    LIME_WHITE = HexColor("#e9dfc9")
    LOGGIA = HexColor("#aa6d5b")
    LONDON_STONE = HexColor("#b2a18d")
    LULWORTH_BLUE = HexColor("#a2b8c7")

    MAHOGANY = HexColor("#524947")
    MATCHSTICK = HexColor("#e6d8be")
    MINSTER_GREEN = HexColor("#586552")
    MONKEY_PUZZLE = HexColor("#4b5853")
    MOUSES_BACK = HexColor("#968975")

    NEW_WHITE = HexColor("#f4e9d0")

    OCTAGON_YELLOW = HexColor("#d1ae72")
    OFF_BLACK = HexColor("#424548")
    OFF_WHITE = HexColor("#e0d6c0")
    OINTMENT_PINK = HexColor("#c7997e")
    OLD_WHITE = HexColor("#cdc3ad")
    OLIVE = HexColor("#8b896b")
    ORANGERY = HexColor("#e0ae6c")
    OVAL_ROOM_BLUE = HexColor("#8b9d9b")

    PALE_HOUND = HexColor("#e6ddb8")
    PALE_POWDER = HexColor("#dde1d5")
    PARMA_GRAY = HexColor("#b1c0c2")
    PEA_GREEN = HexColor("#849779")
    PICTURE_GALLERY_RED = HexColor("#975b4f")
    PIGEON = HexColor("#9fa195")
    PINK_GROUND = HexColor("#ecd8ca")
    PITCH_BLUE = HexColor("#61718e")
    POINTING = HexColor("#f9f3e3")
    PORPHYRY_PINK = HexColor("#b17b6c")
    POWDER_BLUE = HexColor("#acbdb4")
    PRINT_ROOM_YELLOW = HexColor("#dbb678")

    RADIOCCHIO = HexColor("#8f4a51")
    RAILINGS = HexColor("#43474a")
    RECTORY_RED = HexColor("#99434c")
    RED_EARTH = HexColor("#bb7b69")
    RINGWORLD_GROUND = HexColor("#efe0c5")

    SAND = HexColor("#ba9166")
    SAVAGE_GROUND = HexColor("#d7c5a9")
    SAXON_GREEN = HexColor("#99a680")
    SETTING_PLASTER = HexColor("#dbc2b0")
    SHADED_WHITE = HexColor("#dad4c2")
    SKYLIGHT = HexColor("#c6ccc7")
    SLIPPER_SATIN = HexColor("#eae4d3")
    SMOKED_TROUT = HexColor("#bea895")
    STONE_BLUE = HexColor("#77989f")
    STONE_WHITE = HexColor("#b3ac8c")
    STONY_GROUND = HexColor("#cdc2ad")
    STRAW = HexColor("#d7b37e")
    STRING = HexColor("#dcceb0")
    STRONG_WHITE = HexColor("#e9e7dd")
    STUDIO_GREEN = HexColor("#474d4a")
    SUDBURY_YELLOW = HexColor("#d9b475")
    SUGAR_BAG_LIGHT = HexColor("#81a09a")
    SUTCLIFFE_GREEN = HexColor("#899677")

    TALLOW = HexColor("#f5ead2")
    TERESAS_GREEN = HexColor("#c2cfc2")

    VERT_DE_TERRE = HexColor("#babca4")

    WAINSCOT = HexColor("#7e634e")
    WHITE_TIE = HexColor("#f2ead6")

    YELLOW_GROUND = HexColor("#efca89")

    @staticmethod
    def get_matching_color(color: Color) -> typing.Tuple[str, Color]:
        """
        Find the closest Farrow & Ball color that visually matches the given color.

        This method takes an input `Color` object and determines the closest
        `FarrowAndBallColor` based on visual similarity. It returns a tuple
        containing the name of the closest matching Farrow & Ball color and
        the corresponding `FarrowAndBallColor` object.

        :param color: The Color object to match.
        :return: A tuple containing the name of the closest
                 Farrow & Ball color and the corresponding
                 FarrowAndBallColor object.
        """
        from borb.pdf.color.rgb_color import RGBColor

        rgb_color_0: RGBColor = color.to_rgb_color()
        min_distance: typing.Optional[int] = None
        min_color_name: typing.Optional[str] = None
        min_color: typing.Optional[Color] = None
        for name in dir(FarrowAndBallColor):
            try:
                rgb_color_1: RGBColor = getattr(FarrowAndBallColor, name)
                distance = (
                    (rgb_color_0.get_red() - rgb_color_1.get_red()) ** 2
                    + (rgb_color_0.get_green() - rgb_color_1.get_green()) ** 2
                    + (rgb_color_0.get_blue() - rgb_color_1.get_blue()) ** 2
                )
                if min_distance is None or distance < min_distance:
                    min_distance = distance
                    min_color_name = name
                    min_color = rgb_color_1
            except:
                pass
        # fmt: off
        assert min_color_name is not None, "No matching color name was found; min_color_name is None."
        assert min_color is not None, "No matching color object was found; min_color is None."
        # fmt: on
        return min_color_name, min_color
