#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Represents a color defined by the Pantone Matching System (PMS).

Pantone LLC, headquartered in Carlstadt, New Jersey, is renowned for its
proprietary Pantone Matching System (PMS), a standardized color space used
across various industries, including graphic design, fashion design, product
design, printing, and manufacturing. The PMS facilitates effective color
management from design to production in both physical and digital formats,
accommodating a range of materials such as coated and uncoated papers,
cotton, polyester, nylon, and plastics.
"""
import typing

from borb.pdf.color.color import Color
from borb.pdf.color.hex_color import HexColor


class PantoneColor:
    """
    Represents a color defined by the Pantone Matching System (PMS).

    Pantone LLC, headquartered in Carlstadt, New Jersey, is renowned for its
    proprietary Pantone Matching System (PMS), a standardized color space used
    across various industries, including graphic design, fashion design, product
    design, printing, and manufacturing. The PMS facilitates effective color
    management from design to production in both physical and digital formats,
    accommodating a range of materials such as coated and uncoated papers,
    cotton, polyester, nylon, and plastics.
    """

    #
    # CONSTRUCTOR
    #

    #
    # PRIVATE
    #

    #
    # PUBLIC
    #

    ABBEY_STONE = HexColor("#ABA798")
    ABSINTHE_GREEN = HexColor("#76B583")
    ABYSS = HexColor("#8F9E9D")
    ACACIA = HexColor("#DACD65")
    ACAI = HexColor("#46295A")
    ACID_LIME = HexColor("#BADF30")
    ACORN = HexColor("#7E5E52")
    ADOBE = HexColor("#A3623B")
    ADOBE_ROSE = HexColor("#BA9F99")
    ADRIATIC_BLUE = HexColor("#5C899B")
    AEGEAN_BLUE = HexColor("#4E6E81")
    AFRICAN_VIOLET = HexColor("#B085B7")
    AFTER_DARK = HexColor("#3C3535")
    AFTERGLOW = HexColor("#F3E6C9")
    AGATE_GRAY = HexColor("#B1B09F")
    AGATE_GREEN = HexColor("#599F99")
    AGAVE_GREEN = HexColor("#6B7169")
    AIR_BLUE = HexColor("#77ACC7")
    AIRY_BLUE = HexColor("#92B6D5")
    ALABASTER_GLEAM = HexColor("#F0DEBD")
    ALASKAN_BLUE = HexColor("#6DA9D2")
    ALESAN = HexColor("#F1CEB3")
    ALEUTIAN = HexColor("#9A9EB3")
    ALFALFA = HexColor("#B7B59F")
    ALGIERS_BLUE = HexColor("#00859C")
    ALHAMBRA = HexColor("#008778")
    ALLOY = HexColor("#98979A")
    ALLURE = HexColor("#7291B4")
    ALMOND = HexColor("#A7754D")
    ALMOND_BLOSSOM = HexColor("#F5BEC7")
    ALMOND_BUFF = HexColor("#CCB390")
    ALMOND_CREAM = HexColor("#F4C29F")
    ALMOND_MILK = HexColor("#D6CEBE")
    ALMOND_OIL = HexColor("#F4EFC1")
    ALMONDINE = HexColor("#A78C8B")
    ALMOST_APRICOT = HexColor("#E5B39B")
    ALMOST_AQUA = HexColor("#CAD3C1")
    ALMOST_MAUVE = HexColor("#E7DCD9")
    ALOE = HexColor("#817A60")
    ALOE_WASH = HexColor("#D0D3B7")
    ALPINE_GREEN = HexColor("#005F56")
    ALUMINUM = HexColor("#9F9586")
    AMARANTH = HexColor("#6F3C56")
    AMARANTH_PURPLE = HexColor("#6A397B")
    AMAZON = HexColor("#1F7349")
    AMBER = HexColor("#EFAD55")
    AMBER_BROWN = HexColor("#A66646")
    AMBER_GOLD = HexColor("#C19552")
    AMBER_GREEN = HexColor("#9A803A")
    AMBER_YELLOW = HexColor("#FAB75A")
    AMBERGLOW = HexColor("#DC793E")
    AMBERLIGHT = HexColor("#E2BEA2")
    AMBROSIA = HexColor("#D2E7CA")
    AMERICAN_BEAUTY = HexColor("#A73340")
    AMETHYST = HexColor("#864D75")
    AMETHYST_ORCHID = HexColor("#926AA6")
    AMPARO_BLUE = HexColor("#4960A8")
    AMPHORA = HexColor("#9F8672")
    ANDORRA = HexColor("#603535")
    ANEMONE = HexColor("#842C48")
    ANGEL_BLUE = HexColor("#83C5CD")
    ANGEL_FALLS = HexColor("#A3BDD3")
    ANGEL_WING = HexColor("#F3DFD7")
    ANGORA = HexColor("#DFD1BB")
    ANISE_FLOWER = HexColor("#F4E3B5")
    ANTARCTICA = HexColor("#C6C5C6")
    ANTELOPE = HexColor("#B19664")
    ANTHRACITE = HexColor("#28282D")
    ANTIQUA_SAND = HexColor("#83C2CD")
    ANTIQUE_BRONZE = HexColor("#907954")
    ANTIQUE_GOLD = HexColor("#B59E5F")
    ANTIQUE_GREEN = HexColor("#29675C")
    ANTIQUE_MOSS = HexColor("#B9A023")
    ANTIQUE_WHITE = HexColor("#EDE3D2")
    ANTLER = HexColor("#957A76")
    APPLE_BUTTER = HexColor("#844B4D")
    APPLE_CINNAMON = HexColor("#B0885A")
    APPLE_GREEN = HexColor("#B5B644")
    APPLEBLOSSOM = HexColor("#DDBCA0")
    APRICOT = HexColor("#F19035")
    APRICOT_BLUSH = HexColor("#FEAEA5")
    APRICOT_BRANDY = HexColor("#C26A5A")
    APRICOT_BUFF = HexColor("#CD7E4D")
    APRICOT_CREAM = HexColor("#F1BD89")
    APRICOT_GELATO = HexColor("#F5D7AF")
    APRICOT_ICE = HexColor("#FBBE99")
    APRICOT_ILLUSION = HexColor("#E2C4A6")
    APRICOT_NECTAR = HexColor("#ECAA79")
    APRICOT_ORANGE = HexColor("#C86B3C")
    APRICOT_SHERBET = HexColor("#FACD9E")
    APRICOT_TAN = HexColor("#DD9760")
    APRICOT_WASH = HexColor("#FBAC82")
    AQUA = HexColor("#64A1AD")
    AQUA_FOAM = HexColor("#ADC3B4")
    AQUA_GLASS = HexColor("#D2E8E0")
    AQUA_GRAY = HexColor("#A5B2AA")
    AQUA_GREEN = HexColor("#00B89F")
    AQUA_HAZE = HexColor("#87B9BC")
    AQUA_SEA = HexColor("#6BAAAE")
    AQUA_SKY = HexColor("#7BC4C4")
    AQUA_SPLASH = HexColor("#85CED1")
    AQUAMARINE = HexColor("#9DC3D4")
    AQUARELLE = HexColor("#61AAB1")
    AQUARIUS = HexColor("#3CADD4")
    AQUATIC = HexColor("#99C1CC")
    AQUIFER = HexColor("#89ACAC")
    ARABESQUE = HexColor("#D16F52")
    ARABIAN_SPICE = HexColor("#884332")
    ARAGON = HexColor("#B06455")
    ARCADIA = HexColor("#00A28A")
    ARCADIAN_GREEN = HexColor("#A3C893")
    ARCTIC = HexColor("#648589")
    ARCTIC_DUSK = HexColor("#735B6A")
    ARCTIC_ICE = HexColor("#BFC7D6")
    ARGAN_OIL = HexColor("#8B593E")
    ARGYLE_PURPLE = HexColor("#895C79")
    ARONA = HexColor("#879BA3")
    ARROWWOOD = HexColor("#BC8D1F")
    ARTICHOKE_GREEN = HexColor("#4B6D41")
    ARTISANS_GOLD = HexColor("#F2AB46")
    ARUBA_BLUE = HexColor("#81D7D3")
    ASH = HexColor("#A09998")
    ASH_ROSE = HexColor("#B5817D")
    ASHES_OF_ROSES = HexColor("#B5ACAB")
    ASHLEY_BLUE = HexColor("#8699AB")
    ASPARAGUS_GREEN = HexColor("#D2CDB4")
    ASPEN_GOLD = HexColor("#FFD662")
    ASPEN_GREEN = HexColor("#7E9B76")
    ASPHALT = HexColor("#434447")
    ASTER_PURPLE = HexColor("#7D74A8")
    ASTRAL_AURA = HexColor("#363151")
    ATLANTIC_DEEP = HexColor("#274E55")
    ATLANTIS = HexColor("#00AF9F")
    ATMOSPHERE = HexColor("#A89C94")
    AUBURN = HexColor("#A15843")
    AURA_ORANGE = HexColor("#B4262A")
    AURORA = HexColor("#EDDD59")
    AURORA_PINK = HexColor("#E881A6")
    AURORA_RED = HexColor("#B93A32")
    AUTUMN_BLAZE = HexColor("#D9922E")
    AUTUMN_BLONDE = HexColor("#EED0AE")
    AUTUMN_GLAZE = HexColor("#B3573F")
    AUTUMN_GLORY = HexColor("#FF8812")
    AUTUMN_LEAF = HexColor("#B56A4C")
    AUTUMN_MAPLE = HexColor("#C46215")
    AUTUMN_SUNSET = HexColor("#F38554")
    AUTUMNAL = HexColor("#A15325")
    AVOCADO = HexColor("#676232")
    AZALEA = HexColor("#D42E5B")
    AZALEA_PINK = HexColor("#E96A97")
    AZTEC = HexColor("#7A5747")
    AZURE_BLUE = HexColor("#4D91C6")

    BABY_BLUE = HexColor("#B5C7D3")
    BACHELOR_BUTTON = HexColor("#4ABBD5")
    BAJA_BLUE = HexColor("#5F6DB0")
    BAKED_APPLE = HexColor("#B34646")
    BAKED_CLAY = HexColor("#9C5642")
    BALEINE_BLUE = HexColor("#155187")
    BALLAD_BLUE = HexColor("#C0CEDA")
    BALLERINA = HexColor("#F2CFDC")
    BALLET_SLIPPER = HexColor("#EBCED5")
    BALSAM = HexColor("#33565E")
    BALSAM_GREEN = HexColor("#576664")
    BALTIC = HexColor("#279D9F")
    BALTIC_SEA = HexColor("#79B5DB")
    BAMBOO = HexColor("#D2B04C")
    BANANA = HexColor("#FCB953")
    BANANA_CREAM = HexColor("#FFCF73")
    BANANA_CREPE = HexColor("#E7D3AD")
    BARBADOS_CHERRY = HexColor("#AA0A27")
    BARBERRY = HexColor("#BF1945")
    BARELY_BLUE = HexColor("#DDE0DF")
    BARELY_PINK = HexColor("#F8D7DD")
    BARK = HexColor("#A99592")
    BARN_RED = HexColor("#8F423B")
    BAROQUE_ROSE = HexColor("#B35A66")
    BARRIER_REEF = HexColor("#0084A1")
    BASIL = HexColor("#879F84")
    BATON_ROUGE = HexColor("#973C6C")
    BAY = HexColor("#BAE5D6")
    BAYBERRY = HexColor("#255958")
    BAYOU = HexColor("#20706F")
    BEACH_GLASS = HexColor("#96DFCE")
    BEACH_SAND = HexColor("#FBB995")
    BEAUJOLAIS = HexColor("#80304C")
    BEAVER_FUR = HexColor("#997867")
    BEECH = HexColor("#5B4F3B")
    BEECHNUT = HexColor("#C2C18D")
    BEESWAX = HexColor("#EBA851")
    BEET_RED = HexColor("#7A1F3D")
    BEETLE = HexColor("#55584C")
    BEETROOT_PURPLE = HexColor("#CF2D71")
    BEGONIA_PINK = HexColor("#EC9ABE")
    BEIGE = HexColor("#D5BA98")
    BEL_AIR_BLUE = HexColor("#819AC1")
    BELGIAN_BLOCK = HexColor("#A3A9A6")
    BELLFLOWER = HexColor("#9469A2")
    BELLINI = HexColor("#F4C9B1")
    BELUGA = HexColor("#4A4843")
    BERING_SEA = HexColor("#4B5B6E")
    BERMUDA = HexColor("#60C9B3")
    BERRY_CONSERVE = HexColor("#765269")
    BERYL_GREEN = HexColor("#619187")
    BEVELED_GLASS = HexColor("#7ACCB8")
    BIJOU_BLUE = HexColor("#4E5E7F")
    BIKING_RED = HexColor("#77212E")
    BILLIARD = HexColor("#00AA92")
    BILLOWING_SAIL = HexColor("#D8E7E7")
    BIRCH = HexColor("#DDD5C7")
    BIRD_OF_PARADISE = HexColor("#FF8C55")
    BIRDS_EGG_GREEN = HexColor("#AACCB9")
    BISCAY_BAY = HexColor("#097988")
    BISCAY_GREEN = HexColor("#55C6A9")
    BISCOTTI = HexColor("#DAC7AB")
    BISCUIT = HexColor("#B4835B")
    BISON = HexColor("#6E4F3A")
    BISQUE = HexColor("#EDCAB5")
    BISTRE = HexColor("#98754A")
    BISTRO_GREEN = HexColor("#395551")
    BIT_OF_BLUE = HexColor("#E2EAEB")
    BITTER_CHOCOLATE = HexColor("#503130")
    BITTERSWEET = HexColor("#D93744")
    BLACK_BEAN = HexColor("#2E272A")
    BLACK_BEAUTY = HexColor("#26262A")
    BLACK_COFFEE = HexColor("#3B302F")
    BLACK_FOREST = HexColor("#414F3C")
    BLACK_INK = HexColor("#44413C")
    BLACK_IRIS = HexColor("#2B3042")
    BLACK_OLIVE = HexColor("#48413B")
    BLACK_ONYX = HexColor("#2B272B")
    BLACK_PLUM = HexColor("#6C5765")
    BLACKBERRY_CORDIAL = HexColor("#3F2A47")
    BLACKBERRY_WINE = HexColor("#4D3246")
    BLACKENED_PEARL = HexColor("#4D4B50")
    BLANC_DE_BLANC = HexColor("#E7E9E7")
    BLARNEY = HexColor("#00A776")
    BLAZING_ORANGE = HexColor("#FFA64F")
    BLAZING_YELLOW = HexColor("#FEE715")
    BLEACHED_APRICOT = HexColor("#FCCAAC")
    BLEACHED_AQUA = HexColor("#BCE3DF")
    BLEACHED_DENIM = HexColor("#646F9B")
    BLEACHED_SAND = HexColor("#DACCB4")
    BLITHE = HexColor("#0084BD")
    BLOOMING_DAHLIA = HexColor("#EB9687")
    BLOSSOM = HexColor("#F2B2AE")
    BLUE_ASHES = HexColor("#3B5F78")
    BLUE_ASTER = HexColor("#0077B3")
    BLUE_ATOLL = HexColor("#00B1D2")
    BLUE_BELL = HexColor("#93B4D7")
    BLUE_BLUSH = HexColor("#D6DBD9")
    BLUE_BONNET = HexColor("#6384B8")
    BLUE_CORAL = HexColor("#1B5366")
    BLUE_CURACAO = HexColor("#32BECC")
    BLUE_DANUBE = HexColor("#0087B6")
    BLUE_DEPTHS = HexColor("#263056")
    BLUE_FLOWER = HexColor("#D0D9D4")
    BLUE_FOG = HexColor("#9BABBB")
    BLUE_FOX = HexColor("#B9BCB6")
    BLUE_GLASS = HexColor("#C6E3E1")
    BLUE_GLOW = HexColor("#B2D4DD")
    BLUE_GRANITE = HexColor("#717388")
    BLUE_GRAPHITE = HexColor("#323137")
    BLUE_GRASS = HexColor("#007C7A")
    BLUE_GROTTO = HexColor("#5CACCE")
    BLUE_HAZE = HexColor("#A5BCBB")
    BLUE_HEAVEN = HexColor("#5B7E98")
    BLUE_HERON = HexColor("#96A3C7")
    BLUE_HORIZON = HexColor("#4E6482")
    BLUE_ICE = HexColor("#70789B")
    BLUE_INDIGO = HexColor("#49516D")
    BLUE_IRIS = HexColor("#5A5B9F")
    BLUE_JEWEL = HexColor("#007BAA")
    BLUE_LIGHT = HexColor("#ACDFDD")
    BLUE_MIRAGE = HexColor("#5C6D7C")
    BLUE_MIST = HexColor("#5BACC3")
    BLUE_MOON = HexColor("#3686A0")
    BLUE_NIGHTS = HexColor("#363B48")
    BLUE_OPAL = HexColor("#0F3B57")
    BLUE_RADIANCE = HexColor("#58C9D4")
    BLUE_RIBBON = HexColor("#3A395F")
    BLUE_SAPPHIRE = HexColor("#09577B")
    BLUE_SHADOW = HexColor("#66829A")
    BLUE_SPRUCE = HexColor("#486B67")
    BLUE_SURF = HexColor("#90A8A4")
    BLUE_TINT = HexColor("#9FD9D7")
    BLUE_TOPAZ = HexColor("#78BDD4")
    BLUE_TURQUOISE = HexColor("#53B0AE")
    BLUE_WING_TEAL = HexColor("#2C4053")
    BLUE_YONDER = HexColor("#5A77A8")
    BLUEBERRY = HexColor("#2C333E")
    BLUEBIRD = HexColor("#009DAE")
    BLUEJAY = HexColor("#157EA0")
    BLUEPRINT = HexColor("#2D3359")
    BLUESTEEL = HexColor("#35637C")
    BLUESTONE = HexColor("#577284")
    BLUEWASH = HexColor("#E2E6E0")
    BLUSH = HexColor("#D1969A")
    BLUSHING_BRIDE = HexColor("#FBD3D9")
    BOA = HexColor("#8E855F")
    BODACIOUS = HexColor("#B76BA3")
    BOG = HexColor("#BAB696")
    BOK_CHOY = HexColor("#BCCAB3")
    BOMBAY_BROWN = HexColor("#9F5130")
    BONE_BROWN = HexColor("#9D7446")
    BONE_WHITE = HexColor("#D7D0C0")
    BONNIE_BLUE = HexColor("#539CCC")
    BORDEAUX = HexColor("#96637B")
    BOSPHORUS = HexColor("#007558")
    BOSSA_NOVA = HexColor("#973A36")
    BOTANICAL_GARDEN = HexColor("#12403C")
    BOTTLE_GREEN = HexColor("#427D6D")
    BOUGAINVILLEA = HexColor("#9884B9")
    BOULDER = HexColor("#D1BE9B")
    BOYSENBERRY = HexColor("#85325C")
    BRACKEN = HexColor("#4F3F3B")
    BRAN = HexColor("#A66E4A")
    BRANDIED_APRICOT = HexColor("#CA848A")
    BRANDIED_MELON = HexColor("#CE7B5B")
    BRANDY_BROWN = HexColor("#73362A")
    BRAZILIAN_SAND = HexColor("#DACAB7")
    BREEN = HexColor("#795D34")
    BRICK_DUST = HexColor("#B07069")
    BRICK_RED = HexColor("#8C373E")
    BRIDAL_BLUSH = HexColor("#EEE2DD")
    BRIDAL_ROSE = HexColor("#D69FA2")
    BRIGHT_AQUA = HexColor("#30A299")
    BRIGHT_CHARTREUSE = HexColor("#B5BF50")
    BRIGHT_COBALT = HexColor("#385D8D")
    BRIGHT_GOLD = HexColor("#CF9F52")
    BRIGHT_GREEN = HexColor("#009B5C")
    BRIGHT_LIME_GREEN = HexColor("#97BC62")
    BRIGHT_MARIGOLD = HexColor("#FF8D00")
    BRIGHT_ROSE = HexColor("#C51959")
    BRIGHT_VIOLET = HexColor("#784384")
    BRIGHT_WHITE = HexColor("#F4F5F0")
    BRILLIANT_BLUE = HexColor("#0075B3")
    BRILLIANT_WHITE = HexColor("#EDF1FE")
    BRINDLE = HexColor("#82776B")
    BRISTOL_BLUE = HexColor("#558F91")
    BRITTANY_BLUE = HexColor("#4C7E86")
    BRONZE_BROWN = HexColor("#825E2F")
    BRONZE_GREEN = HexColor("#525F48")
    BRONZE_MIST = HexColor("#9C7E41")
    BROOK_GREEN = HexColor("#AFDDCC")
    BROWN_PATINA = HexColor("#834F3D")
    BROWN_RICE = HexColor("#C7BBA4")
    BROWN_STONE = HexColor("#593C39")
    BROWN_SUGAR = HexColor("#A17249")
    BROWNIE = HexColor("#8F7265")
    BRUNETTE = HexColor("#664238")
    BRUNNERA_BLUE = HexColor("#9BA9CA")
    BRUSCHETTA = HexColor("#A75949")
    BRUSH = HexColor("#B99984")
    BRUSHED_NICKEL = HexColor("#73706F")
    BUBBLEGUM = HexColor("#EA738D")
    BUCKSKIN = HexColor("#D18E54")
    BUCKTHORN_BROWN = HexColor("#A76F1F")
    BUD_GREEN = HexColor("#79B465")
    BUFF = HexColor("#EBC396")
    BUFF_ORANGE = HexColor("#FFBB7C")
    BUFF_YELLOW = HexColor("#F1BF70")
    BUNGEE_CORD = HexColor("#696156")
    BURGUNDY = HexColor("#64313E")
    BURLWOOD = HexColor("#9B716B")
    BURNISHED_GOLD = HexColor("#AA9855")
    BURNISHED_LILAC = HexColor("#C5AEB1")
    BURNT_BRICK = HexColor("#A14D3A")
    BURNT_CORAL = HexColor("#E9897E")
    BURNT_HENNA = HexColor("#7E392F")
    BURNT_OCHRE = HexColor("#BB4F35")
    BURNT_OLIVE = HexColor("#646049")
    BURNT_ORANGE = HexColor("#C86733")
    BURNT_RUSSET = HexColor("#7E3940")
    BURNT_SIENNA = HexColor("#C65D52")
    BURRO = HexColor("#947764")
    BUTTERCREAM = HexColor("#EFE0CD")
    BUTTERCUP = HexColor("#FAE03C")
    BUTTERFLY = HexColor("#CADEA5")
    BUTTERNUT = HexColor("#7A643F")
    BUTTERSCOTCH = HexColor("#E19640")
    BUTTERUM = HexColor("#C68F65")
    BYZANTIUM = HexColor("#853B7B")

    CABARET = HexColor("#CB3373")
    CABBAGE = HexColor("#87D7BE")
    CABERNET = HexColor("#64242E")
    CACTUS = HexColor("#53713D")
    CACTUS_FLOWER = HexColor("#A83E6C")
    CADET = HexColor("#6A6378")
    CADMIUM_GREEN = HexColor("#00675B")
    CADMIUM_ORANGE = HexColor("#F99471")
    CADMIUM_YELLOW = HexColor("#EE9626")
    CAFE_AU_LAIT = HexColor("#AE8774")
    CAFE_CREME = HexColor("#C79685")
    CALLA_GREEN = HexColor("#6A6F34")
    CALLISTE_GREEN = HexColor("#757A4E")
    CALYPSO_CORAL = HexColor("#EE5C6C")
    CAMEL = HexColor("#B0846A")
    CAMELLIA = HexColor("#F6745F")
    CAMELLIA_ROSE = HexColor("#EB6081")
    CAMEO_BLUE = HexColor("#769DA6")
    CAMEO_BROWN = HexColor("#C08A80")
    CAMEO_GREEN = HexColor("#AAC0AD")
    CAMEO_PINK = HexColor("#DBA9B8")
    CAMEO_ROSE = HexColor("#D7B8AB")
    CAMPANULA = HexColor("#3272AF")
    CANAL_BLUE = HexColor("#9CC2C5")
    CANARY_GREEN = HexColor("#D6DEC9")
    CANARY_YELLOW = HexColor("#DFD87E")
    CANDIED_GINGER = HexColor("#BFA387")
    CANDLELIGHT_PEACH = HexColor("#F8A39D")
    CANDY_PINK = HexColor("#F5B0BD")
    CANEEL_BAY = HexColor("#00849F")
    CANNOLI_CREAM = HexColor("#F0EFE2")
    CANTALOUPE = HexColor("#FFA177")
    CANTEEN = HexColor("#5E5347")
    CANTON = HexColor("#6DA29E")
    CANYON_CLAY = HexColor("#CE8477")
    CANYON_ROSE = HexColor("#AF6C67")
    CANYON_SUNSET = HexColor("#E1927A")
    CAPERS = HexColor("#695E4B")
    CAPPUCCINO = HexColor("#633F33")
    CAPRI = HexColor("#44BBCA")
    CAPRI_BREEZE = HexColor("#008799")
    CAPTAINS_BLUE = HexColor("#557088")
    CAPULET_OLIVE = HexColor("#656344")
    CARAFE = HexColor("#5D473A")
    CARAMEL = HexColor("#C37C54")
    CARAMEL_CAFE = HexColor("#864C24")
    CARAMEL_CREAM = HexColor("#F4BA94")
    CARBON = HexColor("#272F38")
    CARDINAL = HexColor("#AD3E48")
    CARIBBEAN_SEA = HexColor("#00819D")
    CARIBOU = HexColor("#816D5E")
    CARMINE = HexColor("#BC4869")
    CARMINE_ROSE = HexColor("#E35B8F")
    CARNELIAN = HexColor("#CE785D")
    CAROB_BROWN = HexColor("#855C4C")
    CARROT = HexColor("#FD6F3B")
    CARROT_CURL = HexColor("#FE8C18")
    CASCADE = HexColor("#76C1B2")
    CASHEW = HexColor("#A47149")
    CASHMERE_BLUE = HexColor("#A5B8D0")
    CASHMERE_ROSE = HexColor("#CE879F")
    CASTLE_WALL = HexColor("#C8C1AB")
    CASTLEROCK = HexColor("#5F5E62")
    CASTOR_GRAY = HexColor("#646762")
    CATAWBA_GRAPE = HexColor("#5D3C43")
    CATHAY_SPICE = HexColor("#99642C")
    CAVIAR = HexColor("#292A2D")
    CAYENNE = HexColor("#E04951")
    CEDAR = HexColor("#928E64")
    CEDAR_GREEN = HexColor("#5E6737")
    CEDAR_WOOD = HexColor("#A1655B")
    CELADON = HexColor("#B8CCBA")
    CELADON_GREEN = HexColor("#B5C1A5")
    CELADON_TINT = HexColor("#CBCEBE")
    CELANDINE = HexColor("#EBDF67")
    CELERY = HexColor("#CEC153")
    CELERY_GREEN = HexColor("#C5CC7B")
    CELESTIAL = HexColor("#006380")
    CELESTIAL_BLUE = HexColor("#A3B4C4")
    CELOSIA_ORANGE = HexColor("#E8703A")
    CEMENT = HexColor("#C4B6A6")
    CENDRE_BLUE = HexColor("#3E7FA5")
    CERAMIC = HexColor("#00AAA9")
    CERISE = HexColor("#A41247")
    CERULEAN = HexColor("#9BB7D4")
    CEYLON_YELLOW = HexColor("#D4AE40")
    CHAI_TEA = HexColor("#B1832F")
    CHALK_BLUE = HexColor("#CCDAD7")
    CHALK_PINK = HexColor("#E6C5CA")
    CHALK_VIOLET = HexColor("#8F7DA5")
    CHAMBRAY_BLUE = HexColor("#9EB4D3")
    CHAMOIS = HexColor("#F7B26A")
    CHAMOMILE = HexColor("#E8D0A7")
    CHANTERELLE = HexColor("#A28776")
    CHARCOAL_GRAY = HexColor("#6C6868")
    CHARDONNAY = HexColor("#E7DF99")
    CHARISMA = HexColor("#632A60")
    CHARLOCK = HexColor("#E5E790")
    CHATEAU_GRAY = HexColor("#BBB1A8")
    CHATEAU_ROSE = HexColor("#D2738F")
    CHERRIES_JUBILEE = HexColor("#A22452")
    CHERRY_BLOSSOM = HexColor("#F7CEE0")
    CHERRY_MAHOGANY = HexColor("#66352B")
    CHERRY_TOMATO = HexColor("#EB3C27")
    CHESTNUT = HexColor("#584039")
    CHICORY_COFFEE = HexColor("#4A342E")
    CHILI = HexColor("#BE5141")
    CHILI_OIL = HexColor("#8E3C36")
    CHILI_PEPPER = HexColor("#9B1B30")
    CHINA_BLUE = HexColor("#546477")
    CHINCHILLA = HexColor("#9C8E7B")
    CHINESE_RED = HexColor("#BE132D")
    CHINESE_VIOLET = HexColor("#835E81")
    CHINO_GREEN = HexColor("#D9CAA5")
    CHINOIS_GREEN = HexColor("#7C8C87")
    CHINTZ_ROSE = HexColor("#EEC4BE")
    CHIPMUNK = HexColor("#976F4C")
    CHIVE = HexColor("#4A5335")
    CHIVE_BLOSSOM = HexColor("#7D5D99")
    CHOCOLATE_BROWN = HexColor("#4E403B")
    CHOCOLATE_CHIP = HexColor("#685A4E")
    CHOCOLATE_FONDANT = HexColor("#56352D")
    CHOCOLATE_LAB = HexColor("#5C3E35")
    CHOCOLATE_PLUM = HexColor("#3C2D2E")
    CHOCOLATE_TORTE = HexColor("#382E2D")
    CHOCOLATE_TRUFFLE = HexColor("#612E35")
    CHRYSANTHEMUM = HexColor("#BE454F")
    CHUTNEY = HexColor("#98594B")
    CILANTRO = HexColor("#43544B")
    CINDER = HexColor("#8A7E78")
    CINNABAR = HexColor("#9C453B")
    CINNAMON = HexColor("#6B4139")
    CINNAMON_STICK = HexColor("#9B4722")
    CITADEL = HexColor("#748995")
    CITRON = HexColor("#DFDE9B")
    CITRONELLE = HexColor("#B8AF23")
    CITRUS = HexColor("#F9AC2F")
    CLARET_RED = HexColor("#C84C61")
    CLASSIC_BLUE = HexColor("#0F4C81")
    CLASSIC_GREEN = HexColor("#39A845")
    CLAY = HexColor("#D2A172")
    CLEARLY_AQUA = HexColor("#CEE1D4")
    CLEARWATER = HexColor("#AAD5DB")
    CLEMATIS_BLUE = HexColor("#363B7C")
    CLIMBING_IVY = HexColor("#444940")
    CLOISONNE = HexColor("#0075AF")
    CLOUD_BLUE = HexColor("#A2B6B9")
    CLOUD_CREAM = HexColor("#E6DDC5")
    CLOUD_DANCER = HexColor("#F0EEE9")
    CLOUD_GRAY = HexColor("#B7A9AC")
    CLOUD_PINK = HexColor("#F5D1C8")
    CLOUDBURST = HexColor("#837F7F")
    CLOVE = HexColor("#876155")
    CLOVER = HexColor("#8A3371")
    COASTAL_FJORD = HexColor("#505D7E")
    COBBLESTONE = HexColor("#A89A8E")
    COCKATOO = HexColor("#58C8B6")
    COCOA_BROWN = HexColor("#6C5043")
    COCONUT_MILK = HexColor("#F0EDE5")
    COCONUT_SHELL = HexColor("#874E3C")
    COCOON = HexColor("#C9B27C")
    COFFEE_BEAN = HexColor("#40312F")
    COFFEE_LIQUEUR = HexColor("#6A513B")
    COGNAC = HexColor("#8B645A")
    COLONIAL_BLUE = HexColor("#2D6471")
    COLONY_BLUE = HexColor("#65769A")
    COLUMBIA = HexColor("#009288")
    COMFREY = HexColor("#5B7961")
    CONCH_SHELL = HexColor("#FC8F9B")
    CONCORD_GRAPE = HexColor("#7C5379")
    CONFETTI = HexColor("#E6798E")
    COOL_BLUE = HexColor("#A5C5D9")
    COPEN_BLUE = HexColor("#516B84")
    COPPER = HexColor("#C47E5A")
    COPPER_BROWN = HexColor("#9A6051")
    COPPER_COIN = HexColor("#BA6B57")
    COPPER_TAN = HexColor("#DE8E65")
    CORAL = HexColor("#ED7464")
    CORAL_ALMOND = HexColor("#E29D94")
    CORAL_BLUSH = HexColor("#E6B2B8")
    CORAL_CLOUD = HexColor("#E2A9A1")
    CORAL_GOLD = HexColor("#D27D56")
    CORAL_HAZE = HexColor("#E38E84")
    CORAL_PINK = HexColor("#E8A798")
    CORAL_QUARTZ = HexColor("#F77464")
    CORAL_REEF = HexColor("#FAA181")
    CORAL_ROSE = HexColor("#F3774D")
    CORAL_SANDS = HexColor("#EDAA86")
    CORDOVAN = HexColor("#702F3B")
    CORIANDER = HexColor("#938772")
    CORK = HexColor("#BA8671")
    CORNFLOWER_BLUE = HexColor("#7391C8")
    CORNHUSK = HexColor("#F2D6AE")
    CORNSILK = HexColor("#EDC373")
    CORNSTALK = HexColor("#A9947A")
    CORONET_BLUE = HexColor("#59728E")
    CORSAIR = HexColor("#18576C")
    CORSICAN_BLUE = HexColor("#646093")
    CORYDALIS_BLUE = HexColor("#A9CADA")
    COSMIC_SKY = HexColor("#AAAAC4")
    COUNTRY_BLUE = HexColor("#717F9B")
    COVERT_GREEN = HexColor("#80765F")
    COWHIDE = HexColor("#884344")
    CRABAPPLE = HexColor("#D77E70")
    CRADLE_PINK = HexColor("#EDD0DD")
    CRANBERRY = HexColor("#BB4A4D")
    CREAM_BLUSH = HexColor("#F8C19A")
    CREAM_GOLD = HexColor("#DEC05F")
    CREAM_PINK = HexColor("#F6E4D9")
    CREAM_TAN = HexColor("#E4C7B8")
    CREAMPUFF = HexColor("#FFCDA8")
    CREME_BRULEE = HexColor("#DBCCB5")
    CREME_DE_MENTHE = HexColor("#70A38D")
    CREME_DE_PECHE = HexColor("#F5D6C6")
    CREOLE_PINK = HexColor("#F7D5CC")
    CRESS_GREEN = HexColor("#BCA949")
    CRIMSON = HexColor("#AE0E36")
    CROCKERY = HexColor("#A49887")
    CROCODILE = HexColor("#5D5348")
    CROCUS = HexColor("#C67FAE")
    CROCUS_PETAL = HexColor("#B99BC5")
    CROISSANT = HexColor("#C4AB86")
    CROWN_BLUE = HexColor("#464B65")
    CROWN_JEWEL = HexColor("#482D54")
    CRUSHED_BERRY = HexColor("#804F5A")
    CRUSHED_GRAPE = HexColor("#7A547F")
    CRUSHED_VIOLETS = HexColor("#643A4C")
    CRYSTAL_BLUE = HexColor("#A1C8DB")
    CRYSTAL_GRAY = HexColor("#D7CBC4")
    CRYSTAL_PINK = HexColor("#EDD0CE")
    CRYSTAL_ROSE = HexColor("#FDC3C6")
    CRYSTAL_SEAS = HexColor("#5DAFCE")
    CRYSTAL_TEAL = HexColor("#00637C")
    CUB = HexColor("#6E5C4B")
    CUBAN_SAND = HexColor("#C1A68D")
    CUMIN = HexColor("#927240")
    CURDS_AND_WHEY = HexColor("#BCA483")
    CURRY = HexColor("#BE9E6F")
    CUSTARD = HexColor("#E5D68E")
    CYAN_BLUE = HexColor("#14A3C7")
    CYBER_YELLOW = HexColor("#FFD400")
    CYCLAMEN = HexColor("#D687BA")
    CYPRESS = HexColor("#545A3E")

    DACHSHUND = HexColor("#704F37")
    DAFFODIL = HexColor("#FDC04E")
    DAHLIA = HexColor("#843E83")
    DAHLIA_MAUVE = HexColor("#A64F82")
    DAHLIA_PURPLE = HexColor("#7E6EAC")
    DAIQUIRI_GREEN = HexColor("#C9D77E")
    DAMSON = HexColor("#854C65")
    DANDELION = HexColor("#FFD02E")
    DAPHNE = HexColor("#0F5F9A")
    DAPPLE_GRAY = HexColor("#9C9BA7")
    DARK_BLUE = HexColor("#305679")
    DARK_CHEDDAR = HexColor("#E08119")
    DARK_CITRON = HexColor("#A0AC4F")
    DARK_DENIM = HexColor("#35465E")
    DARK_EARTH = HexColor("#5C4939")
    DARK_FOREST = HexColor("#556962")
    DARK_GREEN = HexColor("#314F40")
    DARK_GULL_GRAY = HexColor("#625D5D")
    DARK_IVY = HexColor("#5B7763")
    DARK_NAVY = HexColor("#232F36")
    DARK_OLIVE = HexColor("#574D35")
    DARK_PURPLE = HexColor("#582147")
    DARK_SAPPHIRE = HexColor("#262B37")
    DARK_SHADOW = HexColor("#4A4B4D")
    DARK_SLATE = HexColor("#46515A")
    DARKEST_SPRUCE = HexColor("#303D3C")
    DAWN = HexColor("#EBD2B7")
    DAWN_BLUE = HexColor("#CACCCB")
    DAWN_PINK = HexColor("#BFA3AF")
    DAYBREAK = HexColor("#8981A0")
    DAZZLING_BLUE = HexColor("#3850A0")
    DEAUVILLE_MAUVE = HexColor("#AF9294")
    DECADENT_CHOCOLATE = HexColor("#513235")
    DECEMBER_SKY = HexColor("#767275")
    DECO_ROSE = HexColor("#985F68")
    DEEP_BLUE = HexColor("#44377D")
    DEEP_CLARET = HexColor("#973443")
    DEEP_COBALT = HexColor("#404466")
    DEEP_DEPTHS = HexColor("#46483C")
    DEEP_DIVE = HexColor("#29495C")
    DEEP_FOREST = HexColor("#37413A")
    DEEP_GRASS_GREEN = HexColor("#558367")
    DEEP_GREEN = HexColor("#009276")
    DEEP_JUNGLE = HexColor("#36716F")
    DEEP_LAGOON = HexColor("#005265")
    DEEP_LAKE = HexColor("#00656B")
    DEEP_LAVENDER = HexColor("#775496")
    DEEP_LICHEN_GREEN = HexColor("#6E6E5C")
    DEEP_MAHOGANY = HexColor("#553B39")
    DEEP_MINT = HexColor("#009E6D")
    DEEP_ORCHID = HexColor("#903F75")
    DEEP_PEACOCK_BLUE = HexColor("#008381")
    DEEP_PERIWINKLE = HexColor("#7C83BC")
    DEEP_PURPLE = HexColor("#50314C")
    DEEP_SEA = HexColor("#4F7C74")
    DEEP_SEA_CORAL = HexColor("#D9615B")
    DEEP_TAUPE = HexColor("#7B6660")
    DEEP_TEAL = HexColor("#18454B")
    DEEP_ULTRAMARINE = HexColor("#384883")
    DEEP_WATER = HexColor("#266691")
    DEEP_WELL = HexColor("#2C2A33")
    DEEP_WISTERIA = HexColor("#443F6F")
    DELFT = HexColor("#3D5E8C")
    DELICACY = HexColor("#F5E3E2")
    DELICIOSO = HexColor("#3F352F")
    DELLA_ROBBIA_BLUE = HexColor("#7A9DCB")
    DELPHINIUM_BLUE = HexColor("#6198AE")
    DEMITASSE = HexColor("#40342B")
    DESERT_DUST = HexColor("#E3BC8E")
    DESERT_FLOWER = HexColor("#FF9687")
    DESERT_MIST = HexColor("#E0B589")
    DESERT_PALM = HexColor("#5A4632")
    DESERT_ROSE = HexColor("#CF6977")
    DESERT_SAGE = HexColor("#A7AE9E")
    DESERT_SAND = HexColor("#BD7B74")
    DESERT_SUN = HexColor("#C87629")
    DESERT_TAUPE = HexColor("#8D7E71")
    DEW = HexColor("#EEDED1")
    DEWBERRY = HexColor("#8B5987")
    DEWKIST = HexColor("#C4D1C2")
    DIFFUSED_ORCHID = HexColor("#9879A2")
    DIJON = HexColor("#97754C")
    DILL = HexColor("#6F7755")
    DIRECTOIRE_BLUE = HexColor("#0061A3")
    DIVA_BLUE = HexColor("#007BB2")
    DOE = HexColor("#B98E68")
    DOESKIN = HexColor("#BDAB9B")
    DOUBLE_CREAM = HexColor("#F3E0AC")
    DOVE = HexColor("#B3ADA7")
    DRAGON_FIRE = HexColor("#FC642D")
    DRAGONFLY = HexColor("#2A5C6A")
    DREAM_BLUE = HexColor("#A0BCD0")
    DRESDEN_BLUE = HexColor("#0086BB")
    DRESS_BLUES = HexColor("#2A3244")
    DRIED_HERB = HexColor("#847A59")
    DRIED_MOSS = HexColor("#CCB97E")
    DRIED_TOBACCO = HexColor("#997B38")
    DRIFTWOOD = HexColor("#847A75")
    DRIZZLE = HexColor("#A09F9C")
    DRY_ROSE = HexColor("#8C4759")
    DUBARRY = HexColor("#F25F66")
    DUCK_GREEN = HexColor("#53665C")
    DUFFEL_BAG = HexColor("#394034")
    DULL_GOLD = HexColor("#8A6F48")
    DUNE = HexColor("#998978")
    DUSK = HexColor("#897F98")
    DUSK_BLUE = HexColor("#7BA0C0")
    DUSKY_CITRON = HexColor("#E3CC81")
    DUSKY_GREEN = HexColor("#746C57")
    DUSKY_ORCHID = HexColor("#9A7182")
    DUSTED_CLAY = HexColor("#CC7357")
    DUSTED_PERI = HexColor("#696BA0")
    DUSTY_AQUA = HexColor("#C0DCCD")
    DUSTY_BLUE = HexColor("#8C9DAD")
    DUSTY_CEDAR = HexColor("#AD5D5D")
    DUSTY_CORAL = HexColor("#D29B83")
    DUSTY_JADE_GREEN = HexColor("#7BB5A3")
    DUSTY_LAVENDER = HexColor("#A1759C")
    DUSTY_OLIVE = HexColor("#646356")
    DUSTY_ORANGE = HexColor("#E27A53")
    DUSTY_PINK = HexColor("#DEAA9B")
    DUSTY_ROSE = HexColor("#BA797D")
    DUSTY_TURQUOISE = HexColor("#649B9E")
    DUSTY_YELLOW = HexColor("#D4CC9A")
    DUTCH_BLUE = HexColor("#4A638D")
    DYNASTY_GREEN = HexColor("#008E80")

    EARTH_RED = HexColor("#95424E")
    EASTER_EGG = HexColor("#919BC9")
    EBONY = HexColor("#41424A")
    ECLIPSE = HexColor("#343148")
    ECRU = HexColor("#F3DFCA")
    ECRU_OLIVE = HexColor("#927B3C")
    EDEN = HexColor("#264E36")
    EGGNOG = HexColor("#ECE1D3")
    EGGPLANT = HexColor("#613F4C")
    EGGSHELL_BLUE = HexColor("#A3CCC9")
    EGRET = HexColor("#F3ECE0")
    EIFFEL_TOWER = HexColor("#5C5658")
    ELDERBERRY = HexColor("#9D848E")
    ELECTRIC_GREEN = HexColor("#4BC3A8")
    ELEPHANT_SKIN = HexColor("#8F8982")
    ELFIN_YELLOW = HexColor("#EEEA97")
    ELM = HexColor("#A39F86")
    ELM_GREEN = HexColor("#547053")
    ELMWOOD = HexColor("#8C7C61")
    EMBERGLOW = HexColor("#EA6759")
    EMERALD = HexColor("#009473")
    EMPERADOR = HexColor("#684832")
    EMPIRE_YELLOW = HexColor("#F7D000")
    ENAMEL_BLUE = HexColor("#007A8E")
    ENDIVE = HexColor("#D2CC81")
    ENGLISH_IVY = HexColor("#61845B")
    ENGLISH_LAVENDAR = HexColor("#9D7BB0")
    ENGLISH_MANOR = HexColor("#7181A4")
    ENGLISH_ROSE = HexColor("#F4C6C3")
    ENSIGN_BLUE = HexColor("#384C67")
    EPHEMERA = HexColor("#6F5965")
    EPSOM = HexColor("#849161")
    ERMINE = HexColor("#836B4F")
    ESPRESSO = HexColor("#363031")
    ESTATE_BLUE = HexColor("#233658")
    ETHER = HexColor("#9EB6B8")
    ETHEREA = HexColor("#A5958F")
    ETHEREAL_BLUE = HexColor("#5CA6CE")
    ETHEREAL_GREEN = HexColor("#F1ECCA")
    ETRUSCAN_RED = HexColor("#A2574B")
    EUCALYPTUS = HexColor("#B1A992")
    EVENING_BLUE = HexColor("#2A293E")
    EVENING_HAZE = HexColor("#BDB8C7")
    EVENING_PRIMROSE = HexColor("#CCDB1E")
    EVENING_SAND = HexColor("#DDB6AB")
    EVENTIDE = HexColor("#959EB7")
    EVERGLADE = HexColor("#005B5D")
    EVERGREEN = HexColor("#11574A")
    EXCALIBUR = HexColor("#676168")
    EXOTIC_ORANGE = HexColor("#F96531")
    EXUBERANCE = HexColor("#E86800")

    FADED_DENIM = HexColor("#798EA4")
    FADED_ROSE = HexColor("#BF6464")
    FAIENCE = HexColor("#2A6A8B")
    FAIR_AQUA = HexColor("#B8E2DC")
    FAIR_GREEN = HexColor("#92AF88")
    FAIR_ORCHID = HexColor("#C0AAC0")
    FAIREST_JADE = HexColor("#D8E3D7")
    FAIRWAY = HexColor("#477050")
    FAIRY_TALE = HexColor("#F2C1D1")
    FAIRY_WREN = HexColor("#9479AF")
    FALCON = HexColor("#6D625B")
    FALL_LEAF = HexColor("#C9A86A")
    FALLEN_ROCK = HexColor("#807669")
    FANDANGO_PINK = HexColor("#E04F80")
    FANFARE = HexColor("#006D70")
    FAWN = HexColor("#AE9490")
    FEATHER_GRAY = HexColor("#B8AD9E")
    FEDERAL_BLUE = HexColor("#43628B")
    FELDSPAR = HexColor("#729B8B")
    FENNEL_SEED = HexColor("#998456")
    FENUGREEK = HexColor("#C0916C")
    FERN = HexColor("#9AA067")
    FERN_GREEN = HexColor("#008C45")
    FESTIVAL_FUCHSIA = HexColor("#9E2C6A")
    FIERY_RED = HexColor("#D01C1F")
    FIESTA = HexColor("#DD4132")
    FIG = HexColor("#532D3B")
    FIR = HexColor("#3A725F")
    FIR_GREEN = HexColor("#67592A")
    FIRECRACKER = HexColor("#F36944")
    FIRED_BRICK = HexColor("#6A2E2A")
    FJORD_BLUE = HexColor("#007290")
    FLAME = HexColor("#F2552C")
    FLAME_ORANGE = HexColor("#FB8B23")
    FLAME_SCARLET = HexColor("#CD212A")
    FLAMINGO = HexColor("#DF7253")
    FLAMINGO_PINK = HexColor("#F7969E")
    FLAN = HexColor("#F6E3B4")
    FLAX = HexColor("#FFC87D")
    FLINT = HexColor("#705861")
    FLINT_GRAY = HexColor("#A09C98")
    FLINT_STONE = HexColor("#677283")
    FLORIDA_KEYS = HexColor("#56BEAB")
    FLUORITE_GREEN = HexColor("#699158")
    FOAM_GREEN = HexColor("#B4C79C")
    FOG = HexColor("#D0C5B1")
    FOG_GREEN = HexColor("#C2CBB4")
    FOGGY_DEW = HexColor("#D1D5D0")
    FOLIAGE = HexColor("#75A14F")
    FOLIAGE_GREEN = HexColor("#3E6F58")
    FOLKSTONE_GRAY = HexColor("#626879")
    FONDUE_FUDGE = HexColor("#5D4236")
    FOREST_BIOME = HexColor("#184A45")
    FOREST_GREEN = HexColor("#6B8D53")
    FOREST_NIGHT = HexColor("#434237")
    FOREST_SHADE = HexColor("#91AC80")
    FOREVER_BLUE = HexColor("#899BB8")
    FORGED_IRON = HexColor("#48464A")
    FORGET_ME_NOT = HexColor("#8FADBD")
    FOSSIL = HexColor("#806F63")
    FOUR_LEAF_CLOVER = HexColor("#616652")
    FOXGLOVE = HexColor("#B98391")
    FRAGRANT_LILAC = HexColor("#CEADBE")
    FRAPPE = HexColor("#D1B7A0")
    FREESIA = HexColor("#F3C12C")
    FRENCH_BLUE = HexColor("#0072B5")
    FRENCH_ROAST = HexColor("#58423F")
    FRENCH_VANILLA = HexColor("#EFE1A7")
    FRESH_SALMON = HexColor("#FF7F6A")
    FRIAR_BROWN = HexColor("#6E493A")
    FROST = HexColor("#DDE2D6")
    FROST_GRAY = HexColor("#848283")
    FROSTED_ALMOND = HexColor("#D2C2AC")
    FROSTY_GREEN = HexColor("#A3B5A6")
    FROSTY_SPRUCE = HexColor("#578270")
    FROZEN_DEW = HexColor("#D8CFB2")
    FRUIT_DOVE = HexColor("#CE5B78")
    FUCHSIA_PINK = HexColor("#DF88B7")
    FUCHSIA_PURPLE = HexColor("#D33479")
    FUCHSIA_RED = HexColor("#AB3475")
    FUCHSIA_ROSE = HexColor("#C74375")
    FUDGE = HexColor("#493338")
    FUDGESICKLE = HexColor("#63403A")
    FUNGI = HexColor("#8F8177")
    FUSION_CORAL = HexColor("#FF8576")

    GALAPAGOS_GREEN = HexColor("#29685F")
    GALAXY_BLUE = HexColor("#2A4B7C")
    GANACHE = HexColor("#34292A")
    GARDEN_GLADE = HexColor("#DCD8A8")
    GARDEN_GREEN = HexColor("#495E35")
    GARDEN_TOPIARY = HexColor("#3E524B")
    GARDENIA = HexColor("#F1E8DF")
    GARGOYLE = HexColor("#686767")
    GARNET = HexColor("#953640")
    GARNET_ROSE = HexColor("#AC4B55")
    GENTIAN_VIOLET = HexColor("#544275")
    GEORGIA_PEACH = HexColor("#F97272")
    GERANIUM = HexColor("#DA3D58")
    GERANIUM_PINK = HexColor("#F6909D")
    GHOST_GRAY = HexColor("#9C9B98")
    GIBRALTAR_SEA = HexColor("#123850")
    GILDED_BEIGE = HexColor("#B39F8D")
    GINGER = HexColor("#C96551")
    GINGER_BREAD = HexColor("#8C4A2F")
    GINGER_ROOT = HexColor("#BFA58A")
    GINGER_SNAP = HexColor("#977D70")
    GINGER_SPICE = HexColor("#B65D48")
    GLACIER = HexColor("#C3DBD4")
    GLACIER_GRAY = HexColor("#C5C6C7")
    GLASS_GREEN = HexColor("#ECEAD0")
    GLAZED_GINGER = HexColor("#91552B")
    GLEAM = HexColor("#BFD1AD")
    GLOXINIA = HexColor("#622E5A")
    GOAT = HexColor("#A89A91")
    GOBLIN_BLUE = HexColor("#5F7278")
    GOJI_BERRY = HexColor("#B91228")
    GOLD_EARTH = HexColor("#DD9C6B")
    GOLD_FLAME = HexColor("#B45422")
    GOLD_FUSION = HexColor("#FFB000")
    GOLDEN_APRICOT = HexColor("#DDA758")
    GOLDEN_BROWN = HexColor("#91672F")
    GOLDEN_CREAM = HexColor("#F7B768")
    GOLDEN_FLEECE = HexColor("#F2D1A0")
    GOLDEN_GLOW = HexColor("#D99938")
    GOLDEN_GREEN = HexColor("#BDB369")
    GOLDEN_HAZE = HexColor("#FBD897")
    GOLDEN_KIWI = HexColor("#F3DD3E")
    GOLDEN_LIME = HexColor("#9A9738")
    GOLDEN_MIST = HexColor("#D5CD94")
    GOLDEN_NUGGET = HexColor("#DB9B59")
    GOLDEN_OAK = HexColor("#BE752D")
    GOLDEN_OCHRE = HexColor("#C77943")
    GOLDEN_OLIVE = HexColor("#AF9841")
    GOLDEN_ORANGE = HexColor("#D7942D")
    GOLDEN_PALM = HexColor("#AA8805")
    GOLDEN_POPPY = HexColor("#F56733")
    GOLDEN_ROD = HexColor("#E2A829")
    GOLDEN_SPICE = HexColor("#C6973F")
    GOLDEN_STRAW = HexColor("#E6BD8F")
    GOLDEN_YELLOW = HexColor("#CB8E16")
    GOLDFINCH = HexColor("#F8DC6C")
    GOLF_GREEN = HexColor("#008763")
    GOSSAMER_GREEN = HexColor("#B2CFBE")
    GOSSAMER_PINK = HexColor("#FAC8C3")
    GOTHIC_GRAPE = HexColor("#473951")
    GOTHIC_OLIVE = HexColor("#7C6E4F")
    GRANADA_SKY = HexColor("#5D81BB")
    GRANITA = HexColor("#A52350")
    GRANITE_GRAY = HexColor("#615E5F")
    GRANITE_GREEN = HexColor("#86A293")
    GRAPE = HexColor("#433455")
    GRAPE_COMPOTE = HexColor("#6B5876")
    GRAPE_JAM = HexColor("#725671")
    GRAPE_JUICE = HexColor("#682961")
    GRAPE_KISS = HexColor("#7B4368")
    GRAPE_LEAF = HexColor("#545144")
    GRAPE_NECTAR = HexColor("#8D5C74")
    GRAPE_ROYALE = HexColor("#4F2D54")
    GRAPE_SHAKE = HexColor("#886971")
    GRAPE_WINE = HexColor("#5A2F43")
    GRAPEADE = HexColor("#85677B")
    GRAPEMIST = HexColor("#8398CA")
    GRAPHITE = HexColor("#3B3B48")
    GRASS_GREEN = HexColor("#7BB369")
    GRASSHOPPER = HexColor("#77824A")
    GRAVEL = HexColor("#CBBFA2")
    GRAY_BLUE = HexColor("#4D587A")
    GRAY_DAWN = HexColor("#BBC1CC")
    GRAY_FLANNEL = HexColor("#848182")
    GRAY_GREEN = HexColor("#A49A79")
    GRAY_LILAC = HexColor("#D4CACD")
    GRAY_MIST = HexColor("#99AEAE")
    GRAY_MORN = HexColor("#CABEB5")
    GRAY_PINSTRIPE = HexColor("#49494D")
    GRAY_RIDGE = HexColor("#847986")
    GRAY_SAND = HexColor("#E5CCAF")
    GRAY_VIOLET = HexColor("#BBBCBC")
    GRAYED_JADE = HexColor("#9BBEA9")
    GRAYSTONE = HexColor("#4D495B")
    GREEN_ASH = HexColor("#A0DAA9")
    GREEN_BANANA = HexColor("#BABC72")
    GREEN_BAY = HexColor("#7E9285")
    GREEN_BLUE_SLATE = HexColor("#358082")
    GREEN_ESSENCE = HexColor("#E9EAC8")
    GREEN_EYES = HexColor("#7D956D")
    GREEN_FLASH = HexColor("#79C753")
    GREEN_GABLES = HexColor("#324241")
    GREEN_GLOW = HexColor("#B0C965")
    GREEN_HAZE = HexColor("#CAC4A4")
    GREEN_LILY = HexColor("#C1CEC1")
    GREEN_MILIEU = HexColor("#8A9992")
    GREEN_MOSS = HexColor("#857946")
    GREEN_OASIS = HexColor("#B0B454")
    GREEN_OLIVE = HexColor("#8D8B55")
    GREEN_SHEEN = HexColor("#D9CE52")
    GREEN_SPRUCE = HexColor("#589F7E")
    GREEN_SULPHUR = HexColor("#AE8E2C")
    GREEN_TEA = HexColor("#86A96F")
    GREEN_TINT = HexColor("#C5CCC0")
    GREENBRIAR = HexColor("#4B9B69")
    GREENER_PASTURES = HexColor("#37503D")
    GREENERY = HexColor("#88B04B")
    GREENGAGE = HexColor("#8BC28C")
    GREENLAKE = HexColor("#007D69")
    GREIGE = HexColor("#928475")
    GRENADINE = HexColor("#DF3F32")
    GRIFFIN = HexColor("#8D8F8F")
    GRISAILLE = HexColor("#585E6F")
    GUACAMOLE = HexColor("#797B3A")
    GULF_STREAM = HexColor("#88C3D0")
    GULL = HexColor("#918C8F")
    GULL_GRAY = HexColor("#A49CA0")
    GUMDROP_GREEN = HexColor("#2EA785")
    GUNMETAL = HexColor("#5C5D5B")

    HABANERO_GOLD = HexColor("#FED450")
    HALOGEN_BLUE = HexColor("#BDC6DC")
    HARBOR_BLUE = HexColor("#00656E")
    HARBOR_GRAY = HexColor("#A8C0BB")
    HARBOR_MIST = HexColor("#AFB1B4")
    HARVEST_GOLD = HexColor("#B68A3A")
    HARVEST_PUMPKIN = HexColor("#D56231")
    HAUTE_RED = HexColor("#A11729")
    HAWAIIAN_OCEAN = HexColor("#008DB9")
    HAWAIIAN_SUNSET = HexColor("#BB5C14")
    HAWAIIAN_SURF = HexColor("#0078A7")
    HAWTHORN_ROSE = HexColor("#884C5E")
    HAY = HexColor("#D3CCA3")
    HAZEL = HexColor("#AE7250")
    HAZELNUT = HexColor("#CFB095")
    HEATHER = HexColor("#B7C0D6")
    HEATHER_ROSE = HexColor("#AD6D7F")
    HEAVENLY_PINK = HexColor("#F4DEDE")
    HEDGE_GREEN = HexColor("#768A75")
    HEIRLOOM_LILAC = HexColor("#9D96B2")
    HELIOTROPE = HexColor("#4F3872")
    HEMLOCK = HexColor("#97C1A1")
    HEMP = HexColor("#C0AD7C")
    HENNA = HexColor("#7C423C")
    HERBAL_GARDEN = HexColor("#9CAD60")
    HERITAGE_BLUE = HexColor("#5D96BC")
    HERON = HexColor("#62617E")
    HIBISCUS = HexColor("#DD3848")
    HIGH_RISE = HexColor("#AEB2B5")
    HIGH_RISK_RED = HexColor("#C71F2D")
    HINT_OF_MINT = HexColor("#D8E8E6")
    HOLIDAY = HexColor("#81C3B4")
    HOLLY_BERRY = HexColor("#B44E5D")
    HOLLY_GREEN = HexColor("#0F9D76")
    HOLLYHOCK = HexColor("#823270")
    HONEY = HexColor("#BA9238")
    HONEY_GINGER = HexColor("#A86217")
    HONEY_GOLD = HexColor("#D1A054")
    HONEY_MUSTARD = HexColor("#B68F52")
    HONEY_PEACH = HexColor("#DCBD9E")
    HONEY_YELLOW = HexColor("#CA9456")
    HONEYDEW = HexColor("#BAE1D3")
    HONEYSUCKLE = HexColor("#D94F70")
    HORIZON_BLUE = HexColor("#289DBE")
    HORTENSIA = HexColor("#553B50")
    HOT_CHOCOLATE = HexColor("#683B39")
    HOT_CORAL = HexColor("#F35B53")
    HOT_PINK = HexColor("#E55982")
    HOT_SAUCE = HexColor("#AB4F41")
    HUCKLEBERRY = HexColor("#5B4349")
    HUMUS = HexColor("#B7A793")
    HUNTER_GREEN = HexColor("#335749")
    HUSHED_GREEN = HexColor("#D8E9E5")
    HUSHED_VIOLET = HexColor("#D1C0BF")
    HYACINTH = HexColor("#936CA7")
    HYACINTH_VIOLET = HexColor("#8D4687")
    HYDRANGEA = HexColor("#849BCC")
    HYDRO = HexColor("#426972")

    IBIS_ROSE = HexColor("#CA628F")
    IBIZA_BLUE = HexColor("#007CB7")
    ICE = HexColor("#E0E4D9")
    ICE_FLOW = HexColor("#C6D2D2")
    ICE_GREEN = HexColor("#87D8C3")
    ICEBERG_GREEN = HexColor("#8C9C92")
    ICED_AQUA = HexColor("#ABD3DB")
    ICED_COFFEE = HexColor("#B18F6A")
    ICELAND_POPPY = HexColor("#F4963A")
    ICELANDIC_BLUE = HexColor("#A9ADC2")
    ICICLE = HexColor("#DADCD0")
    ICY_MORN = HexColor("#B0D3D1")
    IGUANA = HexColor("#818455")
    ILLUSION_BLUE = HexColor("#C9D3DC")
    IMPALA = HexColor("#F8CE97")
    IMPATIENS_PINK = HexColor("#FFC4BC")
    IMPERIAL_BLUE = HexColor("#005A92")
    IMPERIAL_PALACE = HexColor("#604E7A")
    IMPERIAL_PURPLE = HexColor("#542C5D")
    INCA_GOLD = HexColor("#BB7A2C")
    INCENSE = HexColor("#AF9A7E")
    INDIA_INK = HexColor("#3C3F4A")
    INDIAN_TAN = HexColor("#AD8567")
    INDIAN_TEAL = HexColor("#3C586B")
    INDIGO = HexColor("#4C3957")
    INDIGO_BUNTING = HexColor("#006CA9")
    INFINITY = HexColor("#6E7E99")
    INK_BLUE = HexColor("#0B5369")
    INSIGNIA_BLUE = HexColor("#2F3E55")
    IOLITE = HexColor("#707BB4")
    IRIS = HexColor("#BAAFBC")
    IRIS_BLOOM = HexColor("#5B609E")
    IRIS_ORCHID = HexColor("#A767A2")
    IRISH_CREAM = HexColor("#C0AC92")
    IRISH_GREEN = HexColor("#45BE76")
    IRON = HexColor("#736460")
    IRON_GATE = HexColor("#4E5055")
    ISLAND_GREEN = HexColor("#2BAE66")
    ISLAND_PARADISE = HexColor("#95DEE3")
    ITALIAN_PLUM = HexColor("#533146")
    ITALIAN_STRAW = HexColor("#E7D1A1")
    IVORY_CREAM = HexColor("#DAC0A7")
    IVY = HexColor("#226C63")
    IVY_GREEN = HexColor("#585442")

    JACARANDA = HexColor("#848DC5")
    JADE_CREAM = HexColor("#60B892")
    JADE_GREEN = HexColor("#759465")
    JADE_LIME = HexColor("#A1CA7B")
    JADEITE = HexColor("#95A69F")
    JADESHEEN = HexColor("#77A276")
    JAFFA_ORANGE = HexColor("#D86D39")
    JALAPENO_RED = HexColor("#B2103C")
    JASMINE_GREEN = HexColor("#7EC845")
    JASPER = HexColor("#335959")
    JAVA = HexColor("#433331")
    JAZZY = HexColor("#B61C50")
    JELLY_BEAN = HexColor("#008658")
    JESTER_RED = HexColor("#9E1030")
    JET_BLACK = HexColor("#2D2C2F")
    JET_SET = HexColor("#262C2A")
    JET_STREAM = HexColor("#EDE6DE")
    JOJOBA = HexColor("#DABE81")
    JOLLY_GREEN = HexColor("#007844")
    JUNE_BUG = HexColor("#264A48")
    JUNGLE_GREEN = HexColor("#3C4E47")
    JUNIPER = HexColor("#3D7245")
    JURASSIC_GOLD = HexColor("#E7AA56")

    KALAMATA = HexColor("#5F5B4C")
    KALE = HexColor("#5A7247")
    KANGAROO = HexColor("#725E43")
    KASHMIR = HexColor("#6F8D6A")
    KATYDID = HexColor("#66BC91")
    KEEPSAKE_LILAC = HexColor("#C0A5AE")
    KELLY_GREEN = HexColor("#339C5E")
    KELP = HexColor("#988467")
    KENTUCKY_BLUE = HexColor("#A5B3CC")
    KETCHUP = HexColor("#9A382D")
    KHAKI = HexColor("#A39264")
    KIWI = HexColor("#7AAB55")
    KOI = HexColor("#D15837")
    KOMBU_GREEN = HexColor("#3A4032")
    KUMQUAT = HexColor("#FBAA4C")

    LAGOON = HexColor("#4D9E9A")
    LAKE_BLUE = HexColor("#008C96")
    LAMBS_WOOL = HexColor("#E5D0B1")
    LANGOUSTINO = HexColor("#CA6C56")
    LANGUID_LAVENDER = HexColor("#A2A1BA")
    LANTANA = HexColor("#DA7E7A")
    LAPIS = HexColor("#008684")
    LAPIS_BLUE = HexColor("#004B8D")
    LARK = HexColor("#B89B72")
    LARKSPUR = HexColor("#3C7D90")
    LATIGO_BAY = HexColor("#379190")
    LATTE = HexColor("#C5A582")
    LAUREL_GREEN = HexColor("#ADBBA1")
    LAUREL_OAK = HexColor("#918C7E")
    LAUREL_WREATH = HexColor("#616F65")
    LAVENDER = HexColor("#AFA4CE")
    LAVENDER_AURA = HexColor("#9F99AA")
    LAVENDER_BLUE = HexColor("#C5C0D0")
    LAVENDER_CRYSTAL = HexColor("#936A98")
    LAVENDER_FOG = HexColor("#D2C4D6")
    LAVENDER_FROST = HexColor("#BDABBE")
    LAVENDER_GRAY = HexColor("#9890A2")
    LAVENDER_HERB = HexColor("#B18EAA")
    LAVENDER_LUSTRE = HexColor("#8C9CC1")
    LAVENDER_MIST = HexColor("#AE90A7")
    LAVENDER_VIOLET = HexColor("#767BA5")
    LAVENDULA = HexColor("#BCA4CB")
    LEAD = HexColor("#7A898F")
    LEAD_GRAY = HexColor("#8A7963")
    LEAF_GREEN = HexColor("#9FAF6C")
    LEATHER_BROWN = HexColor("#97572B")
    LEEK_GREEN = HexColor("#B7B17A")
    LEGION_BLUE = HexColor("#1F495B")
    LEMON = HexColor("#F3BF08")
    LEMON_CHROME = HexColor("#FFC300")
    LEMON_CURRY = HexColor("#CDA323")
    LEMON_DROP = HexColor("#FDD878")
    LEMON_GRASS = HexColor("#DCD494")
    LEMON_ICING = HexColor("#F6EBC8")
    LEMON_MERINGUE = HexColor("#F6E199")
    LEMON_VERBENA = HexColor("#F3E779")
    LEMON_ZEST = HexColor("#F9D857")
    LEMONADE = HexColor("#F0E79D")
    LENTIL_SPROUT = HexColor("#ABA44D")
    LEPRECHAUN = HexColor("#378661")
    LETTUCE_GREEN = HexColor("#BED38E")
    LIBERTY = HexColor("#4D448A")
    LICHEN = HexColor("#9BC2B1")
    LICHEN_BLUE = HexColor("#5D89B3")
    LICORICE = HexColor("#3A3536")
    LIGHT_GRASS_GREEN = HexColor("#7CB68E")
    LIGHT_GRAY = HexColor("#DAD8C9")
    LIGHT_LILAC = HexColor("#DEC6D3")
    LIGHT_MAHOGANY = HexColor("#AD6D68")
    LIGHT_TAUPE = HexColor("#B19D8D")
    LIGHTEST_SKY = HexColor("#E4EADF")
    LILAC_ASH = HexColor("#D7CDCD")
    LILAC_BREEZE = HexColor("#B3A0C9")
    LILAC_CHIFFON = HexColor("#DE9BC4")
    LILAC_GRAY = HexColor("#9896A4")
    LILAC_HINT = HexColor("#D0D0DA")
    LILAC_MARBLE = HexColor("#C3BABF")
    LILAC_ROSE = HexColor("#BD4275")
    LILAC_SACHET = HexColor("#E9ADCA")
    LILAC_SNOW = HexColor("#E0C7D7")
    LILAS = HexColor("#B88995")
    LILY_GREEN = HexColor("#C5CF98")
    LILY_PAD = HexColor("#818F84")
    LILY_WHITE = HexColor("#E2E2DA")
    LIMA_BEAN = HexColor("#E1D590")
    LIME_CREAM = HexColor("#D7E8BC")
    LIME_GREEN = HexColor("#9FC131")
    LIME_POPSICLE = HexColor("#C0DB3A")
    LIME_PUNCH = HexColor("#C0D725")
    LIME_SHERBET = HexColor("#CDD78A")
    LIMEADE = HexColor("#D3D95F")
    LIMELIGHT = HexColor("#F0E87D")
    LIMESTONE = HexColor("#989A98")
    LIMOGES = HexColor("#243F6C")
    LIMPET_SHELL = HexColor("#98DDDE")
    LINDEN_GREEN = HexColor("#C4BF71")
    LINEN = HexColor("#EDD2C0")
    LINT = HexColor("#B6BA99")
    LION = HexColor("#A0714F")
    LIPSTICK_RED = HexColor("#B31A38")
    LITTLE_BOY_BLUE = HexColor("#6EA2D5")
    LIVING_CORAL = HexColor("#FF6F61")
    LIZARD = HexColor("#71643E")
    LOBSTER_BISQUE = HexColor("#DD9289")
    LODEN_FROST = HexColor("#788F74")
    LODEN_GREEN = HexColor("#6E7153")
    LOGANBERRY = HexColor("#5A4769")
    LOLLIPOP = HexColor("#CC1C3B")
    LONDON_FOG = HexColor("#A29E92")
    LOTUS = HexColor("#E2C1C0")
    LOVE_POTION = HexColor("#C01352")
    LUMINARY_GREEN = HexColor("#E3EAA5")
    LUNAR_ROCK = HexColor("#C5C5C5")
    LUPINE = HexColor("#BE9CC1")
    LUSH_MEADOW = HexColor("#006E51")
    LYCHEE = HexColor("#BA0B32")
    LYONS_BLUE = HexColor("#005871")

    MACADAMIA = HexColor("#E4CFB6")
    MACAROON = HexColor("#B38B71")
    MACAW_GREEN = HexColor("#9BB53E")
    MADDER_BROWN = HexColor("#6A3331")
    MAGENTA = HexColor("#D23C77")
    MAGENTA_HAZE = HexColor("#9D446E")
    MAGENTA_PURPLE = HexColor("#6B264B")
    MAGNET = HexColor("#4D4B4F")
    MAHOGANY = HexColor("#824D46")
    MAHOGANY_ROSE = HexColor("#C5A193")
    MAIZE = HexColor("#EEC843")
    MAJESTY = HexColor("#593761")
    MAJOLICA_BLUE = HexColor("#274357")
    MAJOR_BROWN = HexColor("#5B5149")
    MALACHITE_GREEN = HexColor("#709A89")
    MALAGA = HexColor("#9F5069")
    MALIBU_BLUE = HexColor("#008CC1")
    MALLARD_BLUE = HexColor("#3A5C6E")
    MALLARD_GREEN = HexColor("#405E5C")
    MANDARIN_ORANGE = HexColor("#EC6A37")
    MANDARIN_RED = HexColor("#E74A33")
    MANGO = HexColor("#B75E41")
    MANGO_MOJITO = HexColor("#D69C2F")
    MAPLE_SUGAR = HexColor("#C9A38D")
    MARGARITA = HexColor("#B5C38E")
    MARIGOLD = HexColor("#FADC53")
    MARINA = HexColor("#4F84C4")
    MARINE_BLUE = HexColor("#76AFB6")
    MARINE_GREEN = HexColor("#40A48E")
    MARITIME_BLUE = HexColor("#27293D")
    MARLIN = HexColor("#515B87")
    MARMALADE = HexColor("#C16512")
    MAROON = HexColor("#834655")
    MARRON = HexColor("#6E4C4B")
    MARS_RED = HexColor("#BC2731")
    MARSALA = HexColor("#964F4C")
    MARSHMALLOW = HexColor("#F0EEE4")
    MARTINI_OLIVE = HexColor("#716A4D")
    MARYS_ROSE = HexColor("#F7D1D4")
    MARZIPAN = HexColor("#D8C09D")
    MAUI_BLUE = HexColor("#52A2B4")
    MAUVE_CHALK = HexColor("#E5D0CF")
    MAUVE_MIST = HexColor("#C49BD4")
    MAUVE_MORN = HexColor("#ECD6D6")
    MAUVE_ORCHID = HexColor("#B58299")
    MAUVE_SHADOWS = HexColor("#B598A3")
    MAUVE_WINE = HexColor("#5B3644")
    MAUVEGLOW = HexColor("#D18489")
    MAUVEWOOD = HexColor("#A75D67")
    MAYFLY = HexColor("#65663F")
    MAZARINE_BLUE = HexColor("#273C76")
    MEADOW = HexColor("#8BBA94")
    MEADOW_GREEN = HexColor("#739957")
    MEADOW_MAUVE = HexColor("#A9568C")
    MEADOW_MIST = HexColor("#D3DEC4")
    MEADOW_VIOLET = HexColor("#764F82")
    MEADOWBROOK = HexColor("#60A0A3")
    MEADOWLARK = HexColor("#EAD94E")
    MECCA_ORANGE = HexColor("#BD5745")
    MEDAL_BRONZE = HexColor("#977547")
    MEDIEVAL_BLUE = HexColor("#29304E")
    MEDITERRANEA = HexColor("#32575D")
    MEDITERRANEAN_BLUE = HexColor("#1478A7")
    MEDIUM_GREEN = HexColor("#3C824E")
    MEERKAT = HexColor("#A46F44")
    MELLOW_BUFF = HexColor("#D8B998")
    MELLOW_GREEN = HexColor("#D5D593")
    MELLOW_MAUVE = HexColor("#996378")
    MELLOW_ROSE = HexColor("#D9A6A1")
    MELLOW_YELLOW = HexColor("#F0DD9D")
    MELON = HexColor("#FE8863")
    MERCURY = HexColor("#BAC2BA")
    MERLOT = HexColor("#72262C")
    MERMAID = HexColor("#817A65")
    MESA_ROSE = HexColor("#A66E7A")
    METAL = HexColor("#BABFBC")
    METEORITE = HexColor("#2B2929")
    METHYL_BLUE = HexColor("#0074A8")
    MICRO_CHIP = HexColor("#BABCC0")
    MIDNIGHT = HexColor("#325B74")
    MIDNIGHT_NAVY = HexColor("#34414E")
    MILITARY_OLIVE = HexColor("#63563B")
    MILKY_BLUE = HexColor("#72A8BA")
    MILKY_GREEN = HexColor("#CFDBD1")
    MIMOSA = HexColor("#F0C05A")
    MINERAL_BLUE = HexColor("#6D9192")
    MINERAL_GRAY = HexColor("#B2B6AC")
    MINERAL_GREEN = HexColor("#7A9B78")
    MINERAL_RED = HexColor("#B35457")
    MINERAL_YELLOW = HexColor("#D39C43")
    MING = HexColor("#7CB08A")
    MING_GREEN = HexColor("#3AA278")
    MINIMAL_GRAY = HexColor("#948D99")
    MINION_YELLOW = HexColor("#FED55D")
    MINK = HexColor("#734B42")
    MINT = HexColor("#00A170")
    MINT_GREEN = HexColor("#487D49")
    MINT_LEAF = HexColor("#00B694")
    MIRAGE_GRAY = HexColor("#ABAFAE")
    MIST_GREEN = HexColor("#AACEBC")
    MISTED_YELLOW = HexColor("#DAB965")
    MISTLETOE = HexColor("#8AA282")
    MISTY_BLUE = HexColor("#BFCDCC")
    MISTY_JADE = HexColor("#BCD9C8")
    MISTY_LILAC = HexColor("#BCB4C4")
    MISTY_ROSE = HexColor("#CAA39A")
    MOCHA_BISQUE = HexColor("#8C543A")
    MOCHA_MOUSSE = HexColor("#A47864")
    MOCK_ORANGE = HexColor("#FFA368")
    MOJAVE_DESERT = HexColor("#C7B595")
    MOLE = HexColor("#392D2B")
    MOLTEN_LAVA = HexColor("#B5332E")
    MONACO_BLUE = HexColor("#274374")
    MONKS_ROBE = HexColor("#704822")
    MONTANA_GRAPE = HexColor("#6C5971")
    MONUMENT = HexColor("#84898C")
    MOOD_INDIGO = HexColor("#353A4C")
    MOON_MIST = HexColor("#80817D")
    MOON_ROCK = HexColor("#958B84")
    MOONBEAM = HexColor("#CDC6BD")
    MOONLESS_NIGHT = HexColor("#2F2D30")
    MOONLIGHT = HexColor("#C5B1A0")
    MOONLIGHT_BLUE = HexColor("#506886")
    MOONLIGHT_JADE = HexColor("#C7E5DF")
    MOONLIT_OCEAN = HexColor("#293B4D")
    MOONLITE_MAUVE = HexColor("#D28FB0")
    MOONSCAPE = HexColor("#725F69")
    MOONSTRUCK = HexColor("#C2BEB6")
    MOREL = HexColor("#685C53")
    MORGANITE = HexColor("#DFCDC6")
    MORNING_GLORY = HexColor("#EE819F")
    MORNING_MIST = HexColor("#CFDFDB")
    MOROCCAN_BLUE = HexColor("#0F4E67")
    MOSAIC_BLUE = HexColor("#00758F")
    MOSS = HexColor("#A09D59")
    MOSS_GRAY = HexColor("#AFAB97")
    MOSSTONE = HexColor("#858961")
    MOTH = HexColor("#D2CBAF")
    MOTHER_OF_PEARL = HexColor("#E9D4C3")
    MOUNTAIN_VIEW = HexColor("#2E3D30")
    MOURNING_DOVE = HexColor("#94908B")
    MULBERRY = HexColor("#A76C97")
    MULBERRY_PURPLE = HexColor("#493C62")
    MULCH = HexColor("#433937")
    MULLED_GRAPE = HexColor("#675A74")
    MURMUR = HexColor("#D2D8D2")
    MUSHROOM = HexColor("#BDACA3")
    MUSKMELON = HexColor("#EC935E")
    MUSTANG = HexColor("#684B40")
    MUSTARD_GOLD = HexColor("#B08E51")
    MUTED_CLAY = HexColor("#D29380")
    MUTED_LIME = HexColor("#D1C87C")
    MYKONOS_BLUE = HexColor("#005780")
    MYRTLE = HexColor("#4F6B58")
    MYSTERIOSO = HexColor("#46394B")
    MYSTIC_BLUE = HexColor("#E1E3DE")
    MYSTICAL = HexColor("#5F4E72")

    NARCISSUS = HexColor("#C39449")
    NASTURTIUM = HexColor("#FE6347")
    NATURAL = HexColor("#AA907D")
    NAUTICAL_BLUE = HexColor("#1A5091")
    NAVAGIO_BAY = HexColor("#3183A0")
    NAVAJO = HexColor("#EFDCC3")
    NAVIGATE = HexColor("#008583")
    NAVY_BLAZER = HexColor("#282D3C")
    NAVY_BLUE = HexColor("#403F6F")
    NAVY_COSMOS = HexColor("#503B53")
    NAVY_PEONY = HexColor("#223A5E")
    NEBULAS_BLUE = HexColor("#2D62A3")
    NECTARINE = HexColor("#FF8656")
    NEPTUNE_GREEN = HexColor("#7FBB9E")
    NEUTRAL_GRAY = HexColor("#8E918F")
    NEW_WHEAT = HexColor("#D7B57F")
    NIAGARA = HexColor("#5487A4")
    NIGHT_SKY = HexColor("#2A2A35")
    NIGHTSHADE = HexColor("#433748")
    NIGHTSHADOW_BLUE = HexColor("#4E5368")
    NILE = HexColor("#B4BB85")
    NILE_BLUE = HexColor("#76A7AB")
    NILE_GREEN = HexColor("#A7C796")
    NIMBUS_CLOUD = HexColor("#D5D5D8")
    NINE_IRON = HexColor("#46434A")
    NIRVANA = HexColor("#A2919B")
    NOCTURNE = HexColor("#7A4B56")
    NOMAD = HexColor("#B49F89")
    NORSE_BLUE = HexColor("#4CA5C7")
    NORTH_ATLANTIC = HexColor("#536D70")
    NORTH_SEA = HexColor("#316C6B")
    NOSTALGIA_ROSE = HexColor("#A4777E")
    NOUGAT = HexColor("#B69885")
    NOVELLE_PEACH = HexColor("#E7CFBD")
    NUDE = HexColor("#F2D3BC")
    NUGGET = HexColor("#CF8848")
    NUGGET_GOLD = HexColor("#C89720")
    NUTMEG = HexColor("#7E5C54")
    NUTRIA = HexColor("#75663E")

    OAK_BUFF = HexColor("#CF9C63")
    OASIS = HexColor("#A3A04E")
    OATMEAL = HexColor("#CBC3B4")
    OBSIDIAN = HexColor("#3A363B")
    OCEAN_DEPTHS = HexColor("#006175")
    OCEAN_WAVE = HexColor("#8EC5B6")
    OCHRE = HexColor("#D6AF66")
    ODYSSEY_GRAY = HexColor("#434452")
    OIL_BLUE = HexColor("#658C88")
    OIL_GREEN = HexColor("#80856D")
    OIL_YELLOW = HexColor("#C4A647")
    OLD_GOLD = HexColor("#ECA825")
    OLD_ROSE = HexColor("#B47B77")
    OLIVE_BRANCH = HexColor("#646A45")
    OLIVE_DRAB = HexColor("#756D47")
    OLIVE_GRAY = HexColor("#A6997A")
    OLIVE_NIGHT = HexColor("#535040")
    OLIVE_OIL = HexColor("#A98B2D")
    OLIVENITE = HexColor("#C1A65C")
    OLIVINE = HexColor("#666B54")
    OLYMPIAN_BLUE = HexColor("#1A4C8B")
    OMBRE_BLUE = HexColor("#434854")
    OMPHALODES = HexColor("#B5CEDF")
    ONLINE_LIME = HexColor("#44883C")
    OPAL = HexColor("#77CFB7")
    OPAL_BLUE = HexColor("#C3DDD6")
    OPAL_GRAY = HexColor("#A49E9E")
    OPALINE_GREEN = HexColor("#A3C57D")
    OPERA_MAUVE = HexColor("#CA80B1")
    ORANGE_CHIFFON = HexColor("#F9AA7D")
    ORANGE_COM = HexColor("#DA321C")
    ORANGE_OCHRE = HexColor("#DC793A")
    ORANGE_PEEL = HexColor("#FA7A35")
    ORANGE_PEPPER = HexColor("#DF7500")
    ORANGE_POPSICLE = HexColor("#FF7913")
    ORANGE_RUST = HexColor("#C25A3C")
    ORANGE_TIGER = HexColor("#F96714")
    ORANGEADE = HexColor("#E2552C")
    ORCHID = HexColor("#D198C5")
    ORCHID_BLOOM = HexColor("#C5AECF")
    ORCHID_BOUQUET = HexColor("#D1ACCE")
    ORCHID_HAZE = HexColor("#B0879B")
    ORCHID_HUSH = HexColor("#CEC3D2")
    ORCHID_ICE = HexColor("#E0D0DB")
    ORCHID_MIST = HexColor("#917798")
    ORCHID_PETAL = HexColor("#BFB4CB")
    ORCHID_PINK = HexColor("#F3BBCA")
    ORCHID_SMOKE = HexColor("#D294AA")
    ORCHID_TINT = HexColor("#DBD2DB")
    ORIENT_BLUE = HexColor("#47457A")
    ORION_BLUE = HexColor("#3E4F5C")
    OTTER = HexColor("#7F674F")
    OUTER_SPACE = HexColor("#2F3441")
    OVERCAST = HexColor("#C3BDAB")
    OXBLOOD_RED = HexColor("#70393F")
    OXFORD_TAN = HexColor("#B8A99A")
    OYSTER_GRAY = HexColor("#CBC1AE")
    OYSTER_MUSHROOM = HexColor("#C3C6C8")
    OYSTER_WHITE = HexColor("#D2CAAF")

    PACIFIC = HexColor("#1F595C")
    PACIFIC_COAST = HexColor("#5480AC")
    PAGODA_BLUE = HexColor("#1A7F8E")
    PAISLEY_PURPLE = HexColor("#8B79B1")
    PALACE_BLUE = HexColor("#346CB0")
    PALE_AQUA = HexColor("#C1CCC2")
    PALE_BANANA = HexColor("#FAE199")
    PALE_BLUE = HexColor("#C4D6D3")
    PALE_BLUSH = HexColor("#E4BFB3")
    PALE_DOGWOOD = HexColor("#EDCDC2")
    PALE_GOLD = HexColor("#BD9865")
    PALE_GREEN = HexColor("#CBCE91")
    PALE_IRIS = HexColor("#8895C5")
    PALE_KHAKI = HexColor("#BFAF92")
    PALE_LILAC = HexColor("#E1C6CC")
    PALE_LIME_YELLOW = HexColor("#DFE69F")
    PALE_MARIGOLD = HexColor("#FFC66E")
    PALE_MAUVE = HexColor("#C6A4A4")
    PALE_OLIVE_GREEN = HexColor("#B5AD88")
    PALE_PEACH = HexColor("#FED1BD")
    PALM = HexColor("#AFAF5E")
    PALOMA = HexColor("#9F9C99")
    PAMPAS = HexColor("#CFBB7B")
    PANSY = HexColor("#653D7C")
    PAPAYA = HexColor("#FEA166")
    PAPAYA_PUNCH = HexColor("#FCA289")
    PAPRIKA = HexColor("#CE4D42")
    PAPYRUS = HexColor("#F5EDD6")
    PARACHUTE_PURPLE = HexColor("#392852")
    PARADISE_GREEN = HexColor("#B2E79F")
    PARADISE_PINK = HexColor("#E4445E")
    PARAKEET = HexColor("#008C69")
    PARASAILING = HexColor("#00736C")
    PARCHMENT = HexColor("#DFD1BE")
    PARFAIT_PINK = HexColor("#E9C3CF")
    PARISIAN_BLUE = HexColor("#4F7CA4")
    PARISIAN_NIGHT = HexColor("#323441")
    PARROT_GREEN = HexColor("#8DB051")
    PARSNIP = HexColor("#D6C69A")
    PARTRIDGE = HexColor("#725440")
    PASSION_FLOWER = HexColor("#6D5698")
    PASTEL_BLUE = HexColor("#BCD3D5")
    PASTEL_GREEN = HexColor("#B4D3B2")
    PASTEL_LAVENDER = HexColor("#D8A1C4")
    PASTEL_LILAC = HexColor("#BDB0D0")
    PASTEL_PARCHMENT = HexColor("#E5D9D3")
    PASTEL_ROSE_TAN = HexColor("#E9D1BF")
    PASTEL_TURQUOISE = HexColor("#99C5C4")
    PASTEL_YELLOW = HexColor("#F2E6B1")
    PASTRY_SHELL = HexColor("#BD8C66")
    PATINA_GREEN = HexColor("#B9EAB3")
    PATRICIAN_PURPLE = HexColor("#6C4E79")
    PATRIOT_BLUE = HexColor("#363756")
    PAVEMENT = HexColor("#524D50")
    PEACH = HexColor("#F2A987")
    PEACH_AMBER = HexColor("#FB9F93")
    PEACH_BEIGE = HexColor("#D3A297")
    PEACH_BLOOM = HexColor("#D99B7C")
    PEACH_BLOSSOM = HexColor("#DE8286")
    PEACH_BLUSH = HexColor("#E4CCC6")
    PEACH_BUD = HexColor("#FDB2AB")
    PEACH_CARAMEL = HexColor("#C5733D")
    PEACH_COBBLER = HexColor("#FFB181")
    PEACH_DUST = HexColor("#F0D8CC")
    PEACH_ECHO = HexColor("#F7786B")
    PEACH_FUZZ = HexColor("#FFBE98")
    PEACH_MELBA = HexColor("#FBBDAF")
    PEACH_NECTAR = HexColor("#FFB59B")
    PEACH_NOUGAT = HexColor("#E6AF91")
    PEACH_PARFAIT = HexColor("#F8BFA8")
    PEACH_PEARL = HexColor("#FFB2A5")
    PEACH_PINK = HexColor("#FA9A85")
    PEACH_PUREE = HexColor("#EFCFBA")
    PEACH_QUARTZ = HexColor("#F5B895")
    PEACH_WHIP = HexColor("#DBBEB7")
    PEACHES_N_CREAM = HexColor("#F4A6A3")
    PEACHSKIN = HexColor("#DFB8B6")
    PEACHY_KEEN = HexColor("#E2BDB3")
    PEACOAT = HexColor("#2B2E43")
    PEACOCK_BLUE = HexColor("#00A0B0")
    PEACOCK_GREEN = HexColor("#00A78B")
    PEAPOD = HexColor("#82B185")
    PEAR_SORBET = HexColor("#F3EAC3")
    PEARL = HexColor("#F9DBD8")
    PEARL_BLUE = HexColor("#B0B7BE")
    PEARL_BLUSH = HexColor("#F4CEC5")
    PEARLED_IVORY = HexColor("#F0DFCC")
    PEAT = HexColor("#3B3A36")
    PEBBLE = HexColor("#CAB698")
    PECAN_BROWN = HexColor("#A36E51")
    PELICAN = HexColor("#C1BCAC")
    PEONY = HexColor("#ED9CA8")
    PEPPER_GREEN = HexColor("#007D60")
    PEPPERCORN = HexColor("#6C5656")
    PEPPERMINT = HexColor("#699E6D")
    PERIDOT = HexColor("#819548")
    PERISCOPE = HexColor("#46444C")
    PERSIAN_JEWEL = HexColor("#6E81BE")
    PERSIAN_RED = HexColor("#A21441")
    PERSIAN_VIOLET = HexColor("#8C8EB2")
    PERSIMMON = HexColor("#F67866")
    PERSIMMON_ORANGE = HexColor("#F47327")
    PESTO = HexColor("#595F34")
    PETAL_PINK = HexColor("#F2E2E0")
    PETIT_FOUR = HexColor("#87C2D4")
    PETRIFIED_OAK = HexColor("#8D7960")
    PETUNIA = HexColor("#4F3466")
    PEWTER = HexColor("#666564")
    PEYOTE = HexColor("#C5BBAE")
    PHANTOM = HexColor("#39373B")
    PHANTOM_GREEN = HexColor("#DCE4D7")
    PHEASANT = HexColor("#C68463")
    PHLOX = HexColor("#692D5D")
    PHLOX_PINK = HexColor("#CE5E9A")
    PICANTE = HexColor("#8D3F2D")
    PICASSO_LILY = HexColor("#634878")
    PICKLED_BEET = HexColor("#4D233D")
    PIGEON = HexColor("#A9AFAA")
    PINE_BARK = HexColor("#827064")
    PINE_GREEN = HexColor("#3A795E")
    PINE_GROVE = HexColor("#213631")
    PINEAPPLE_SLICE = HexColor("#E7D391")
    PINECONE = HexColor("#61473B")
    PINENEEDLE = HexColor("#334D41")
    PINK_CARNATION = HexColor("#ED7A9E")
    PINK_DOGWOOD = HexColor("#F7D1D1")
    PINK_FLAMBE = HexColor("#D3507A")
    PINK_ICING = HexColor("#EEA0A6")
    PINK_LADY = HexColor("#EFC1D6")
    PINK_LAVENDER = HexColor("#D9AFCA")
    PINK_LEMONADE = HexColor("#EE6D8A")
    PINK_MIST = HexColor("#E6BCCD")
    PINK_NECTAR = HexColor("#D8AAB7")
    PINK_PEACOCK = HexColor("#C62168")
    PINK_SALT = HexColor("#F7CDC7")
    PINK_SAND = HexColor("#DFB19B")
    PINK_TINT = HexColor("#DBCBBD")
    PINK_YARROW = HexColor("#CE3175")
    PIQUANT_GREEN = HexColor("#769358")
    PIRATE_BLACK = HexColor("#363838")
    PISTACHIO_GREEN = HexColor("#A9D39E")
    PISTACHIO_SHELL = HexColor("#D7CFBB")
    PLACID_BLUE = HexColor("#8CADD3")
    PLANTATION = HexColor("#7A6332")
    PLAZA_TAUPE = HexColor("#AEA393")
    PLEIN_AIR = HexColor("#BFCAD6")
    PLUM = HexColor("#5A315D")
    PLUM_CASPIA = HexColor("#61224A")
    PLUM_JAM = HexColor("#624076")
    PLUM_KITTEN = HexColor("#625B5C")
    PLUM_PERFECT = HexColor("#473442")
    PLUM_PURPLE = HexColor("#51304E")
    PLUM_TRUFFLE = HexColor("#675657")
    PLUM_WINE = HexColor("#674550")
    PLUME = HexColor("#A5CFD5")
    POINCIANA = HexColor("#CA3422")
    POINSETTIA = HexColor("#CB3441")
    POISON_GREEN = HexColor("#4DB560")
    POLIGNAC = HexColor("#C28799")
    POMEGRANATE = HexColor("#6C2831")
    POMPEIAN_RED = HexColor("#A4292E")
    PONDEROSA_PINE = HexColor("#203B3D")
    POOL_BLUE = HexColor("#67BCB3")
    POOL_GREEN = HexColor("#00AF9D")
    POPCORN = HexColor("#F8DE8D")
    POPPY_RED = HexColor("#DC343B")
    PORCELAIN = HexColor("#5D9CA4")
    PORCELAIN_BLUE = HexColor("#95C0CB")
    PORCELAIN_GREEN = HexColor("#108780")
    PORCELAIN_ROSE = HexColor("#EA6B6A")
    PORCINI = HexColor("#CCA580")
    PORPOISE = HexColor("#A7A19E")
    PORT = HexColor("#663336")
    PORT_ROYALE = HexColor("#502B33")
    PORTABELLA = HexColor("#937B6A")
    POSEIDON = HexColor("#123955")
    POSY_GREEN = HexColor("#325B51")
    POTENT_PURPLE = HexColor("#462639")
    POTPOURRI = HexColor("#E7C9CA")
    POTTERS_CLAY = HexColor("#9E4624")
    POTTING_SOIL = HexColor("#54392D")
    POWDER_BLUE = HexColor("#96B3D2")
    POWDER_PINK = HexColor("#ECB2B3")
    POWDER_PUFF = HexColor("#F3E0D6")
    PRAIRIE_SAND = HexColor("#B59A6A")
    PRAIRIE_SUNSET = HexColor("#FFBB9E")
    PRALINE = HexColor("#AD8B75")
    PRIMROSE_PINK = HexColor("#EED4D9")
    PRIMROSE_YELLOW = HexColor("#F6D155")
    PRINCESS_BLUE = HexColor("#00539C")
    PRISM_PINK = HexColor("#F0A1BF")
    PRISM_VIOLET = HexColor("#53357D")
    PRISTINE = HexColor("#F2E8DA")
    PROVENCE = HexColor("#658DC6")
    PROVINCIAL_BLUE = HexColor("#5C798E")
    PRUNE = HexColor("#603749")
    PRUNE_PURPLE = HexColor("#5C3A4D")
    PUCE = HexColor("#503938")
    PUFFINS_BILL = HexColor("#E95C20")
    PUMICE_STONE = HexColor("#CAC2B9")
    PUMPKIN = HexColor("#F5A26F")
    PUMPKIN_SPICE = HexColor("#A05C17")
    PURE_CASHMERE = HexColor("#ADA396")
    PUREED_PUMPKIN = HexColor("#C34121")
    PURITAN_GRAY = HexColor("#A8B0AE")
    PURPLE_ASH = HexColor("#8F8395")
    PURPLE_CORALLITE = HexColor("#5A4E8F")
    PURPLE_DOVE = HexColor("#98878C")
    PURPLE_GUMDROP = HexColor("#7A596F")
    PURPLE_HAZE = HexColor("#807396")
    PURPLE_HEART = HexColor("#745587")
    PURPLE_HEATHER = HexColor("#BAB8D3")
    PURPLE_IMPRESSION = HexColor("#858FB1")
    PURPLE_MAGIC = HexColor("#663271")
    PURPLE_OPULENCE = HexColor("#60569A")
    PURPLE_ORCHID = HexColor("#AD4D8C")
    PURPLE_PASSION = HexColor("#683D62")
    PURPLE_PENNANT = HexColor("#432C47")
    PURPLE_PLUMERIA = HexColor("#473854")
    PURPLE_POTION = HexColor("#692746")
    PURPLE_REIGN = HexColor("#56456B")
    PURPLE_ROSE = HexColor("#B09FCA")
    PURPLE_SAGE = HexColor("#75697E")
    PURPLE_SAPPHIRE = HexColor("#6F4685")
    PURPLE_VELVET = HexColor("#41354D")
    PURPLE_WINE = HexColor("#8C3573")
    PUSSYWILLOW_GRAY = HexColor("#AEACA1")
    PUTTY = HexColor("#D4CAB0")

    QUAIL = HexColor("#98868C")
    QUARRY = HexColor("#98A0A5")
    QUARTZ_PINK = HexColor("#EFA6AA")
    QUETZAL_GREEN = HexColor("#006865")
    QUICKSILVER = HexColor("#7E7D88")
    QUIET_GRAY = HexColor("#B9BABD")
    QUIET_GREEN = HexColor("#9EBC97")
    QUIET_HARBOR = HexColor("#5A789A")
    QUIET_SHADE = HexColor("#66676D")

    RABBIT = HexColor("#5F575C")
    RACING_RED = HexColor("#BD162C")
    RADIANT_ORCHID = HexColor("#AD5E99")
    RADIANT_YELLOW = HexColor("#FC9E21")
    RAFFIA = HexColor("#DAC483")
    RAIN_DRUM = HexColor("#5F4C40")
    RAIN_FOREST = HexColor("#15463E")
    RAINDROPS = HexColor("#B1AAB3")
    RAINY_DAY = HexColor("#CFC8BD")
    RAISIN = HexColor("#524144")
    RAPTURE_ROSE = HexColor("#D16277")
    RASPBERRY = HexColor("#D32E5E")
    RASPBERRY_RADIANCE = HexColor("#802A50")
    RASPBERRY_ROSE = HexColor("#CC4385")
    RASPBERRY_SORBET = HexColor("#D2386C")
    RASPBERRY_WINE = HexColor("#B63753")
    RATTAN = HexColor("#D1B272")
    RAVEN = HexColor("#413E3D")
    RAW_SIENNA = HexColor("#B9714F")
    RAW_UMBER = HexColor("#92705F")
    RAWHIDE = HexColor("#865E49")
    REAL_TEAL = HexColor("#405D73")
    RED_BUD = HexColor("#962D49")
    RED_CLAY = HexColor("#C2452D")
    RED_DAHLIA = HexColor("#7D2027")
    RED_MAHOGANY = HexColor("#60373D")
    RED_OCHRE = HexColor("#913832")
    RED_ORANGE = HexColor("#F05627")
    RED_PEAR = HexColor("#7B3539")
    RED_PLUM = HexColor("#7C2946")
    RED_VIOLET = HexColor("#A35776")
    REDWOOD = HexColor("#A6594C")
    REED = HexColor("#C3D3A8")
    REED_YELLOW = HexColor("#DCC99E")
    REEF_WATERS = HexColor("#6F9FA9")
    REFLECTING_POND = HexColor("#203E4A")
    REGAL_ORCHID = HexColor("#A98BAF")
    REGATTA = HexColor("#487AB7")
    RENAISSANCE_ROSE = HexColor("#865560")
    RESEDA = HexColor("#A1AD92")
    RHAPSODY = HexColor("#9F86AA")
    RHODODENDRON = HexColor("#722B3F")
    RHUBARB = HexColor("#77202F")
    RIBBON_RED = HexColor("#B92636")
    RICH_GOLD = HexColor("#C8B273")
    RIFLE_GREEN = HexColor("#414832")
    RIO_RED = HexColor("#8A2232")
    RIVER_BLUE = HexColor("#38AFCD")
    RIVERSIDE = HexColor("#4C6A92")
    RIVIERA = HexColor("#5879A2")
    ROAN_ROUGE = HexColor("#885157")
    ROASTED_CASHEW = HexColor("#918579")
    ROASTED_PECAN = HexColor("#93592B")
    ROCK_RIDGE = HexColor("#918C86")
    ROCKY_ROAD = HexColor("#5A3E36")
    ROCOCCO_RED = HexColor("#BB363F")
    ROEBUCK = HexColor("#B09080")
    ROOIBOS_TEA = HexColor("#A23C26")
    ROOT_BEER = HexColor("#714A41")
    ROSE_BROWN = HexColor("#80565B")
    ROSE_CLOUD = HexColor("#DBB0A2")
    ROSE_DAWN = HexColor("#C2877B")
    ROSE_DUST = HexColor("#CDB2A5")
    ROSE_OF_SHARON = HexColor("#DC5B62")
    ROSE_QUARTZ = HexColor("#F7CAC9")
    ROSE_RED = HexColor("#C92351")
    ROSE_SHADOW = HexColor("#F9C2CD")
    ROSE_SMOKE = HexColor("#D3B4AD")
    ROSE_TAN = HexColor("#D19C97")
    ROSE_TAUPE = HexColor("#806062")
    ROSE_VIOLET = HexColor("#C0428A")
    ROSE_WATER = HexColor("#F8E0E7")
    ROSE_WINE = HexColor("#A4596D")
    ROSEBLOOM = HexColor("#E290B2")
    ROSEBUD = HexColor("#B65F9A")
    ROSETTE = HexColor("#CE8E8B")
    ROSEWATER = HexColor("#F6DBD8")
    ROSEWOOD = HexColor("#813639")
    ROSIN = HexColor("#36362D")
    ROUGE_RED = HexColor("#E24666")
    ROYAL_BLUE = HexColor("#3D428B")
    ROYAL_LILAC = HexColor("#774D8E")
    ROYAL_PURPLE = HexColor("#603F83")
    RUBBER = HexColor("#815B37")
    RUBY_WINE = HexColor("#77333B")
    RUGBY_TAN = HexColor("#C2A594")
    RUM_RAISIN = HexColor("#583432")
    RUMBA_RED = HexColor("#7C2439")
    RUSSET = HexColor("#8F5F50")
    RUSSET_BROWN = HexColor("#743332")
    RUSSET_ORANGE = HexColor("#E47127")
    RUST = HexColor("#B55A30")
    RUSTIC_BROWN = HexColor("#855141")
    RUTABAGA = HexColor("#ECDDBE")

    SABLE = HexColor("#6E403C")
    SACHET_PINK = HexColor("#F18AAD")
    SAFARI = HexColor("#BAAA91")
    SAFFRON = HexColor("#FFA500")
    SAGE = HexColor("#91946E")
    SAGE_GREEN = HexColor("#B2AC88")
    SAGEBRUSH_GREEN = HexColor("#567572")
    SAHARA_SUN = HexColor("#DFC08A")
    SAILOR_BLUE = HexColor("#0E3A53")
    SALMON = HexColor("#FAAA94")
    SALMON_BUFF = HexColor("#FEAA7B")
    SALMON_ROSE = HexColor("#FF8D94")
    SALSA = HexColor("#AA182B")
    SALUTE = HexColor("#282B34")
    SAMBA = HexColor("#A2242F")
    SAMOAN_SUN = HexColor("#FBC85F")
    SAND = HexColor("#CCA67F")
    SAND_DOLLAR = HexColor("#DECDBE")
    SAND_VERBENA = HexColor("#9F90C1")
    SANDSHELL = HexColor("#D8CCBB")
    SANDSTONE = HexColor("#C48A69")
    SANDSTORM = HexColor("#BD8B69")
    SANGRIA = HexColor("#982551")
    SAP_GREEN = HexColor("#AFCB80")
    SARGASSO_SEA = HexColor("#35435A")
    SASSAFRAS = HexColor("#54353B")
    SATELLITE = HexColor("#9F8D89")
    SAUTERNE = HexColor("#C5A253")
    SAXONY_BLUE = HexColor("#1F6680")
    SCALLOP_SHELL = HexColor("#FBD8C9")
    SCARAB = HexColor("#23312D")
    SCARLET = HexColor("#BC2B3D")
    SCARLET_IBIS = HexColor("#F45520")
    SCARLET_SAGE = HexColor("#9D202F")
    SCOOTER = HexColor("#941E32")
    SCUBA_BLUE = HexColor("#00ABC0")
    SEA_ANGEL = HexColor("#98BFCA")
    SEA_BLUE = HexColor("#549F98")
    SEA_FOAM = HexColor("#B7C2B2")
    SEA_FOG = HexColor("#A5929D")
    SEA_GREEN = HexColor("#149C88")
    SEA_MIST = HexColor("#D8C9A3")
    SEA_MOSS = HexColor("#254445")
    SEA_PINE = HexColor("#4C6969")
    SEA_PINK = HexColor("#DE98AB")
    SEA_SALT = HexColor("#F1E6DE")
    SEA_SPRAY = HexColor("#717E6F")
    SEA_TURTLE = HexColor("#5E5749")
    SEACREST = HexColor("#BFD1B3")
    SEAFOAM_GREEN = HexColor("#CBD5B1")
    SEAGRASS = HexColor("#959889")
    SEAL_BROWN = HexColor("#493B39")
    SEAPORT = HexColor("#005E7D")
    SEASHELL_PINK = HexColor("#F7C8C2")
    SEDONA_SAGE = HexColor("#686D6C")
    SEEDLING = HexColor("#C0CBA1")
    SEEDPEARL = HexColor("#E6DAC4")
    SEMOLINA = HexColor("#CEB899")
    SENECA_ROCK = HexColor("#9A927F")
    SEPIA = HexColor("#6B543E")
    SEPIA_ROSE = HexColor("#D4BAB6")
    SEPIA_TINT = HexColor("#897560")
    SEQUOIA = HexColor("#804839")
    SERENITY = HexColor("#91A8D0")
    SESAME = HexColor("#BAA38B")
    SHADED_SPRUCE = HexColor("#00585E")
    SHADOW = HexColor("#888D82")
    SHADOW_GRAY = HexColor("#BBA5A0")
    SHADOW_GREEN = HexColor("#CFC486")
    SHADOW_LIME = HexColor("#CFE09D")
    SHADOW_PURPLE = HexColor("#4E334E")
    SHADY_GLADE = HexColor("#006E5B")
    SHALE = HexColor("#4A3F41")
    SHALE_GREEN = HexColor("#739072")
    SHAMROCK = HexColor("#6FA26B")
    SHARK = HexColor("#6D636B")
    SHARKSKIN = HexColor("#838487")
    SHARP_GREEN = HexColor("#C6EC7A")
    SHAVED_CHOCOLATE = HexColor("#543B35")
    SHEEPSKIN = HexColor("#DAB58F")
    SHEER_LILAC = HexColor("#B793C0")
    SHEER_PINK = HexColor("#F6E5DB")
    SHELL = HexColor("#E1CFC6")
    SHELL_CORAL = HexColor("#EA9575")
    SHELL_PINK = HexColor("#F88180")
    SHIFTING_SAND = HexColor("#D8C0AD")
    SHITAKE = HexColor("#736253")
    SHOCKING_PINK = HexColor("#DE5B8C")
    SHOPPING_BAG = HexColor("#5A4743")
    SHRIMP = HexColor("#E29A86")
    SHRINKING_VIOLET = HexColor("#F4E1E6")
    SIERRA = HexColor("#985C41")
    SILT_GREEN = HexColor("#A9BDB1")
    SILVER = HexColor("#A2A2A1")
    SILVER_BIRCH = HexColor("#D2CFC4")
    SILVER_BLUE = HexColor("#8A9A9A")
    SILVER_BULLET = HexColor("#81839A")
    SILVER_CLOUD = HexColor("#BEB7B0")
    SILVER_FERN = HexColor("#BBAA7E")
    SILVER_FILIGREE = HexColor("#7F7C81")
    SILVER_GRAY = HexColor("#C1B7B0")
    SILVER_GREEN = HexColor("#D7D7C7")
    SILVER_LAKE_BLUE = HexColor("#618BB9")
    SILVER_LINING = HexColor("#BDB6AB")
    SILVER_MINK = HexColor("#9F8D7C")
    SILVER_PEONY = HexColor("#E7CFC7")
    SILVER_PINE = HexColor("#4E6866")
    SILVER_PINK = HexColor("#DCB1AF")
    SILVER_SAGE = HexColor("#938B78")
    SILVER_SCONCE = HexColor("#A19FA5")
    SIMPLY_GREEN = HexColor("#009B75")
    SIMPLY_TAUPE = HexColor("#AD9F93")
    SIROCCO = HexColor("#C39D88")
    SKI_PATROL = HexColor("#BB1237")
    SKIPPER_BLUE = HexColor("#484A72")
    SKY_BLUE = HexColor("#8ABAD3")
    SKY_CAPTAIN = HexColor("#262934")
    SKY_GRAY = HexColor("#BCC8C6")
    SKYDIVER = HexColor("#00589B")
    SKYLIGHT = HexColor("#C8E0E0")
    SKYWAY = HexColor("#ADBED3")
    SLATE = HexColor("#8C9FA1")
    SLATE_BLACK = HexColor("#4B3D33")
    SLATE_GRAY = HexColor("#8A9691")
    SLATE_GREEN = HexColor("#A0987C")
    SLATE_ROSE = HexColor("#B45865")
    SLEET = HexColor("#92949B")
    SMOKE = HexColor("#BFC8C3")
    SMOKE_BLUE = HexColor("#6D8994")
    SMOKE_GRAY = HexColor("#CEBAA8")
    SMOKE_GREEN = HexColor("#A8BBA2")
    SMOKE_PINE = HexColor("#3E6257")
    SMOKED_PAPRIKA = HexColor("#6E362C")
    SMOKED_PEARL = HexColor("#656466")
    SMOKY_GRAPE = HexColor("#B88AAC")
    SNAPDRAGON = HexColor("#FED777")
    SNORKEL_BLUE = HexColor("#034F84")
    SNOW_WHITE = HexColor("#F2F0EB")
    SODALITE_BLUE = HexColor("#253668")
    SOFT_PINK = HexColor("#F2D8CD")
    SOLAR_POWER = HexColor("#F4BF3A")
    SOOTHING_SEA = HexColor("#C3E9E4")
    SOUTHERN_MOSS = HexColor("#BCA66A")
    SOYBEAN = HexColor("#D2C29D")
    SPA_BLUE = HexColor("#D3DEDF")
    SPANISH_VILLA = HexColor("#DFBAA9")
    SPARKLING_GRAPE = HexColor("#773376")
    SPARROW = HexColor("#69595C")
    SPEARMINT = HexColor("#64BFA4")
    SPECTRA_GREEN = HexColor("#009B8C")
    SPECTRA_YELLOW = HexColor("#F7B718")
    SPECTRUM_BLUE = HexColor("#3D3C7C")
    SPHINX = HexColor("#AB9895")
    SPICE_ROUTE = HexColor("#B95B3F")
    SPICED_APPLE = HexColor("#783937")
    SPICED_CORAL = HexColor("#D75C5D")
    SPICED_PLUM = HexColor("#6D4773")
    SPICY_MUSTARD = HexColor("#D8AE47")
    SPICY_ORANGE = HexColor("#D73C26")
    SPINACH_GREEN = HexColor("#909B4C")
    SPLIT_PEA = HexColor("#9C9A40")
    SPONGE = HexColor("#A49775")
    SPRAY = HexColor("#BED3BB")
    SPRAY_GREEN = HexColor("#AEA692")
    SPRING_BOUQUET = HexColor("#6DCE87")
    SPRING_BUD = HexColor("#6BCD9C")
    SPRING_CROCUS = HexColor("#BA69A1")
    SPROUT_GREEN = HexColor("#CBD7D2")
    SPRUCE_YELLOW = HexColor("#BE8A4A")
    SPRUCESTONE = HexColor("#9FC09C")
    STAR_SAPPHIRE = HexColor("#386192")
    STAR_WHITE = HexColor("#EFEFE8")
    STARFISH = HexColor("#B09A77")
    STARGAZER = HexColor("#39505C")
    STARLIGHT_BLUE = HexColor("#B5CED4")
    STEEL_GRAY = HexColor("#726F70")
    STEEPLE_GRAY = HexColor("#827E7C")
    STELLAR = HexColor("#46647E")
    STERLING_BLUE = HexColor("#A2B9C2")
    STILLWATER = HexColor("#70A4B0")
    STONE_BLUE = HexColor("#829CA5")
    STONE_GRAY = HexColor("#685E4F")
    STONE_GREEN = HexColor("#658E67")
    STONEWASH = HexColor("#74809A")
    STORM = HexColor("#035453")
    STORM_BLUE = HexColor("#47788A")
    STORM_FRONT = HexColor("#787376")
    STORM_GRAY = HexColor("#B5BAB6")
    STORMY_SEA = HexColor("#6E8082")
    STORMY_WEATHER = HexColor("#58646D")
    STRATOSPHERE = HexColor("#9EC1CC")
    STRAW = HexColor("#E0C992")
    STRAWBERRY_CREAM = HexColor("#F4C3C4")
    STRAWBERRY_ICE = HexColor("#E78B90")
    STRAWBERRY_PINK = HexColor("#F57F8E")
    STRETCH_LIMO = HexColor("#2B2C30")
    STRIKING_PURPLE = HexColor("#944E87")
    STRING = HexColor("#AA9F96")
    STRONG_BLUE = HexColor("#1F5DA0")
    STUCCO = HexColor("#A58D7F")
    SUBTLE_GREEN = HexColor("#B5CBBB")
    SUDAN_BROWN = HexColor("#AC6B29")
    SUGAR_ALMOND = HexColor("#935529")
    SUGAR_CORAL = HexColor("#F56C73")
    SUGAR_SWIZZLE = HexColor("#F3EEE7")
    SULPHUR = HexColor("#DDB614")
    SULPHUR_SPRING = HexColor("#D5D717")
    SUMMER_FIG = HexColor("#BE4B3B")
    SUMMER_GREEN = HexColor("#7ED37F")
    SUMMER_MELON = HexColor("#EAD3AE")
    SUMMER_SHOWER = HexColor("#E5EBE3")
    SUN_BAKED = HexColor("#D27F63")
    SUN_DRIED_TOMATO = HexColor("#752329")
    SUN_KISS = HexColor("#EBD1BB")
    SUN_ORANGE = HexColor("#F48037")
    SUNBURN = HexColor("#B37256")
    SUNBURST = HexColor("#F6C289")
    SUNDRESS = HexColor("#EBCF89")
    SUNFLOWER = HexColor("#D39237")
    SUNKIST_CORAL = HexColor("#EA6676")
    SUNLIGHT = HexColor("#EDD59E")
    SUNLIT_ALLIUM = HexColor("#9787BB")
    SUNNY_LIME = HexColor("#DFEF87")
    SUNSET_GOLD = HexColor("#F7C46C")
    SUNSET_PURPLE = HexColor("#6F456E")
    SUNSHINE = HexColor("#FADE85")
    SUPER_LEMON = HexColor("#E4BF45")
    SUPER_PINK = HexColor("#CE6BA4")
    SURF_SPRAY = HexColor("#B4C8C2")
    SURF_THE_WEB = HexColor("#203C7F")
    SWAMP = HexColor("#A8B197")
    SWEDISH_BLUE = HexColor("#007EB1")
    SWEET_CREAM = HexColor("#F0EAD6")
    SWEET_GRAPE = HexColor("#4B3B4F")
    SWEET_LAVENDER = HexColor("#9A9BC1")
    SWEET_LILAC = HexColor("#E8B5CE")
    SWEET_PEA = HexColor("#A3A969")
    SYCAMORE = HexColor("#35463D")
    SYLVAN_GREEN = HexColor("#E7EACB")
    SYRAH = HexColor("#6A282C")

    TAFFY = HexColor("#C39B6A")
    TAHITIAN_TIDE = HexColor("#006B7E")
    TAN = HexColor("#B69574")
    TANAGER_TURQUOISE = HexColor("#91DCE8")
    TANDORI_SPICE = HexColor("#9F4440")
    TANGELO = HexColor("#FE7E03")
    TANGERINE = HexColor("#F88F58")
    TANGERINE_TANGO = HexColor("#DD4124")
    TANGO_RED = HexColor("#AC0E2E")
    TANNIN = HexColor("#A68A6D")
    TAOS_TAUPE = HexColor("#BFA77F")
    TAP_SHOE = HexColor("#2A2B2D")
    TAPENADE = HexColor("#805D24")
    TAPESTRY = HexColor("#436573")
    TAPIOCA = HexColor("#DCCDBC")
    TARMAC = HexColor("#5A5348")
    TARRAGON = HexColor("#A4AE77")
    TAUPE_GRAY = HexColor("#8E7C71")
    TAWNY_BIRCH = HexColor("#AE856C")
    TAWNY_BROWN = HexColor("#AB856F")
    TAWNY_OLIVE = HexColor("#C4962C")
    TAWNY_ORANGE = HexColor("#D37F6F")
    TAWNY_PORT = HexColor("#5C2C35")
    TEA = HexColor("#999B85")
    TEA_ROSE = HexColor("#DC7178")
    TEABERRY = HexColor("#DC3855")
    TEAK = HexColor("#655341")
    TEAL = HexColor("#478589")
    TEAL_BLUE = HexColor("#007F7C")
    TEAL_GREEN = HexColor("#006361")
    TEMPEST = HexColor("#79839B")
    TENDER_GREENS = HexColor("#C5CFB6")
    TENDER_PEACH = HexColor("#F8D5B8")
    TENDER_SHOOTS = HexColor("#B5CC39")
    TENDER_YELLOW = HexColor("#EDEDB7")
    TENDRIL = HexColor("#89A06B")
    TERRA_COTTA = HexColor("#D38377")
    THAI_CURRY = HexColor("#AB6819")
    THISTLE = HexColor("#B9B3C5")
    THISTLE_DOWN = HexColor("#9499BB")
    THRUSH = HexColor("#936B4F")
    THYME = HexColor("#50574C")
    TIBETAN_RED = HexColor("#782A39")
    TIBETAN_STONE = HexColor("#82C2C7")
    TIDAL_FOAM = HexColor("#BFB9A3")
    TIDEPOOL = HexColor("#0A6F69")
    TIGERLILY = HexColor("#E2583E")
    TIGERS_EYE = HexColor("#977C61")
    TILE_BLUE = HexColor("#008491")
    TILLANDSIA_PURPLE = HexColor("#563474")
    TIMBER_WOLF = HexColor("#8D8070")
    TINSEL = HexColor("#C3964D")
    TIRAMISU = HexColor("#634235")
    TITANIUM = HexColor("#807D7F")
    TOADSTOOL = HexColor("#988088")
    TOAST = HexColor("#CA9978")
    TOASTED_ALMOND = HexColor("#D2B49C")
    TOASTED_COCONUT = HexColor("#8B6A4F")
    TOASTED_NUT = HexColor("#C08768")
    TOBACCO_BROWN = HexColor("#9A7352")
    TOFFEE = HexColor("#755139")
    TOFU = HexColor("#E8E3D9")
    TOMATO = HexColor("#CE2939")
    TOMATO_CREAM = HexColor("#C57644")
    TOMATO_PUREE = HexColor("#C53346")
    TOPAZ = HexColor("#D08344")
    TOREADOR = HexColor("#B61032")
    TORNADO = HexColor("#5E5B60")
    TORTOISE_SHELL = HexColor("#754734")
    TOTAL_ECLIPSE = HexColor("#2C313D")
    TOURMALINE = HexColor("#86A1A9")
    TRADEWINDS = HexColor("#7F8793")
    TRANSPARENT_YELLOW = HexColor("#F4ECC2")
    TRAVERTINE = HexColor("#AE997D")
    TREE_HOUSE = HexColor("#988C75")
    TREETOP = HexColor("#476A30")
    TREKKING_GREEN = HexColor("#355048")
    TRELLIS = HexColor("#6A8988")
    TROOPER = HexColor("#697A7E")
    TROPICAL_GREEN = HexColor("#008786")
    TROPICAL_PEACH = HexColor("#FFC4B2")
    TRUE_BLUE = HexColor("#1E4477")
    TRUE_NAVY = HexColor("#3F5277")
    TRUE_RED = HexColor("#BF1932")
    TUFFET = HexColor("#A59788")
    TULIPWOOD = HexColor("#805466")
    TURBULENCE = HexColor("#4E545B")
    TURF_GREEN = HexColor("#6F8C69")
    TURKISH_COFFEE = HexColor("#483F39")
    TURKISH_SEA = HexColor("#195190")
    TURKISH_TILE = HexColor("#00698B")
    TURMERIC = HexColor("#FE840E")
    TURQUOISE = HexColor("#45B5AA")
    TURTLE_GREEN = HexColor("#81894E")
    TURTLEDOVE = HexColor("#DED7C8")
    TUSCANY = HexColor("#BE9785")
    TWILIGHT_BLUE = HexColor("#313D64")
    TWILIGHT_MAUVE = HexColor("#8B6F70")
    TWILIGHT_PURPLE = HexColor("#66648B")
    TWILL = HexColor("#A79B82")
    TWIST_OF_LIME = HexColor("#4E632C")

    ULTRA_VIOLET = HexColor("#5F4B8B")
    ULTRAMARINE = HexColor("#5B7EBD")
    ULTRAMARINE_GREEN = HexColor("#006B54")
    UMBER = HexColor("#944A1F")
    URBAN_CHIC = HexColor("#464E4D")

    VALERIAN = HexColor("#9F7A93")
    VALIANT_POPPY = HexColor("#BC322C")
    VALLARTA_BLUE = HexColor("#30658E")
    VANILLA = HexColor("#F4E1C1")
    VANILLA_CREAM = HexColor("#F4D8C6")
    VANILLA_CUSTARD = HexColor("#F3E0BE")
    VANILLA_ICE = HexColor("#F0EADA")
    VAPOR_BLUE = HexColor("#BEBDBD")
    VAPOROUS_GRAY = HexColor("#DFDDD7")
    VEILED_ROSE = HexColor("#F8CDC9")
    VELVET_MORNING = HexColor("#60688D")
    VERDANT_GREEN = HexColor("#12674A")
    VERMILLION_ORANGE = HexColor("#F9633B")
    VERONICA = HexColor("#6D6695")
    VERY_BERRY = HexColor("#B73275")
    VERY_GRAPE = HexColor("#927288")
    VETIVER = HexColor("#807D6F")
    VIBRANT_GREEN = HexColor("#55A860")
    VIBRANT_ORANGE = HexColor("#FF7420")
    VIBRANT_YELLOW = HexColor("#FFDA29")
    VICTORIA_BLUE = HexColor("#08589D")
    VINEYARD_GREEN = HexColor("#5F7355")
    VINEYARD_WINE = HexColor("#58363D")
    VINTAGE_INDIGO = HexColor("#4A556B")
    VINTAGE_KHAKI = HexColor("#9A9186")
    VINTAGE_VIOLET = HexColor("#634F62")
    VIOLA = HexColor("#A692BA")
    VIOLET = HexColor("#C17FB5")
    VIOLET_ICE = HexColor("#C2ACB1")
    VIOLET_INDIGO = HexColor("#3E285C")
    VIOLET_QUARTZ = HexColor("#8B4963")
    VIOLET_STORM = HexColor("#5C619D")
    VIOLET_TULIP = HexColor("#9E91C3")
    VIOLET_TULLE = HexColor("#C193C0")
    VIRIDIAN_GREEN = HexColor("#009499")
    VIRIDIS = HexColor("#00846B")
    VIRTUAL_PINK = HexColor("#C6174E")
    VISTA_BLUE = HexColor("#81A0D4")
    VIVACIOUS = HexColor("#A32857")
    VIVID_BLUE = HexColor("#0088B0")
    VIVID_GREEN = HexColor("#009E82")
    VIVID_VIOLA = HexColor("#993C7C")
    VOLCANIC_GLASS = HexColor("#615C60")
    VULCAN = HexColor("#2D3036")

    WALNUT = HexColor("#776A5F")
    WAN_BLUE = HexColor("#CBDCDF")
    WARM_APRICOT = HexColor("#FFB865")
    WARM_OLIVE = HexColor("#C7B63C")
    WARM_SAND = HexColor("#C5AE91")
    WARM_TAUPE = HexColor("#AF9483")
    WASABI = HexColor("#73A89E")
    WATER_LILY = HexColor("#DDE3D5")
    WATERCRESS = HexColor("#748C69")
    WATERFALL = HexColor("#3AB0A2")
    WAX_YELLOW = HexColor("#EDE9AD")
    WEDGEWOOD = HexColor("#6479B3")
    WEEPING_WILLOW = HexColor("#B3B17B")
    WET_WEATHER = HexColor("#929090")
    WHEAT = HexColor("#DEC5A5")
    WHISPER_GREEN = HexColor("#E0E6D7")
    WHISPER_PINK = HexColor("#DACBBE")
    WHISPER_WHITE = HexColor("#EDE6DB")
    WHISPERING_BLUE = HexColor("#C9DCDC")
    WHITE_ALYSSUM = HexColor("#EFEBE7")
    WHITE_ASPARAGUS = HexColor("#E1DBC8")
    WHITE_JADE = HexColor("#D4DBB2")
    WHITE_PEPPER = HexColor("#B6A893")
    WHITE_SAND = HexColor("#DBD5D1")
    WHITE_SMOKE = HexColor("#EDDCC9")
    WHITE_SWAN = HexColor("#E4D7C5")
    WHITECAP_GRAY = HexColor("#E0D5C6")
    WILD_ASTER = HexColor("#92316F")
    WILD_DOVE = HexColor("#8B8C89")
    WILD_GINGER = HexColor("#7C4C53")
    WILD_LIME = HexColor("#C3D363")
    WILD_ORCHID = HexColor("#D979A2")
    WILD_ROSE = HexColor("#CE8498")
    WILLOW = HexColor("#9A8B4F")
    WILLOW_BOUGH = HexColor("#59754D")
    WILLOWHERB = HexColor("#8E4483")
    WIND_CHIME = HexColor("#CAC5C2")
    WINDSOR_WINE = HexColor("#582B36")
    WINEBERRY = HexColor("#5A395B")
    WINETASTING = HexColor("#492A34")
    WINSOME_ORCHID = HexColor("#D4B9CB")
    WINTER_BLOOM = HexColor("#47243B")
    WINTER_GREEN = HexColor("#4F9E81")
    WINTER_MOSS = HexColor("#5B5A41")
    WINTER_PEAR = HexColor("#B0B487")
    WINTER_SKY = HexColor("#A9C0CB")
    WINTER_TWIG = HexColor("#948A7A")
    WINTER_WHEAT = HexColor("#DFC09F")
    WINTER_WHITE = HexColor("#F5ECD2")
    WISTERIA = HexColor("#A198AF")
    WISTFUL_MAUVE = HexColor("#946C74")
    WITHERED_ROSE = HexColor("#A26666")
    WOOD_ASH = HexColor("#D7CAB0")
    WOOD_THRUSH = HexColor("#A47D43")
    WOOD_VIOLET = HexColor("#75406A")
    WOODBINE = HexColor("#7B7F32")
    WOODROSE = HexColor("#AE8C8E")
    WOODSMOKE = HexColor("#947764")
    WREN = HexColor("#4A4139")
    WROUGHT_IRON = HexColor("#999E98")

    XENON_BLUE = HexColor("#B7C0D7")

    YAM = HexColor("#D0893F")
    YARROW = HexColor("#FACE6D")
    YELLOW_CREAM = HexColor("#EFDC75")
    YELLOW_IRIS = HexColor("#EEE78E")
    YELLOW_PEAR = HexColor("#ECE99B")
    YOLK_YELLOW = HexColor("#E2B051")
    YOUNG_WHEAT = HexColor("#E1E3A9")
    YUCCA = HexColor("#A1D7C9")

    ZEN_BLUE = HexColor("#9FA9BE")
    ZEPHYR = HexColor("#C89FA5")
    ZEPHYR_BLUE = HexColor("#D3D9D1")
    ZEPHYR_GREEN = HexColor("#7CB083")
    ZINC = HexColor("#92898A")
    ZINFANDEL = HexColor("#5C2935")
    ZINNIA = HexColor("#FFA010")

    @staticmethod
    def get_matching_color(color: Color) -> typing.Tuple[str, Color]:
        """
        Find the closest Pantone color that visually matches the given color.

        This method accepts a `Color` object and determines the closest
        `PantoneColor` based on visual similarity. It returns a tuple
        containing the name of the closest matching Pantone color and
        the corresponding `PantoneColor` object.

        :param color: The `Color` object to match.
        :return: A tuple containing the name of the closest
                 Pantone color and the corresponding
                 PantoneColor object.
        """
        from borb.pdf.color.rgb_color import RGBColor

        rgb_color_0: RGBColor = color.to_rgb_color()
        min_distance: typing.Optional[int] = None
        min_color_name: typing.Optional[str] = None
        min_color: typing.Optional[Color] = None
        for name in dir(PantoneColor):
            try:
                rgb_color_1: RGBColor = getattr(PantoneColor, name)
                distance = (
                    (rgb_color_0.get_red() - rgb_color_1.get_red()) ** 2
                    + (rgb_color_0.get_green() - rgb_color_1.get_green()) ** 2
                    + (rgb_color_0.get_blue() - rgb_color_1.get_blue()) ** 2
                )
                if min_distance is None or distance < min_distance:
                    min_distance = distance
                    min_color_name = name
                    min_color = rgb_color_1
            except:
                pass
        # fmt: off
        assert min_color_name is not None, "No matching color name was found; min_color_name is None."
        assert min_color is not None, "No matching color object was found; min_color is None."
        # fmt: on
        return min_color_name, min_color
