#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Represents an emoji, a logogram or ideogram used in electronic messages and web pages.

Emojis serve to provide emotional cues that are often missing from typed conversation.
Examples of emojis include 😃, 🧘🏻‍♂️, 🌍, 🍞, 🚗, 📞, 🎉, ♥️, 🍆, and 🏁.
They encompass various genres, including facial expressions, common objects, places, types of weather, and animals.

Unlike emoticons, which are typographic representations of emotions, emojis are graphical images.
The term "emoji" strictly refers to pictures that can be represented as encoded characters,
though it is sometimes extended to include messaging stickers.
"""
from borb.pdf.layout_element.image.emoji_a_k import EmojiAK
from borb.pdf.layout_element.image.emoji_l_z import EmojiLZ


class Emoji:
    """
    Represents an emoji, a logogram or ideogram used in electronic messages and web pages.

    Emojis serve to provide emotional cues that are often missing from typed conversation.
    Examples of emojis include 😃, 🧘🏻‍♂️, 🌍, 🍞, 🚗, 📞, 🎉, ♥️, 🍆, and 🏁.
    They encompass various genres, including facial expressions, common objects, places, types of weather, and animals.

    Unlike emoticons, which are typographic representations of emotions, emojis are graphical images.
    The term "emoji" strictly refers to pictures that can be represented as encoded characters,
    though it is sometimes extended to include messaging stickers.
    """

    #
    # CONSTRUCTOR
    #

    #
    # PRIVATE
    #

    #
    # PUBLIC
    #

    # fmt: off
    A = EmojiAK.A
    AB = EmojiAK.AB
    ABC = EmojiAK.ABC
    ABCD = EmojiAK.ABCD
    AERIAL_TRAMWAY = EmojiAK.AERIAL_TRAMWAY
    AIRPLANE = EmojiAK.AIRPLANE
    ALARM_CLOCK = EmojiAK.ALARM_CLOCK
    ALIEN = EmojiAK.ALIEN
    AMBULANCE = EmojiAK.AMBULANCE
    ANCHOR = EmojiAK.ANCHOR
    ANGEL = EmojiAK.ANGEL
    ANGER = EmojiAK.ANGER
    ANGRY = EmojiAK.ANGRY
    ANGUISHED = EmojiAK.ANGUISHED
    ANT = EmojiAK.ANT
    APPLE = EmojiAK.APPLE
    AQUARIUS = EmojiAK.AQUARIUS
    ARIES = EmojiAK.ARIES
    ARROWS_CLOCKWISE = EmojiAK.ARROWS_CLOCKWISE
    ARROWS_COUNTERCLOCKWISE = EmojiAK.ARROWS_COUNTERCLOCKWISE
    ARROWS_RIGHT_TWISTED = EmojiAK.ARROWS_RIGHT_TWISTED
    ARROW_BACKWARD = EmojiAK.ARROW_BACKWARD
    ARROW_DOUBLE_DOWN = EmojiAK.ARROW_DOUBLE_DOWN
    ARROW_DOUBLE_UP = EmojiAK.ARROW_DOUBLE_UP
    ARROW_DOWN = EmojiAK.ARROW_DOWN
    ARROW_DOWN_HOOK = EmojiAK.ARROW_DOWN_HOOK
    ARROW_DOWN_SMALL = EmojiAK.ARROW_DOWN_SMALL
    ARROW_FORWARD = EmojiAK.ARROW_FORWARD
    ARROW_LEFT = EmojiAK.ARROW_LEFT
    ARROW_LEFT_HOOK = EmojiAK.ARROW_LEFT_HOOK
    ARROW_LEFT_RIGHT = EmojiAK.ARROW_LEFT_RIGHT
    ARROW_LOWER_LEFT = EmojiAK.ARROW_LOWER_LEFT
    ARROW_LOWER_RIGHT = EmojiAK.ARROW_LOWER_RIGHT
    ARROW_RIGHT = EmojiAK.ARROW_RIGHT
    ARROW_RIGHT_HOOK = EmojiAK.ARROW_RIGHT_HOOK
    ARROW_UP = EmojiAK.ARROW_UP
    ARROW_UPPER_LEFT = EmojiAK.ARROW_UPPER_LEFT
    ARROW_UPPER_RIGHT = EmojiAK.ARROW_UPPER_RIGHT
    ARROW_UP_DOWN = EmojiAK.ARROW_UP_DOWN
    ARROW_UP_HOOK = EmojiAK.ARROW_UP_HOOK
    ARROW_UP_SMALL = EmojiAK.ARROW_UP_SMALL
    ART = EmojiAK.ART
    ARTICULATED_LORRY = EmojiAK.ARTICULATED_LORRY
    ASTONISHED = EmojiAK.ASTONISHED
    ATM = EmojiAK.ATM
    # fmt: on

    # fmt: off
    B = EmojiAK.B
    BABY = EmojiAK.BABY
    BABY_BOTTLE = EmojiAK.BABY_BOTTLE
    BABY_CHICK = EmojiAK.BABY_CHICK
    BABY_SYMBOL = EmojiAK.BABY_SYMBOL
    BAGAGE_CLAIM = EmojiAK.BAGAGE_CLAIM
    BALLOON = EmojiAK.BALLOON
    BALLOT_BOX_WITH_CHECK = EmojiAK.BALLOT_BOX_WITH_CHECK
    BAMBOO = EmojiAK.BAMBOO
    BANANA = EmojiAK.BANANA
    BANG_BANG = EmojiAK.BANG_BANG
    BANK = EmojiAK.BANK
    BARBER = EmojiAK.BARBER
    BAR_CHART = EmojiAK.BAR_CHART
    BASEBALL = EmojiAK.BASEBALL
    BASKETBALL = EmojiAK.BASKETBALL
    BATH = EmojiAK.BATH
    BATHTUB = EmojiAK.BATHTUB
    BATTERY = EmojiAK.BATTERY
    BEAR = EmojiAK.BEAR
    BEER = EmojiAK.BEER
    BEERS = EmojiAK.BEERS
    BEETLE = EmojiAK.BEETLE
    BEGINNER = EmojiAK.BEGINNER
    BELL = EmojiAK.BELL
    BENTO = EmojiAK.BENTO
    BICYCLIST = EmojiAK.BICYCLIST
    BIKE = EmojiAK.BIKE
    BIKINI = EmojiAK.BIKINI
    BIRD = EmojiAK.BIRD
    BIRTHDAY = EmojiAK.BIRTHDAY
    BLACK_CIRCLE = EmojiAK.BLACK_CIRCLE
    BLACK_JOKER = EmojiAK.BLACK_JOKER
    BLACK_NIB = EmojiAK.BLACK_NIB
    BLACK_SQUARE_BUTTON = EmojiAK.BLACK_SQUARE_BUTTON
    BLOSSOM = EmojiAK.BLOSSOM
    BLOWFISH = EmojiAK.BLOWFISH
    BLUE_BOOK = EmojiAK.BLUE_BOOK
    BLUE_CAR = EmojiAK.BLUE_CAR
    BLUE_CIRCLE = EmojiAK.BLUE_CIRCLE
    BLUE_DIAMOND = EmojiAK.BLUE_DIAMOND
    BLUE_HEART = EmojiAK.BLUE_HEART
    BLUSH = EmojiAK.BLUSH
    BOAR = EmojiAK.BOAR
    BOAT = EmojiAK.BOAT
    BOMB = EmojiAK.BOMB
    BOOK = EmojiAK.BOOK
    BOOKMARK = EmojiAK.BOOKMARK
    BOOKMARK_TABS = EmojiAK.BOOKMARK_TABS
    BOOKS = EmojiAK.BOOKS
    BOOM = EmojiAK.BOOM
    BOOT = EmojiAK.BOOT
    BORB = EmojiAK.BORB
    BORB_STICKER = EmojiAK.BORB_STICKER
    BOUQUET = EmojiAK.BOUQUET
    BOW = EmojiAK.BOW
    BOWLING = EmojiAK.BOWLING
    BOWTIE = EmojiAK.BOWTIE
    BOY = EmojiAK.BOY
    BREAD = EmojiAK.BREAD
    BRIDE_WITH_VEIL = EmojiAK.BRIDE_WITH_VEIL
    BRIDGE_AT_NIGHT = EmojiAK.BRIDGE_AT_NIGHT
    BRIEFCASE = EmojiAK.BRIEFCASE
    BROKEN_HEART = EmojiAK.BROKEN_HEART
    BUG = EmojiAK.BUG
    BULB = EmojiAK.BULB
    BULLETTRAIN_FRONT = EmojiAK.BULLETTRAIN_FRONT
    BULLETTRAIN_SIDE = EmojiAK.BULLETTRAIN_SIDE
    BUS = EmojiAK.BUS
    BUSSTOP = EmojiAK.BUSSTOP
    BUSTS_IN_SILHOUETTE = EmojiAK.BUSTS_IN_SILHOUETTE
    BUST_IN_SILHOUETTE = EmojiAK.BUST_IN_SILHOUETTE
    # fmt: on

    # fmt: off
    CACTUS = EmojiAK.CACTUS
    CAKE = EmojiAK.CAKE
    CALENDAR = EmojiAK.CALENDAR
    CALLING = EmojiAK.CALLING
    CAMEL = EmojiAK.CAMEL
    CAMERA = EmojiAK.CAMERA
    CANCER = EmojiAK.CANCER
    CANDY = EmojiAK.CANDY
    CAPITAL_ABCD = EmojiAK.CAPITAL_ABCD
    CAPRICORN = EmojiAK.CAPRICORN
    CAR = EmojiAK.CAR
    CARD_INDEX = EmojiAK.CARD_INDEX
    CAROUSEL_HORSE = EmojiAK.CAROUSEL_HORSE
    CAT = EmojiAK.CAT
    CAT_2 = EmojiAK.CAT_2
    CD = EmojiAK.CD
    CHART = EmojiAK.CHART
    CHART_WITH_DOWNWARDS_TREND = EmojiAK.CHART_WITH_DOWNWARDS_TREND
    CHART_WITH_UPWARDS_TREND = EmojiAK.CHART_WITH_UPWARDS_TREND
    CHECKERED_FLAG = EmojiAK.CHECKERED_FLAG
    CHERRIES = EmojiAK.CHERRIES
    CHERRY_BLOSSOM = EmojiAK.CHERRY_BLOSSOM
    CHESTNUT = EmojiAK.CHESTNUT
    CHICKEN = EmojiAK.CHICKEN
    CHILDREN_CROSSING = EmojiAK.CHILDREN_CROSSING
    CHOCOLATE_BAR = EmojiAK.CHOCOLATE_BAR
    CHRISTMAS_TREE = EmojiAK.CHRISTMAS_TREE
    CHURCH = EmojiAK.CHURCH
    CINEMA = EmojiAK.CINEMA
    CIRCUS_TENT = EmojiAK.CIRCUS_TENT
    CITY_SUNRISE = EmojiAK.CITY_SUNRISE
    CITY_SUNSET = EmojiAK.CITY_SUNSET
    CL = EmojiAK.CL
    CLAP = EmojiAK.CLAP
    CLAPPER = EmojiAK.CLAPPER
    CLIPBOARD = EmojiAK.CLIPBOARD
    CLOCK_1 = EmojiAK.CLOCK_1
    CLOCK_10 = EmojiAK.CLOCK_10
    CLOCK_10_30 = EmojiAK.CLOCK_10_30
    CLOCK_11 = EmojiAK.CLOCK_11
    CLOCK_11_30 = EmojiAK.CLOCK_11_30
    CLOCK_12 = EmojiAK.CLOCK_12
    CLOCK_12_30 = EmojiAK.CLOCK_12_30
    CLOCK_1_30 = EmojiAK.CLOCK_1_30
    CLOCK_2 = EmojiAK.CLOCK_2
    CLOCK_2_30 = EmojiAK.CLOCK_2_30
    CLOCK_3 = EmojiAK.CLOCK_3
    CLOCK_3_30 = EmojiAK.CLOCK_3_30
    CLOCK_4 = EmojiAK.CLOCK_4
    CLOCK_4_30 = EmojiAK.CLOCK_4_30
    CLOCK_5 = EmojiAK.CLOCK_5
    CLOCK_5_30 = EmojiAK.CLOCK_5_30
    CLOCK_6 = EmojiAK.CLOCK_6
    CLOCK_6_30 = EmojiAK.CLOCK_6_30
    CLOCK_7 = EmojiAK.CLOCK_7
    CLOCK_7_30 = EmojiAK.CLOCK_7_30
    CLOCK_8 = EmojiAK.CLOCK_8
    CLOCK_8_30 = EmojiAK.CLOCK_8_30
    CLOCK_9 = EmojiAK.CLOCK_9
    CLOCK_9_30 = EmojiAK.CLOCK_9_30
    CLOSED_BOOK = EmojiAK.CLOSED_BOOK
    CLOSED_LOCK_WITH_KEY = EmojiAK.CLOSED_LOCK_WITH_KEY
    CLOSED_UMBRELLA = EmojiAK.CLOSED_UMBRELLA
    CLOUD = EmojiAK.CLOUD
    CLUBS = EmojiAK.CLUBS
    CN = EmojiAK.CN
    COCKTAIL = EmojiAK.COCKTAIL
    COFFEE = EmojiAK.COFFEE
    COLLISION = EmojiAK.COLLISION
    COMPUTER = EmojiAK.COMPUTER
    CONFETTI_BALL = EmojiAK.CONFETTI_BALL
    CONFOUNDED = EmojiAK.CONFOUNDED
    CONFUSED = EmojiAK.CONFUSED
    CONSTRUCTION = EmojiAK.CONSTRUCTION
    CONSTRUCTION_WORKER = EmojiAK.CONSTRUCTION_WORKER
    CONVENIENCE_STORE = EmojiAK.CONVENIENCE_STORE
    COOKIE = EmojiAK.COOKIE
    COOL = EmojiAK.COOL
    COP = EmojiAK.COP
    COPYRIGHT = EmojiAK.COPYRIGHT
    CORN = EmojiAK.CORN
    COUPLE = EmojiAK.COUPLE
    COUPLEKISS = EmojiAK.COUPLEKISS
    COUPLE_WITH_HEART = EmojiAK.COUPLE_WITH_HEART
    COW = EmojiAK.COW
    COW_2 = EmojiAK.COW_2
    CREDIT_CARD = EmojiAK.CREDIT_CARD
    CROCODILE = EmojiAK.CROCODILE
    CROSSED_FLAGS = EmojiAK.CROSSED_FLAGS
    CROWN = EmojiAK.CROWN
    CRY = EmojiAK.CRY
    CRYING_CAT_FACE = EmojiAK.CRYING_CAT_FACE
    CRYSTAL_BALL = EmojiAK.CRYSTAL_BALL
    CUPID = EmojiAK.CUPID
    CURLY_LOOP = EmojiAK.CURLY_LOOP
    CURRENCY_EXCHANGE = EmojiAK.CURRENCY_EXCHANGE
    CURRY = EmojiAK.CURRY
    CUSTARD = EmojiAK.CUSTARD
    CUSTOMS = EmojiAK.CUSTOMS
    CYCLONE = EmojiAK.CYCLONE
    # fmt: on

    # fmt: off
    DANCER = EmojiAK.DANCER
    DANCERS = EmojiAK.DANCERS
    DANGO = EmojiAK.DANGO
    DART = EmojiAK.DART
    DASH = EmojiAK.DASH
    DATE = EmojiAK.DATE
    DE = EmojiAK.DE
    DECIDUOUS_TREE = EmojiAK.DECIDUOUS_TREE
    DEPARTMENT_STORE = EmojiAK.DEPARTMENT_STORE
    DIAMONDS = EmojiAK.DIAMONDS
    DIAMOND_SHAPE_WITH_DOT_INSIDE = EmojiAK.DIAMOND_SHAPE_WITH_DOT_INSIDE
    DISAPPOINTED = EmojiAK.DISAPPOINTED
    DISAPPOINTED_RELIEVED = EmojiAK.DISAPPOINTED_RELIEVED
    DIZZY = EmojiAK.DIZZY
    DIZZY_FACE = EmojiAK.DIZZY_FACE
    DOG = EmojiAK.DOG
    DOG_2 = EmojiAK.DOG_2
    DOLLAR = EmojiAK.DOLLAR
    DOLLS = EmojiAK.DOLLS
    DOLPHIN = EmojiAK.DOLPHIN
    DOOR = EmojiAK.DOOR
    DOUGHNUT = EmojiAK.DOUGHNUT
    DO_NOT_LITTER = EmojiAK.DO_NOT_LITTER
    DRAGON = EmojiAK.DRAGON
    DRAGON_FACE = EmojiAK.DRAGON_FACE
    DRESS = EmojiAK.DRESS
    DROMEDARY_CAMEL = EmojiAK.DROMEDARY_CAMEL
    DROPLET = EmojiAK.DROPLET
    DVD = EmojiAK.DVD
    # fmt: on

    # fmt: off
    EAR = EmojiAK.EAR
    EARTH_AFRICA = EmojiAK.EARTH_AFRICA
    EARTH_AMERICAS = EmojiAK.EARTH_AMERICAS
    EARTH_ASIA = EmojiAK.EARTH_ASIA
    EAR_OF_RICE = EmojiAK.EAR_OF_RICE
    EGG = EmojiAK.EGG
    EGGPLANT = EmojiAK.EGGPLANT
    EIGHT = EmojiAK.EIGHT
    EIGHT_POINTED_BLACK_STAR = EmojiAK.EIGHT_POINTED_BLACK_STAR
    EIGHT_POINTED_BLUE_STAR = EmojiAK.EIGHT_POINTED_BLUE_STAR
    ELECTRIC_PLUG = EmojiAK.ELECTRIC_PLUG
    ELEPHANT = EmojiAK.ELEPHANT
    EMAIL = EmojiAK.EMAIL
    END = EmojiAK.END
    ENVELOPE = EmojiAK.ENVELOPE
    ES = EmojiAK.ES
    EURO = EmojiAK.EURO
    EUROPEAN_CASTLE = EmojiAK.EUROPEAN_CASTLE
    EUROPEAN_POST_OFFICE = EmojiAK.EUROPEAN_POST_OFFICE
    EVERGREEN_TREE = EmojiAK.EVERGREEN_TREE
    EXCLAMATION = EmojiAK.EXCLAMATION
    EXPRESSIONLESS = EmojiAK.EXPRESSIONLESS
    EYEGLASSES = EmojiAK.EYEGLASSES
    EYES = EmojiAK.EYES
    E_MAIL = EmojiAK.E_MAIL
    # fmt: on

    # fmt: off
    FACEPUNCH = EmojiAK.FACEPUNCH
    FACTORY = EmojiAK.FACTORY
    FALLEN_LEAF = EmojiAK.FALLEN_LEAF
    FAMILY = EmojiAK.FAMILY
    FAST_FORWARD = EmojiAK.FAST_FORWARD
    FAX = EmojiAK.FAX
    FEARFUL = EmojiAK.FEARFUL
    FEELSGOOD = EmojiAK.FEELSGOOD
    FEET = EmojiAK.FEET
    FERRIS_WHEEL = EmojiAK.FERRIS_WHEEL
    FILE_FOLDER = EmojiAK.FILE_FOLDER
    FINNADIE = EmojiAK.FINNADIE
    FIRE = EmojiAK.FIRE
    FIREWORKS = EmojiAK.FIREWORKS
    FIRE_ENGINE = EmojiAK.FIRE_ENGINE
    FIRST_QUARTER_MOON = EmojiAK.FIRST_QUARTER_MOON
    FIRST_QUARTER_MOON_WITH_FACE = EmojiAK.FIRST_QUARTER_MOON_WITH_FACE
    FISH = EmojiAK.FISH
    FISHING_POLE_AND_FISH = EmojiAK.FISHING_POLE_AND_FISH
    FISH_CAKE = EmojiAK.FISH_CAKE
    FIST = EmojiAK.FIST
    FIVE = EmojiAK.FIVE
    FLAGS = EmojiAK.FLAGS
    FLASHLIGHT = EmojiAK.FLASHLIGHT
    FLOPPY_DISK = EmojiAK.FLOPPY_DISK
    FLOWER_PLAYING_CARDS = EmojiAK.FLOWER_PLAYING_CARDS
    FLUSHED = EmojiAK.FLUSHED
    FOGGY = EmojiAK.FOGGY
    FOOTBALL = EmojiAK.FOOTBALL
    FOUNTAIN = EmojiAK.FOUNTAIN
    FOUR = EmojiAK.FOUR
    FOUR_LEAF_CLOVER = EmojiAK.FOUR_LEAF_CLOVER
    FR = EmojiAK.FR
    FREE = EmojiAK.FREE
    FRIED_SHRIMP = EmojiAK.FRIED_SHRIMP
    FRIES = EmojiAK.FRIES
    FROG = EmojiAK.FROG
    FROWNING = EmojiAK.FROWNING
    FU = EmojiAK.FU
    FUELPUMP = EmojiAK.FUELPUMP
    FULL_MOON = EmojiAK.FULL_MOON
    FULL_MOON_WITH_FACE = EmojiAK.FULL_MOON_WITH_FACE
    # fmt: on

    # fmt: off
    GAME_DIE = EmojiAK.GAME_DIE
    GB = EmojiAK.GB
    GEM = EmojiAK.GEM
    GEMINI = EmojiAK.GEMINI
    GHOST = EmojiAK.GHOST
    GIFT = EmojiAK.GIFT
    GIFT_HEART = EmojiAK.GIFT_HEART
    GIRL = EmojiAK.GIRL
    GLOBE_WITH_MERIDIANS = EmojiAK.GLOBE_WITH_MERIDIANS
    GOAT = EmojiAK.GOAT
    GOBERSERK = EmojiAK.GOBERSERK
    GODMODE = EmojiAK.GODMODE
    GOLF = EmojiAK.GOLF
    GRAPES = EmojiAK.GRAPES
    GREEN_APPLE = EmojiAK.GREEN_APPLE
    GREEN_BOOK = EmojiAK.GREEN_BOOK
    GREEN_HEART = EmojiAK.GREEN_HEART
    GREY_EXCLAMATION = EmojiAK.GREY_EXCLAMATION
    GREY_QUESTION = EmojiAK.GREY_QUESTION
    GRIMACING = EmojiAK.GRIMACING
    GRIN = EmojiAK.GRIN
    GRINNING = EmojiAK.GRINNING
    GUARDSMAN = EmojiAK.GUARDSMAN
    GUITAR = EmojiAK.GUITAR
    GUN = EmojiAK.GUN
    # fmt: on

    # fmt: off
    HAIRCUT = EmojiAK.HAIRCUT
    HAMBURGER = EmojiAK.HAMBURGER
    HAMMER = EmojiAK.HAMMER
    HAMSTER = EmojiAK.HAMSTER
    HAND = EmojiAK.HAND
    HANDBAG = EmojiAK.HANDBAG
    HANKEY = EmojiAK.HANKEY
    HASH = EmojiAK.HASH
    HATCHED_CHICK = EmojiAK.HATCHED_CHICK
    HATCHING_CHICK = EmojiAK.HATCHING_CHICK
    HEADPHONES = EmojiAK.HEADPHONES
    HEART = EmojiAK.HEART
    HEARTBEAT = EmojiAK.HEARTBEAT
    HEARTPULSE = EmojiAK.HEARTPULSE
    HEARTS = EmojiAK.HEARTS
    HEART_DECORATION = EmojiAK.HEART_DECORATION
    HEART_EYES = EmojiAK.HEART_EYES
    HEART_EYES_CAT = EmojiAK.HEART_EYES_CAT
    HEAR_NO_EVIL = EmojiAK.HEAR_NO_EVIL
    HEAVY_CHECK_MARK = EmojiAK.HEAVY_CHECK_MARK
    HEAVY_DIVISION_SIGN = EmojiAK.HEAVY_DIVISION_SIGN
    HEAVY_DOLLAR_SIGN = EmojiAK.HEAVY_DOLLAR_SIGN
    HEAVY_EXCLAMATION_MARK = EmojiAK.HEAVY_EXCLAMATION_MARK
    HEAVY_MINUS_SIGN = EmojiAK.HEAVY_MINUS_SIGN
    HEAVY_MULTIPLICATION = EmojiAK.HEAVY_MULTIPLICATION
    HEAVY_PLUS_SIGN = EmojiAK.HEAVY_PLUS_SIGN
    HELICOPTER = EmojiAK.HELICOPTER
    HERB = EmojiAK.HERB
    HIBISCUS = EmojiAK.HIBISCUS
    HIGH_BRIGHTNESS = EmojiAK.HIGH_BRIGHTNESS
    HIGH_HEEL = EmojiAK.HIGH_HEEL
    HOCHO = EmojiAK.HOCHO
    HONEYBEE = EmojiAK.HONEYBEE
    HONEY_POT = EmojiAK.HONEY_POT
    HORSE = EmojiAK.HORSE
    HORSE_RACING = EmojiAK.HORSE_RACING
    HOSPITAL = EmojiAK.HOSPITAL
    HOTEL = EmojiAK.HOTEL
    HOTSPRINGS = EmojiAK.HOTSPRINGS
    HOURGLASS = EmojiAK.HOURGLASS
    HOURGLASS_FLOWING_SAND = EmojiAK.HOURGLASS_FLOWING_SAND
    HOUSE = EmojiAK.HOUSE
    HOUSE_WITH_GARDEN = EmojiAK.HOUSE_WITH_GARDEN
    HUNDRED = EmojiAK.HUNDRED
    HURTREALBAD = EmojiAK.HURTREALBAD
    HUSHED = EmojiAK.HUSHED
    # fmt: on

    # fmt: off
    ICECREAM = EmojiAK.ICECREAM
    ICE_CREAM = EmojiAK.ICE_CREAM
    ID = EmojiAK.ID
    IMP = EmojiAK.IMP
    INBOX_TRAY = EmojiAK.INBOX_TRAY
    INCOMING_ENVELOPE = EmojiAK.INCOMING_ENVELOPE
    INFORMATION_DESK_PERSON = EmojiAK.INFORMATION_DESK_PERSON
    INFORMATION_SOURCE = EmojiAK.INFORMATION_SOURCE
    INNOCENT = EmojiAK.INNOCENT
    INTERROBANG = EmojiAK.INTERROBANG
    IPHONE = EmojiAK.IPHONE
    IT = EmojiAK.IT
    IZAKAYA_LANTERN = EmojiAK.IZAKAYA_LANTERN
    # fmt: on

    # fmt: off
    JACK_O_LANTERN = EmojiAK.JACK_O_LANTERN
    JAPAN = EmojiAK.JAPAN
    JAPANESE_CASTLE = EmojiAK.JAPANESE_CASTLE
    JAPANESE_GOBLIN = EmojiAK.JAPANESE_GOBLIN
    JAPANESE_OGRE = EmojiAK.JAPANESE_OGRE
    JEANS = EmojiAK.JEANS
    JOY = EmojiAK.JOY
    JOY_CAT = EmojiAK.JOY_CAT
    JP = EmojiAK.JP
    # fmt: on

    # fmt: off
    KEY = EmojiAK.KEY
    KEYCAP_TEN = EmojiAK.KEYCAP_TEN
    KIMONO = EmojiAK.KIMONO
    KISS = EmojiAK.KISS
    KISSING = EmojiAK.KISSING
    KISSING_CAT = EmojiAK.KISSING_CAT
    KISSING_CLOSED_EYES = EmojiAK.KISSING_CLOSED_EYES
    KISSING_HEART = EmojiAK.KISSING_HEART
    KISSING_SMILING_EYES = EmojiAK.KISSING_SMILING_EYES
    KNIFE_AND_FORK = EmojiAK.KNIFE_AND_FORK
    KOALA = EmojiAK.KOALA
    KOKO = EmojiAK.KOKO
    KR = EmojiAK.KR
    # fmt: on

    # fmt: off
    LAST_QUARTER_MOON = EmojiLZ.LAST_QUARTER_MOON
    LAST_QUARTER_MOON_WITH_FACE = EmojiLZ.LAST_QUARTER_MOON_WITH_FACE
    LAUGHING = EmojiLZ.LAUGHING
    LEAVES = EmojiLZ.LEAVES
    LEDGER = EmojiLZ.LEDGER
    LEFT_LUGGAGE = EmojiLZ.LEFT_LUGGAGE
    LEMON = EmojiLZ.LEMON
    LEO = EmojiLZ.LEO
    LEOPARD = EmojiLZ.LEOPARD
    LIBRA = EmojiLZ.LIBRA
    LIGHT_RAIL = EmojiLZ.LIGHT_RAIL
    LINK = EmojiLZ.LINK
    LIPS = EmojiLZ.LIPS
    LIPSTICK = EmojiLZ.LIPSTICK
    LOCK = EmojiLZ.LOCK
    LOCK_WITH_INK_PEN = EmojiLZ.LOCK_WITH_INK_PEN
    LOLLIPOP = EmojiLZ.LOLLIPOP
    LOOP = EmojiLZ.LOOP
    LOUDSPEAKER = EmojiLZ.LOUDSPEAKER
    LOVE_HOTEL = EmojiLZ.LOVE_HOTEL
    LOVE_LETTER = EmojiLZ.LOVE_LETTER
    LOW_BRIGHTNESS = EmojiLZ.LOW_BRIGHTNESS
    # fmt: on

    # fmt: off
    M = EmojiLZ.M
    MAG = EmojiLZ.MAG
    MAGIC_8_BALL = EmojiLZ.MAGIC_8_BALL
    MAG_RIGHT = EmojiLZ.MAG_RIGHT
    MAHJONG = EmojiLZ.MAHJONG
    MAILBOX = EmojiLZ.MAILBOX
    MAILBOX_CLOSED = EmojiLZ.MAILBOX_CLOSED
    MAILBOX_WITH_MAIL = EmojiLZ.MAILBOX_WITH_MAIL
    MAILBOX_WITH_NO_MAIL = EmojiLZ.MAILBOX_WITH_NO_MAIL
    MAN = EmojiLZ.MAN
    MANS_SHOE = EmojiLZ.MANS_SHOE
    MAN_WITH_GUA_PI_MAO = EmojiLZ.MAN_WITH_GUA_PI_MAO
    MAN_WITH_TURBAN = EmojiLZ.MAN_WITH_TURBAN
    MAPLE_LEAF = EmojiLZ.MAPLE_LEAF
    MASK = EmojiLZ.MASK
    MASSAGE = EmojiLZ.MASSAGE
    MEAT_ON_BONE = EmojiLZ.MEAT_ON_BONE
    MEGA = EmojiLZ.MEGA
    MELON = EmojiLZ.MELON
    MEMO = EmojiLZ.MEMO
    MENS = EmojiLZ.MENS
    METAL = EmojiLZ.METAL
    MICROPHONE = EmojiLZ.MICROPHONE
    MICROSCOPE = EmojiLZ.MICROSCOPE
    MILKY_WAY = EmojiLZ.MILKY_WAY
    MINIBUS = EmojiLZ.MINIBUS
    MINIDISC = EmojiLZ.MINIDISC
    MINUS_1 = EmojiLZ.MINUS_1
    MOBILE_PHONE_OFF = EmojiLZ.MOBILE_PHONE_OFF
    MONEYBAG = EmojiLZ.MONEYBAG
    MONEY_WITH_WINGS = EmojiLZ.MONEY_WITH_WINGS
    MONKEY = EmojiLZ.MONKEY
    MONKEY_FACE = EmojiLZ.MONKEY_FACE
    MONORAIL = EmojiLZ.MONORAIL
    MOON = EmojiLZ.MOON
    MORTAR_BOARD = EmojiLZ.MORTAR_BOARD
    MOUNTAIN_BICYCLIST = EmojiLZ.MOUNTAIN_BICYCLIST
    MOUNTAIN_CABLEWAY = EmojiLZ.MOUNTAIN_CABLEWAY
    MOUNTAIN_RAILWAY = EmojiLZ.MOUNTAIN_RAILWAY
    MOUNT_FUJI = EmojiLZ.MOUNT_FUJI
    MOUSE = EmojiLZ.MOUSE
    MOUSE_2 = EmojiLZ.MOUSE_2
    MOVIE_CAMERA = EmojiLZ.MOVIE_CAMERA
    MOYAI = EmojiLZ.MOYAI
    MUSCLE = EmojiLZ.MUSCLE
    MUSHROOM = EmojiLZ.MUSHROOM
    MUSICAL_KEYBOARD = EmojiLZ.MUSICAL_KEYBOARD
    MUSICAL_NOTE = EmojiLZ.MUSICAL_NOTE
    MUSICAL_SCORE = EmojiLZ.MUSICAL_SCORE
    MUTE = EmojiLZ.MUTE
    # fmt: on

    # fmt: off
    NAIL_CARE = EmojiLZ.NAIL_CARE
    NAME_BADGE = EmojiLZ.NAME_BADGE
    NECKBEARD = EmojiLZ.NECKBEARD
    NECKTIE = EmojiLZ.NECKTIE
    NEGATIVE_SQUARED_CROSS_MARK = EmojiLZ.NEGATIVE_SQUARED_CROSS_MARK
    NEUTRAL_FACE = EmojiLZ.NEUTRAL_FACE
    NEW = EmojiLZ.NEW
    NEWSPAPER = EmojiLZ.NEWSPAPER
    NEW_MOON = EmojiLZ.NEW_MOON
    NEW_MOON_WITH_FACE = EmojiLZ.NEW_MOON_WITH_FACE
    NG = EmojiLZ.NG
    NINE = EmojiLZ.NINE
    NON_POTABLE_WATER = EmojiLZ.NON_POTABLE_WATER
    NOSE = EmojiLZ.NOSE
    NOTEBOOK = EmojiLZ.NOTEBOOK
    NOTEBOOK_WITH_DECORATIVE_COVER = EmojiLZ.NOTEBOOK_WITH_DECORATIVE_COVER
    NOTES = EmojiLZ.NOTES
    NO_BELL = EmojiLZ.NO_BELL
    NO_BICYCLES = EmojiLZ.NO_BICYCLES
    NO_ENTRY = EmojiLZ.NO_ENTRY
    NO_GOOD = EmojiLZ.NO_GOOD
    NO_MOBILE_PHONES = EmojiLZ.NO_MOBILE_PHONES
    NO_MOUTH = EmojiLZ.NO_MOUTH
    NO_PEDESTRIANS = EmojiLZ.NO_PEDESTRIANS
    NO_SMOKING = EmojiLZ.NO_SMOKING
    NUT_AND_BOLT = EmojiLZ.NUT_AND_BOLT
    # fmt: on

    # fmt: off
    O = EmojiLZ.O
    OCEAN = EmojiLZ.OCEAN
    OCTOCAT = EmojiLZ.OCTOCAT
    OCTOPUS = EmojiLZ.OCTOPUS
    ODEN = EmojiLZ.ODEN
    OFFICE = EmojiLZ.OFFICE
    OK = EmojiLZ.OK
    OK_HAND = EmojiLZ.OK_HAND
    OK_WOMAN = EmojiLZ.OK_WOMAN
    OLDER_MAN = EmojiLZ.OLDER_MAN
    OLDER_WOMAN = EmojiLZ.OLDER_WOMAN
    ON = EmojiLZ.ON
    ONCOMING_AUTOMOBILE = EmojiLZ.ONCOMING_AUTOMOBILE
    ONCOMING_BUS = EmojiLZ.ONCOMING_BUS
    ONCOMING_POLICE_CAR = EmojiLZ.ONCOMING_POLICE_CAR
    ONCOMING_TAXI = EmojiLZ.ONCOMING_TAXI
    ONE = EmojiLZ.ONE
    ONE_TWO_THREE_FOUR = EmojiLZ.ONE_TWO_THREE_FOUR
    OPEN_FILE_FOLDER = EmojiLZ.OPEN_FILE_FOLDER
    OPEN_HANDS = EmojiLZ.OPEN_HANDS
    OPEN_MOUTH = EmojiLZ.OPEN_MOUTH
    OPHIUCHUS = EmojiLZ.OPHIUCHUS
    ORANGE_BOOK = EmojiLZ.ORANGE_BOOK
    ORANGE_DIAMOND = EmojiLZ.ORANGE_DIAMOND
    OUTBOX_TRAY = EmojiLZ.OUTBOX_TRAY
    OX = EmojiLZ.OX
    # fmt: on

    # fmt: off
    PAGER = EmojiLZ.PAGER
    PAGE_FACING_UP = EmojiLZ.PAGE_FACING_UP
    PAGE_WITH_CURL = EmojiLZ.PAGE_WITH_CURL
    PALM_TREE = EmojiLZ.PALM_TREE
    PANDA_FACE = EmojiLZ.PANDA_FACE
    PAPERCLIP = EmojiLZ.PAPERCLIP
    PARKING = EmojiLZ.PARKING
    PARTLY_SUNNY = EmojiLZ.PARTLY_SUNNY
    PART_ALTERNATION_MARK = EmojiLZ.PART_ALTERNATION_MARK
    PASSPORT_CONTROL = EmojiLZ.PASSPORT_CONTROL
    PAW_PRINTS = EmojiLZ.PAW_PRINTS
    PEACH = EmojiLZ.PEACH
    PEAR = EmojiLZ.PEAR
    PENCIL = EmojiLZ.PENCIL
    PENCIL_2 = EmojiLZ.PENCIL_2
    PENGUIN = EmojiLZ.PENGUIN
    PENSIVE = EmojiLZ.PENSIVE
    PERFORMING_ARTS = EmojiLZ.PERFORMING_ARTS
    PERSEVERE = EmojiLZ.PERSEVERE
    PHONE = EmojiLZ.PHONE
    PIG = EmojiLZ.PIG
    PIG_2 = EmojiLZ.PIG_2
    PIG_NOSE = EmojiLZ.PIG_NOSE
    PILL = EmojiLZ.PILL
    PINEAPPLE = EmojiLZ.PINEAPPLE
    PISCES = EmojiLZ.PISCES
    PIZZA = EmojiLZ.PIZZA
    PLUS_1 = EmojiLZ.PLUS_1
    POINT_DOWN = EmojiLZ.POINT_DOWN
    POINT_LEFT = EmojiLZ.POINT_LEFT
    POINT_RIGHT = EmojiLZ.POINT_RIGHT
    POINT_UP = EmojiLZ.POINT_UP
    POINT_UP_2 = EmojiLZ.POINT_UP_2
    POLICE_CAR = EmojiLZ.POLICE_CAR
    POODLE = EmojiLZ.POODLE
    POOP = EmojiLZ.POOP
    POSTAL_HORN = EmojiLZ.POSTAL_HORN
    POSTBOX = EmojiLZ.POSTBOX
    POST_OFFICE = EmojiLZ.POST_OFFICE
    POTABLE_WATER = EmojiLZ.POTABLE_WATER
    POUCH = EmojiLZ.POUCH
    POULTRY_LEG = EmojiLZ.POULTRY_LEG
    POUND = EmojiLZ.POUND
    POUTING_CAT = EmojiLZ.POUTING_CAT
    PRAY = EmojiLZ.PRAY
    PRINCESS = EmojiLZ.PRINCESS
    PUNCH = EmojiLZ.PUNCH
    PURPLE_HEART = EmojiLZ.PURPLE_HEART
    PURSE = EmojiLZ.PURSE
    PUSHPIN = EmojiLZ.PUSHPIN
    PUT_LITTER_IN_ITS_PLACE = EmojiLZ.PUT_LITTER_IN_ITS_PLACE
    # fmt: on

    # fmt: off
    QUESTION = EmojiLZ.QUESTION
    # fmt: on

    # fmt: off
    RABBIT = EmojiLZ.RABBIT
    RABBIT_2 = EmojiLZ.RABBIT_2
    RACEHORSE = EmojiLZ.RACEHORSE
    RADIO = EmojiLZ.RADIO
    RADIO_BUTTON = EmojiLZ.RADIO_BUTTON
    RAGE = EmojiLZ.RAGE
    RAGE_1 = EmojiLZ.RAGE_1
    RAGE_2 = EmojiLZ.RAGE_2
    RAGE_3 = EmojiLZ.RAGE_3
    RAGE_4 = EmojiLZ.RAGE_4
    RAILWAY_CAR = EmojiLZ.RAILWAY_CAR
    RAINBOW = EmojiLZ.RAINBOW
    RAISED_HAND = EmojiLZ.RAISED_HAND
    RAISED_HANDS = EmojiLZ.RAISED_HANDS
    RAISING_HAND = EmojiLZ.RAISING_HAND
    RAM = EmojiLZ.RAM
    RAMEN = EmojiLZ.RAMEN
    RAT = EmojiLZ.RAT
    RECYCLE = EmojiLZ.RECYCLE
    RED_CAR = EmojiLZ.RED_CAR
    RED_CIRCLE = EmojiLZ.RED_CIRCLE
    REGISTERED = EmojiLZ.REGISTERED
    RELAXED = EmojiLZ.RELAXED
    RELIEVED = EmojiLZ.RELIEVED
    REPEAT = EmojiLZ.REPEAT
    REPEAT_ONCE = EmojiLZ.REPEAT_ONCE
    RESTROOM = EmojiLZ.RESTROOM
    REVOLVING_HEARTS = EmojiLZ.REVOLVING_HEARTS
    REWIND = EmojiLZ.REWIND
    RIBBON = EmojiLZ.RIBBON
    RICE = EmojiLZ.RICE
    RICE_BALL = EmojiLZ.RICE_BALL
    RICE_CRACKER = EmojiLZ.RICE_CRACKER
    RICE_SCENE = EmojiLZ.RICE_SCENE
    RING = EmojiLZ.RING
    ROCKET = EmojiLZ.ROCKET
    ROLLER_COASTER = EmojiLZ.ROLLER_COASTER
    ROOSTER = EmojiLZ.ROOSTER
    ROSE = EmojiLZ.ROSE
    ROTATING_LIGHT = EmojiLZ.ROTATING_LIGHT
    ROUND_PUSHPIN = EmojiLZ.ROUND_PUSHPIN
    ROWBOAT = EmojiLZ.ROWBOAT
    RU = EmojiLZ.RU
    RUGBY_FOOTBALL = EmojiLZ.RUGBY_FOOTBALL
    RUNNER = EmojiLZ.RUNNER
    RUNNING = EmojiLZ.RUNNING
    RUNNING_SHIRT_WITH_SASH = EmojiLZ.RUNNING_SHIRT_WITH_SASH
    # fmt: on

    # fmt: off
    SAGITTARIUS = EmojiLZ.SAGITTARIUS
    SAILBOAT = EmojiLZ.SAILBOAT
    SAKE = EmojiLZ.SAKE
    SANDAL = EmojiLZ.SANDAL
    SANTA = EmojiLZ.SANTA
    SATELITE = EmojiLZ.SATELITE
    SATISFIED = EmojiLZ.SATISFIED
    SAXOPHONE = EmojiLZ.SAXOPHONE
    SCHOOL = EmojiLZ.SCHOOL
    SCHOOL_SATCHEL = EmojiLZ.SCHOOL_SATCHEL
    SCISSORS = EmojiLZ.SCISSORS
    SCORPIUS = EmojiLZ.SCORPIUS
    SCREAM = EmojiLZ.SCREAM
    SCREAM_CAT = EmojiLZ.SCREAM_CAT
    SCROLL = EmojiLZ.SCROLL
    SEAT = EmojiLZ.SEAT
    SEEDLING = EmojiLZ.SEEDLING
    SEE_NO_EVIL = EmojiLZ.SEE_NO_EVIL
    SEVEN = EmojiLZ.SEVEN
    SHAVED_ICE = EmojiLZ.SHAVED_ICE
    SHEEP = EmojiLZ.SHEEP
    SHELL = EmojiLZ.SHELL
    SHIP = EmojiLZ.SHIP
    SHIPIT = EmojiLZ.SHIPIT
    SHIRT = EmojiLZ.SHIRT
    SHIT = EmojiLZ.SHIT
    SHOE = EmojiLZ.SHOE
    SHOWER = EmojiLZ.SHOWER
    SIGNAL_STRENGTH = EmojiLZ.SIGNAL_STRENGTH
    SIX = EmojiLZ.SIX
    SIX_POINTED_STAR = EmojiLZ.SIX_POINTED_STAR
    SKI = EmojiLZ.SKI
    SKULL = EmojiLZ.SKULL
    SLEEPING = EmojiLZ.SLEEPING
    SLEEPY = EmojiLZ.SLEEPY
    SLOT_MACHINE = EmojiLZ.SLOT_MACHINE
    SMALL_BLUE_DIAMOND = EmojiLZ.SMALL_BLUE_DIAMOND
    SMALL_ORANGE_DIAMOND = EmojiLZ.SMALL_ORANGE_DIAMOND
    SMALL_RED_TRIANGLE_DOWN = EmojiLZ.SMALL_RED_TRIANGLE_DOWN
    SMALL_RED_TRIANGLE_UP = EmojiLZ.SMALL_RED_TRIANGLE_UP
    SMILE = EmojiLZ.SMILE
    SMILEY = EmojiLZ.SMILEY
    SMILEY_CAT = EmojiLZ.SMILEY_CAT
    SMILE_CAT = EmojiLZ.SMILE_CAT
    SMILING_IMP = EmojiLZ.SMILING_IMP
    SMIRK = EmojiLZ.SMIRK
    SMIRK_CAT = EmojiLZ.SMIRK_CAT
    SMOKING = EmojiLZ.SMOKING
    SNAIL = EmojiLZ.SNAIL
    SNAKE = EmojiLZ.SNAKE
    SNOWBOARDER = EmojiLZ.SNOWBOARDER
    SNOWFLAKE = EmojiLZ.SNOWFLAKE
    SNOWMAN = EmojiLZ.SNOWMAN
    SOB = EmojiLZ.SOB
    SOCCER = EmojiLZ.SOCCER
    SOON = EmojiLZ.SOON
    SOS = EmojiLZ.SOS
    SOUND = EmojiLZ.SOUND
    SPACE_INVADER = EmojiLZ.SPACE_INVADER
    SPADES = EmojiLZ.SPADES
    SPAGHETTI = EmojiLZ.SPAGHETTI
    SPARKLER = EmojiLZ.SPARKLER
    SPARKLES = EmojiLZ.SPARKLES
    SPARKLING_HEART = EmojiLZ.SPARKLING_HEART
    SPEAKER = EmojiLZ.SPEAKER
    SPEAK_NO_EVIL = EmojiLZ.SPEAK_NO_EVIL
    SPEECH_BALLOON = EmojiLZ.SPEECH_BALLOON
    SPEEDBOAT = EmojiLZ.SPEEDBOAT
    STAR = EmojiLZ.STAR
    STARS = EmojiLZ.STARS
    STAR_2 = EmojiLZ.STAR_2
    STATION = EmojiLZ.STATION
    STATUE_OF_LIBERTY = EmojiLZ.STATUE_OF_LIBERTY
    STEAM_LOCOMOTIVE = EmojiLZ.STEAM_LOCOMOTIVE
    STEW = EmojiLZ.STEW
    STRAIGHT_RULER = EmojiLZ.STRAIGHT_RULER
    STRAWBERRY = EmojiLZ.STRAWBERRY
    STUCK_OUT_TONGUE = EmojiLZ.STUCK_OUT_TONGUE
    STUCK_OUT_TONGUE_CLOSED_EYES = EmojiLZ.STUCK_OUT_TONGUE_CLOSED_EYES
    STUCK_OUT_TONGUE_WINKING_EYE = EmojiLZ.STUCK_OUT_TONGUE_WINKING_EYE
    SUNFLOWER = EmojiLZ.SUNFLOWER
    SUNGLASSES = EmojiLZ.SUNGLASSES
    SUNNY = EmojiLZ.SUNNY
    SUNRISE = EmojiLZ.SUNRISE
    SUNRISE_OVER_MOUNTAINS = EmojiLZ.SUNRISE_OVER_MOUNTAINS
    SUN_WITH_FACE = EmojiLZ.SUN_WITH_FACE
    SURFER = EmojiLZ.SURFER
    SUSHI = EmojiLZ.SUSHI
    SUSPECT = EmojiLZ.SUSPECT
    SUSPENSION_RAILWAY = EmojiLZ.SUSPENSION_RAILWAY
    SWEAT = EmojiLZ.SWEAT
    SWEAT_DROPS = EmojiLZ.SWEAT_DROPS
    SWEAT_SMILE = EmojiLZ.SWEAT_SMILE
    SWEET_POTATO = EmojiLZ.SWEET_POTATO
    SWIMMER = EmojiLZ.SWIMMER
    SYMBOLS = EmojiLZ.SYMBOLS
    SYRINGE = EmojiLZ.SYRINGE
    # fmt: on

    # fmt: off
    TADA = EmojiLZ.TADA
    TANABATA_TREE = EmojiLZ.TANABATA_TREE
    TANGERINE = EmojiLZ.TANGERINE
    TAURUS = EmojiLZ.TAURUS
    TAXI = EmojiLZ.TAXI
    TEA = EmojiLZ.TEA
    TELEPHONE = EmojiLZ.TELEPHONE
    TELEPHONE_RECEIVER = EmojiLZ.TELEPHONE_RECEIVER
    TELESCOPE = EmojiLZ.TELESCOPE
    TENNIS = EmojiLZ.TENNIS
    TENT = EmojiLZ.TENT
    THOUGHT_BALLOON = EmojiLZ.THOUGHT_BALLOON
    THREE = EmojiLZ.THREE
    THUMBSDOWN = EmojiLZ.THUMBSDOWN
    THUMBSUP = EmojiLZ.THUMBSUP
    TICKET = EmojiLZ.TICKET
    TIGER = EmojiLZ.TIGER
    TIGER_2 = EmojiLZ.TIGER_2
    TIRED_FACE = EmojiLZ.TIRED_FACE
    TM = EmojiLZ.TM
    TOILET = EmojiLZ.TOILET
    TOKYO_TOWER = EmojiLZ.TOKYO_TOWER
    TOMATO = EmojiLZ.TOMATO
    TONGUE = EmojiLZ.TONGUE
    TOP = EmojiLZ.TOP
    TOPHAT = EmojiLZ.TOPHAT
    TRACTOR = EmojiLZ.TRACTOR
    TRAFFIC_LIGHT = EmojiLZ.TRAFFIC_LIGHT
    TRAIN = EmojiLZ.TRAIN
    TRAIN_2 = EmojiLZ.TRAIN_2
    TRAM = EmojiLZ.TRAM
    TRIANGULAR_FLAG_ON_POST = EmojiLZ.TRIANGULAR_FLAG_ON_POST
    TRIANGULAR_RULER = EmojiLZ.TRIANGULAR_RULER
    TRIDENT = EmojiLZ.TRIDENT
    TRIUMPH = EmojiLZ.TRIUMPH
    TROLLEYBUS = EmojiLZ.TROLLEYBUS
    TROLLFACE = EmojiLZ.TROLLFACE
    TROPHY = EmojiLZ.TROPHY
    TROPICAL_DRINK = EmojiLZ.TROPICAL_DRINK
    TROPICAL_FISH = EmojiLZ.TROPICAL_FISH
    TRUCK = EmojiLZ.TRUCK
    TRUMPET = EmojiLZ.TRUMPET
    TSHIRT = EmojiLZ.TSHIRT
    TULIP = EmojiLZ.TULIP
    TURTLE = EmojiLZ.TURTLE
    TV = EmojiLZ.TV
    TWO = EmojiLZ.TWO
    TWO_HEARTS = EmojiLZ.TWO_HEARTS
    TWO_MEN_HOLDING_HANDS = EmojiLZ.TWO_MEN_HOLDING_HANDS
    TWO_WOMEN_HOLDING_HANDS = EmojiLZ.TWO_WOMEN_HOLDING_HANDS
    # fmt: on

    # fmt: off
    UK = EmojiLZ.UK
    UMBRELLA = EmojiLZ.UMBRELLA
    UNAMUSED = EmojiLZ.UNAMUSED
    UNDERAGE = EmojiLZ.UNDERAGE
    UNLOCK = EmojiLZ.UNLOCK
    UP = EmojiLZ.UP
    US = EmojiLZ.US
    # fmt: on

    # fmt: off
    V = EmojiLZ.V
    VERTICAL_TRAFFIC_LIGHT = EmojiLZ.VERTICAL_TRAFFIC_LIGHT
    VHS = EmojiLZ.VHS
    VIBRATION_MODE = EmojiLZ.VIBRATION_MODE
    VIDEO_CAMERA = EmojiLZ.VIDEO_CAMERA
    VIDEO_GAME = EmojiLZ.VIDEO_GAME
    VIOLIN = EmojiLZ.VIOLIN
    VIRGO = EmojiLZ.VIRGO
    VOLCANO = EmojiLZ.VOLCANO
    VS = EmojiLZ.VS
    # fmt: on

    # fmt: off
    WALKING = EmojiLZ.WALKING
    WANING_CRESENT_MOON = EmojiLZ.WANING_CRESENT_MOON
    WANING_GIBBOUS_MOON = EmojiLZ.WANING_GIBBOUS_MOON
    WARNING = EmojiLZ.WARNING
    WATCH = EmojiLZ.WATCH
    WATERMELON = EmojiLZ.WATERMELON
    WATER_BUFFALO = EmojiLZ.WATER_BUFFALO
    WAVE = EmojiLZ.WAVE
    WAVY_DASH = EmojiLZ.WAVY_DASH
    WAXING_CRESENT_MOON = EmojiLZ.WAXING_CRESENT_MOON
    WAXING_GIBBOUS_MOON = EmojiLZ.WAXING_GIBBOUS_MOON
    WC = EmojiLZ.WC
    WEARY = EmojiLZ.WEARY
    WEDDING = EmojiLZ.WEDDING
    WHALE = EmojiLZ.WHALE
    WHALE_2 = EmojiLZ.WHALE_2
    WHITE_CIRCLE = EmojiLZ.WHITE_CIRCLE
    WHITE_FLOWER = EmojiLZ.WHITE_FLOWER
    WHITE_SQUARE_BUTTON = EmojiLZ.WHITE_SQUARE_BUTTON
    WIND_CHIME = EmojiLZ.WIND_CHIME
    WINE_GLASS = EmojiLZ.WINE_GLASS
    WINK = EmojiLZ.WINK
    WOLF = EmojiLZ.WOLF
    WOMAN = EmojiLZ.WOMAN
    WOMANS_CLOTHES = EmojiLZ.WOMANS_CLOTHES
    WOMANS_HAT = EmojiLZ.WOMANS_HAT
    WOMENS = EmojiLZ.WOMENS
    WORRIED = EmojiLZ.WORRIED
    WRENCH = EmojiLZ.WRENCH
    # fmt: on

    # fmt: off
    X = EmojiLZ.X
    # fmt: on

    # fmt: off
    YELLOW_HEART = EmojiLZ.YELLOW_HEART
    YEN = EmojiLZ.YEN
    YUM = EmojiLZ.YUM
    # fmt: on

    # fmt: off
    ZAP = EmojiLZ.ZAP
    ZERO = EmojiLZ.ZERO
    ZZZ = EmojiLZ.ZZZ
    # fmt: off
