#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Defines standard character code-to-name mappings for common font encodings.

The `CommonFontEncodings` class provides predefined mappings used to interpret
character codes in various standard font encodings. These mappings are essential
for rendering text accurately in PDF documents by associating character codes with
specific glyph names.

This class serves as a utility for handling font encodings consistently across
different PDF documents.
"""


class CommonFontEncodings:
    """
    Defines standard character code-to-name mappings for common font encodings.

    The `CommonFontEncodings` class provides predefined mappings used to interpret
    character codes in various standard font encodings. These mappings are essential
    for rendering text accurately in PDF documents by associating character codes with
    specific glyph names.

    This class serves as a utility for handling font encodings consistently across
    different PDF documents.
    """

    #
    # CONSTRUCTOR
    #

    #
    # PRIVATE
    #

    #
    # PUBLIC
    #

    # fmt: off
    MACEXPERT_CHARACTER_CODE_TO_CHARACTER_NAME = {32: 'space', 33: 'exclam', 34: 'universal', 35: 'numbersign', 36: 'existential', 37: 'percent', 38: 'ampersand', 39: 'suchthat', 40: 'parenleft', 41: 'parenright', 42: 'asteriskmath', 43: 'plus', 44: 'comma', 45: 'minus', 46: 'period', 47: 'slash', 48: 'zero', 49: 'one', 50: 'two', 51: 'three', 52: 'four', 53: 'five', 54: 'six', 55: 'seven', 56: 'eight', 57: 'nine', 58: 'colon', 59: 'semicolon', 60: 'less', 61: 'equal', 62: 'greater', 63: 'question', 64: 'congruent', 65: 'Alpha', 66: 'Beta', 67: 'Chi', 68: 'Delta', 69: 'Epsilon', 70: 'Phi', 71: 'Gamma', 72: 'Eta', 73: 'Iota', 74: 'theta1', 75: 'Kappa', 76: 'Lambda', 77: 'Mu', 78: 'Nu', 79: 'Omicron', 80: 'Pi', 81: 'Theta', 82: 'Rho', 83: 'Sigma', 84: 'Tau', 85: 'Upsilon', 86: 'sigma1', 87: 'Omega', 88: 'Xi', 89: 'Psi', 90: 'Zeta', 91: 'bracketleft', 92: 'therefore', 93: 'bracketright', 94: 'perpendicular', 95: 'underscore', 96: 'radicalex', 97: 'alpha', 98: 'beta', 99: 'chi', 100: 'delta', 101: 'epsilon', 102: 'phi', 103: 'gamma', 104: 'eta', 105: 'iota', 106: 'phi1', 107: 'kappa', 108: 'lambda', 109: 'mu', 110: 'nu', 111: 'omicron', 112: 'pi', 113: 'theta', 114: 'rho', 115: 'sigma', 116: 'tau', 117: 'upsilon', 118: 'omega1', 119: 'omega', 120: 'xi', 121: 'psi', 122: 'zeta', 123: 'braceleft', 124: 'bar', 125: 'braceright', 126: 'similar', 127: 'Upsilon1', 128: 'minute', 129: 'lessequal', 130: 'fraction', 131: 'infinity', 132: 'florin', 133: 'club', 134: 'diamond', 135: 'heart', 136: 'spade', 137: 'arrowboth', 138: 'arrowleft', 139: 'arrowup', 140: 'arrowright', 141: 'arrowdown', 142: 'degree', 143: 'plusminus', 144: 'second', 145: 'greaterequal', 146: 'multiply', 147: 'proportional', 148: 'partialdiff', 149: 'bullet', 150: 'divide', 151: 'notequal', 152: 'equivalence', 153: 'approxequal', 154: 'ellipsis', 155: 'arrowvertex', 156: 'arrowhorizex', 157: 'carriagereturn', 158: 'aleph', 159: 'Ifraktur', 160: 'Rfraktur', 161: 'weierstrass', 162: 'circlemultiply', 163: 'circleplus', 164: 'emptyset', 165: 'intersection', 166: 'union', 167: 'propersuperset', 168: 'reflexsuperset', 169: 'notsubset', 170: 'propersubset', 171: 'reflexsubset', 172: 'element', 173: 'notelement', 174: 'angle', 175: 'gradient', 176: 'registerserif', 177: 'copyrightserif', 178: 'trademarkserif', 179: 'product', 180: 'radical', 181: 'dotmath', 182: 'logicalnot', 183: 'logicaland', 184: 'logicalor', 185: 'arrowdblboth', 186: 'arrowdblleft', 187: 'arrowdblup', 188: 'arrowdblright', 189: 'arrowdbldown', 190: 'lozenge', 191: 'angleleft', 192: 'registersans', 193: 'copyrightsans', 194: 'trademarksans', 195: 'summation', 196: 'parenlefttp', 197: 'parenleftex', 198: 'parenleftbt', 199: 'bracketlefttp', 200: 'bracketleftex', 201: 'bracketleftbt', 202: 'bracelefttp', 203: 'braceleftmid', 204: 'braceleftbt', 205: 'braceex', 206: 'angleright', 207: 'integral', 208: 'integraltp', 209: 'integralex', 210: 'integralbt', 211: 'parenrighttp', 212: 'parenrightex', 213: 'parenrightbt', 214: 'bracketrighttp', 215: 'bracketrightex', 216: 'bracketrightbt', 217: 'bracerighttp', 218: 'bracerightmid', 219: 'bracerightbt'}
    MACEXPERT_CHARACTER_NAME_TO_CHARACTER_CODE = {v:k for k,v in MACEXPERT_CHARACTER_CODE_TO_CHARACTER_NAME.items()}
    # fmt: on

    # fmt: off
    MACROMAN_CHARACTER_CODE_TO_CHARACTER_NAME = {32: 'space', 33: 'exclam', 34: 'quotedbl', 35: 'numbersign', 36: 'dollar', 37: 'percent', 38: 'ampersand', 39: 'quotesingle', 40: 'parenleft', 41: 'parenright', 42: 'asterisk', 43: 'plus', 44: 'comma', 45: 'hyphen', 46: 'period', 47: 'slash', 48: 'zero', 49: 'one', 50: 'two', 51: 'three', 52: 'four', 53: 'five', 54: 'six', 55: 'seven', 56: 'eight', 57: 'nine', 58: 'colon', 59: 'semicolon', 60: 'less', 61: 'equal', 62: 'greater', 63: 'question', 64: 'at', 65: 'A', 66: 'B', 67: 'C', 68: 'D', 69: 'E', 70: 'F', 71: 'G', 72: 'H', 73: 'I', 74: 'J', 75: 'K', 76: 'L', 77: 'M', 78: 'N', 79: 'O', 80: 'P', 81: 'Q', 82: 'R', 83: 'S', 84: 'T', 85: 'U', 86: 'V', 87: 'W', 88: 'X', 89: 'Y', 90: 'Z', 91: 'bracketleft', 92: 'backslash', 93: 'bracketright', 94: 'asciicircum', 95: 'underscore', 96: 'grave', 97: 'a', 98: 'b', 99: 'c', 100: 'd', 101: 'e', 102: 'f', 103: 'g', 104: 'h', 105: 'i', 106: 'j', 107: 'k', 108: 'l', 109: 'm', 110: 'n', 111: 'o', 112: 'p', 113: 'q', 114: 'r', 115: 's', 116: 't', 117: 'u', 118: 'v', 119: 'w', 120: 'x', 121: 'y', 122: 'z', 123: 'braceleft', 124: 'bar', 125: 'braceright', 126: 'asciitilde', 127: 'delete', 128: 'Ccedilla', 129: 'udieresis', 130: 'eacute', 131: 'acircumflex', 132: 'adieresis', 133: 'agrave', 134: 'aring', 135: 'ccedilla', 136: 'ecircumflex', 137: 'edieresis', 138: 'egrave', 139: 'idieresis', 140: 'icircumflex', 141: 'igrave', 142: 'Adieresis', 143: 'Aring', 144: 'Eacute', 145: 'ae', 146: 'AE', 147: 'ocircumflex', 148: 'odieresis', 149: 'ograve', 150: 'ucircumflex', 151: 'ugrave', 152: 'ydieresis', 153: 'Odieresis', 154: 'Udieresis', 155: 'cent', 156: 'sterling', 157: 'yen', 158: 'florin', 159: 'section', 160: 'currency', 161: 'quotesingle', 162: 'quotedblleft', 163: 'guillemotleft', 164: 'guilsinglleft', 165: 'guilsinglright', 166: 'fi', 167: 'fl', 168: 'endash', 169: 'dagger', 170: 'daggerdbl', 171: 'periodcentered', 172: 'paragraph', 173: 'bullet', 174: 'quotesinglbase', 175: 'quotedblbase', 176: 'quotedblright', 177: 'guillemotright', 178: 'ellipsis', 179: 'perthousand', 180: 'questiondown', 181: 'grave', 182: 'acute', 183: 'circumflex', 184: 'tilde', 185: 'macron', 186: 'breve', 187: 'dotaccent', 188: 'dieresis', 189: 'ring', 190: 'cedilla', 191: 'hungarumlaut', 192: 'ogonek', 193: 'caron', 194: 'emdash', 195: 'AEacute', 196: 'Lslash', 197: 'Oslash', 198: 'OE', 199: 'ordfeminine', 200: 'ordmasculine', 201: 'aeacute', 202: 'lslash', 203: 'oslash', 204: 'oe', 205: 'Ydieresis', 206: 'Scaron', 207: 'Zcaron', 208: 'scaron', 209: 'zcaron', 210: 'ligature', 211: 'perp', 212: 'symmetric', 213: 'macron_accent', 214: 'currency_compat', 215: 'dotbelow', 216: 'ogonek_compat', 217: 'ring_compat', 218: 'not_def'}
    MACROMAN_CHARACTER_NAME_TO_CHARACTER_CODE = {v:k for k,v in MACROMAN_CHARACTER_CODE_TO_CHARACTER_NAME.items()}
    # fmt: on

    # fmt: off
    STANDARD_ENCODING_CHARACTER_CODE_TO_CHARACTER_NAME = {32: 'space', 33: 'exclam', 34: 'quotedbl', 35: 'numbersign', 36: 'dollar', 37: 'percent', 38: 'ampersand', 39: 'quotesingle', 40: 'parenleft', 41: 'parenright', 42: 'asterisk', 43: 'plus', 44: 'comma', 45: 'hyphen', 46: 'period', 47: 'slash', 48: 'zero', 49: 'one', 50: 'two', 51: 'three', 52: 'four', 53: 'five', 54: 'six', 55: 'seven', 56: 'eight', 57: 'nine', 58: 'colon', 59: 'semicolon', 60: 'less', 61: 'equal', 62: 'greater', 63: 'question', 64: 'at', 65: 'A', 66: 'B', 67: 'C', 68: 'D', 69: 'E', 70: 'F', 71: 'G', 72: 'H', 73: 'I', 74: 'J', 75: 'K', 76: 'L', 77: 'M', 78: 'N', 79: 'O', 80: 'P', 81: 'Q', 82: 'R', 83: 'S', 84: 'T', 85: 'U', 86: 'V', 87: 'W', 88: 'X', 89: 'Y', 90: 'Z', 91: 'bracketleft', 92: 'backslash', 93: 'bracketright', 94: 'asciicircum', 95: 'underscore', 96: 'grave', 97: 'a', 98: 'b', 99: 'c', 100: 'd', 101: 'e', 102: 'f', 103: 'g', 104: 'h', 105: 'i', 106: 'j', 107: 'k', 108: 'l', 109: 'm', 110: 'n', 111: 'o', 112: 'p', 113: 'q', 114: 'r', 115: 's', 116: 't', 117: 'u', 118: 'v', 119: 'w', 120: 'x', 121: 'y', 122: 'z', 123: 'braceleft', 124: 'bar', 125: 'braceright', 126: 'asciitilde', 161: 'exclamdown', 162: 'cent', 163: 'sterling', 164: 'fraction', 165: 'yen', 166: 'florin', 167: 'section', 168: 'currency', 169: 'quotesinglebase', 170: 'guillemotleft', 171: 'guilsinglleft', 172: 'guilsinglright', 173: 'fi', 174: 'fl', 175: 'endash', 176: 'dagger', 177: 'daggerdbl', 178: 'periodcentered', 179: 'paragraph', 180: 'bullet', 181: 'quotesinglbase', 182: 'quotedblbase', 183: 'quotedblleft', 184: 'quotedblright', 185: 'quoteleft', 186: 'quoteright', 187: 'divide', 188: 'trademark', 189: 'mu', 190: 'eth', 191: 'germandbls', 192: 'Ae', 193: 'Oe', 194: 'oe', 195: 'oslash', 196: 'ae', 197: 'thorn', 198: 'ydieresis'}
    STANDARD_ENCODING_CHARACTER_NAME_TO_CHARACTER_CODE = {v:k for k,v in STANDARD_ENCODING_CHARACTER_CODE_TO_CHARACTER_NAME.items()}
    # fmt: on

    # fmt: off
    SYMBOL_CHARACTER_CODE_TO_CHARACTER_NAME = {32: 'space', 33: 'exclam', 34: 'universal', 35: 'numbersign', 36: 'existential', 37: 'percent', 38: 'ampersand', 39: 'suchthat', 40: 'parenleft', 41: 'parenright', 42: 'asterisk', 43: 'plus', 44: 'comma', 45: 'hyphen', 46: 'period', 47: 'slash', 48: 'zero', 49: 'one', 50: 'two', 51: 'three', 52: 'four', 53: 'five', 54: 'six', 55: 'seven', 56: 'eight', 57: 'nine', 58: 'colon', 59: 'semicolon', 60: 'less', 61: 'equal', 62: 'greater', 63: 'question', 64: 'congruent', 65: 'Alpha', 66: 'Beta', 67: 'Chi', 68: 'Delta', 69: 'Epsilon', 70: 'Phi', 71: 'Gamma', 72: 'Eta', 73: 'Iota', 74: 'theta.math', 75: 'Kappa', 76: 'Lambda', 77: 'Mu', 78: 'Nu', 79: 'Omicron', 80: 'Pi', 81: 'Theta', 82: 'Rho', 83: 'Sigma', 84: 'Tau', 85: 'Upsilon', 86: 'finalsigma', 87: 'Omega', 88: 'Xi', 89: 'Psi', 90: 'Zeta', 91: 'bracketleft', 92: 'therefore', 93: 'bracketright', 94: 'tackup', 95: 'underscore', 96: 'overlinecmb', 97: 'alpha', 98: 'beta', 99: 'chi', 100: 'delta', 101: 'epsilon', 102: 'phi.math', 103: 'gamma', 104: 'eta', 105: 'iota', 106: 'phi', 107: 'kappa', 108: 'lambda', 109: 'mu', 110: 'nu', 111: 'omicron', 112: 'pi', 113: 'theta', 114: 'rho', 115: 'sigma', 116: 'tau', 117: 'upsilon', 118: 'pi.math', 119: 'omega', 120: 'xi', 121: 'psi', 122: 'zeta', 123: 'braceleft', 124: 'bar', 125: 'braceright', 126: 'asciitilde', 160: 'Euro', 161: 'Upsilonhooksymbol', 162: 'minute', 163: 'lessequal', 164: 'fraction', 165: 'infinity', 166: 'fhook', 167: 'clubblack', 168: 'misc:diamondblack', 169: 'heartblack', 170: 'spadeblack', 171: 'arrowleftright', 172: 'arrowleft', 173: 'arrowup', 174: 'arrowright', 175: 'arrowdown', 176: 'degree', 177: 'plusminus', 178: 'second', 179: 'greaterequal', 180: 'multiply', 181: 'proportional', 182: 'partialdiff', 183: 'bullet', 184: 'divide', 185: 'notequal', 186: 'equivalence', 187: 'approxequal', 188: 'ellipsis', 189: 'lightvert', 190: 'lighthorz', 191: 'arrowleftdowncorner', 192: 'aleph', 193: 'Ifraktur', 194: 'Rfraktur', 195: 'weierstrass', 196: 'circlemultiply', 197: 'circleplus', 198: 'emptyset', 199: 'intersection', 200: 'union', 201: 'propersuperset', 202: 'reflexsuperset', 203: 'notsubset', 204: 'propersubset', 205: 'reflexsubset', 206: 'element', 207: 'notelement', 208: 'angle', 209: 'gradient', 210: 'registered', 211: 'copyright', 212: 'trademark', 213: 'product', 214: 'radical', 215: 'dotmath', 216: 'logicalnot', 217: 'logicaland', 218: 'logicalor', 219: 'dblarrowleftright', 220: 'dblarrowleft', 221: 'dblarrowup', 222: 'dblarrowright', 223: 'dblarrowdown', 224: 'lozenge', 225: 'angleleft', 229: 'summation', 230: 'parenhookupleft', 231: 'parenextensionleft', 232: 'parenlowerhookleft', 233: 'bracketcornerupleftsquare', 234: 'bracketextensionleftsquare', 235: 'bracketlowercornerleftsquare', 236: 'brackethookupleftcurly', 237: 'bracketmiddlepieceleftcurly', 238: 'bracketlowerhookleftcurly', 239: 'bracketextensioncurly', 241: 'angleright', 242: 'integral', 243: 'integraltp', 244: 'integralextension', 245: 'integralbt', 246: 'parenhookupright', 247: 'parenextensionright', 248: 'parenlowerhookright', 249: 'bracketcorneruprightsquare', 250: 'bracketextensionrightsquare', 251: 'bracketlowercornerrightsquare', 252: 'brackethookuprightcurly', 253: 'bracketmiddlepiecerightcurly', 254: 'bracketlowerhookrightcurly'}
    SYMBOL_CHARACTER_NAME_TO_CHARACTER_CODE = {v:k for k,v in SYMBOL_CHARACTER_CODE_TO_CHARACTER_NAME.items()}
    # fmt: on

    # fmt: off
    WINANSI_CHARACTER_CODE_TO_CHARACTER_NAME = {32: 'space', 33: 'exclam', 34: 'quotedbl', 35: 'numbersign', 36: 'dollar', 37: 'percent', 38: 'ampersand', 39: 'quotesingle', 40: 'parenleft', 41: 'parenright', 42: 'asterisk', 43: 'plus', 44: 'comma', 45: 'hyphen', 46: 'period', 47: 'slash', 48: 'zero', 49: 'one', 50: 'two', 51: 'three', 52: 'four', 53: 'five', 54: 'six', 55: 'seven', 56: 'eight', 57: 'nine', 58: 'colon', 59: 'semicolon', 60: 'less', 61: 'equal', 62: 'greater', 63: 'question', 64: 'at', 65: 'A', 66: 'B', 67: 'C', 68: 'D', 69: 'E', 70: 'F', 71: 'G', 72: 'H', 73: 'I', 74: 'J', 75: 'K', 76: 'L', 77: 'M', 78: 'N', 79: 'O', 80: 'P', 81: 'Q', 82: 'R', 83: 'S', 84: 'T', 85: 'U', 86: 'V', 87: 'W', 88: 'X', 89: 'Y', 90: 'Z', 91: 'bracketleft', 92: 'backslash', 93: 'bracketright', 94: 'asciicircum', 95: 'underscore', 96: 'grave', 97: 'a', 98: 'b', 99: 'c', 100: 'd', 101: 'e', 102: 'f', 103: 'g', 104: 'h', 105: 'i', 106: 'j', 107: 'k', 108: 'l', 109: 'm', 110: 'n', 111: 'o', 112: 'p', 113: 'q', 114: 'r', 115: 's', 116: 't', 117: 'u', 118: 'v', 119: 'w', 120: 'x', 121: 'y', 122: 'z', 123: 'braceleft', 124: 'bar', 125: 'braceright', 126: 'asciitilde', 128: 'Euro', 130: 'quotesinglbase', 131: 'fhook', 132: 'quotedblbase', 133: 'ellipsis', 134: 'dagger', 135: 'daggerdbl', 136: 'circumflex', 137: 'perthousand', 138: 'Scaron', 139: 'guilsinglleft', 140: 'OE', 142: 'Zcaron', 145: 'quoteleft', 146: 'quoteright', 147: 'quotedblleft', 148: 'quotedblright', 149: 'bullet', 150: 'endash', 151: 'emdash', 152: 'tilde', 153: 'trademark', 154: 'scaron', 155: 'guilsinglright', 156: 'oe', 158: 'zcaron', 159: 'Ydieresis', 160: 'nbspace', 161: 'exclamdown', 162: 'cent', 163: 'sterling', 164: 'currency', 165: 'yen', 166: 'brokenbar', 167: 'section', 168: 'dieresis', 169: 'copyright', 170: 'ordfeminine', 171: 'guillemetleft', 172: 'logicalnot', 173: 'hyphensoft', 174: 'registered', 175: 'macron', 176: 'degree', 177: 'plusminus', 178: 'two.superior', 179: 'three.superior', 180: 'acute', 181: 'mu.math', 182: 'paragraph', 183: 'periodcentered', 184: 'cedilla', 185: 'one.superior', 186: 'ordmasculine', 187: 'guillemetright', 188: 'onequarter', 189: 'onehalf', 190: 'threequarters', 191: 'questiondown', 192: 'Agrave', 193: 'Aacute', 194: 'Acircumflex', 195: 'Atilde', 196: 'Adieresis', 197: 'Aring', 198: 'AE', 199: 'Ccedilla', 200: 'Egrave', 201: 'Eacute', 202: 'Ecircumflex', 203: 'Edieresis', 204: 'Igrave', 205: 'Iacute', 206: 'Icircumflex', 207: 'Idieresis', 208: 'Eth', 209: 'Ntilde', 210: 'Ograve', 211: 'Oacute', 212: 'Ocircumflex', 213: 'Otilde', 214: 'Odieresis', 215: 'multiply', 216: 'Oslash', 217: 'Ugrave', 218: 'Uacute', 219: 'Ucircumflex', 220: 'Udieresis', 221: 'Yacute', 222: 'Thorn', 223: 'germandbls', 224: 'agrave', 225: 'aacute', 226: 'acircumflex', 227: 'atilde', 228: 'adieresis', 229: 'aring', 230: 'ae', 231: 'ccedilla', 232: 'egrave', 233: 'eacute', 234: 'ecircumflex', 235: 'edieresis', 236: 'igrave', 237: 'iacute', 238: 'icircumflex', 239: 'idieresis', 240: 'eth', 241: 'ntilde', 242: 'ograve', 243: 'oacute', 244: 'ocircumflex', 245: 'otilde', 246: 'odieresis', 247: 'divide', 248: 'oslash', 249: 'ugrave', 250: 'uacute', 251: 'ucircumflex', 252: 'udieresis', 253: 'yacute', 254: 'thorn'}
    WINANSI_CHARACTER_NAME_TO_CHARACTER_CODE = {v:k for k,v in WINANSI_CHARACTER_CODE_TO_CHARACTER_NAME.items()}
    # fmt: on

    # fmt: off
    ZAPFDINGBATS_CHARACTER_CODE_TO_CHARACTER_NAME = {32: 'space', 33: 'scissorsupperblade', 34: 'scissorsblack', 35: 'scissorslowerblade', 36: 'scissorswhite', 37: 'telephoneblack', 38: 'telephonelocationsign', 39: 'tapedrive', 40: 'airplane', 41: 'envelope', 42: 'pointingindexrightblack', 43: 'pointingindexrightwhite', 44: 'hvictory', 45: 'hwriting', 46: 'pencillowerright', 47: 'pencil', 48: 'pencilupperright', 49: 'nibwhite', 50: 'nibblack', 51: 'check', 52: 'checkheavy', 53: 'multiplicationx', 54: 'multiplicationxheavy', 55: 'ballotx', 56: 'ballotxheavy', 57: 'greekcrossoutlined', 58: 'greekcrossheavy', 59: 'crosscentreopen', 60: 'crosscentreopenheavy', 61: 'latincross', 62: 'latincrossshadowedwhite', 63: 'latincrossoutlined', 64: 'maltesecross', 65: 'starofdavid', 66: 'asteriskteardropfour', 67: 'asteriskballoonfour', 68: 'asteriskballoonheavyfour', 69: 'asteriskclubfour', 70: 'starpointedblackfour', 71: 'starpointedwhitefour', 72: 'starblack', 73: 'staroutlinedstresswhite', 74: 'starcircledwhite', 75: 'starcentreopenblack', 76: 'starcentreblackwhite', 77: 'staroutlinedblack', 78: 'staroutlinedblackheavy', 79: 'starpinwheel', 80: 'starshadowedwhite', 81: 'asteriskheavy', 82: 'asteriskcentreopen', 83: 'spokedasteriskeight', 84: 'starpointedblackeight', 85: 'starpointedpinwheeleight', 86: 'starpointedblacksix', 87: 'compasstarpointedblackeight', 88: 'compasstarpointedblackheavyeight', 89: 'starpointedblacktwelve', 90: 'asteriskpointedsixteen', 91: 'asteriskteardrop', 92: 'asteriskteardropcentreopen', 93: 'asteriskteardropheavy', 94: 'florettepetalledblackwhitesix', 95: 'floretteblack', 96: 'florettewhite', 97: 'floretteoutlinedpetalledblackeight', 98: 'starcentreopenpointedcircledeight', 99: 'asteriskteardroppinwheelheavy', 100: 'snowflake', 101: 'snowflaketight', 102: 'chevronsnowflakeheavy', 103: 'sparkle', 104: 'sparkleheavy', 105: 'asteriskballoon', 106: 'asteriskteardroppropellereight', 107: 'asteriskteardroppropellerheavyeight', 108: 'circleblack', 109: 'circleshadowedwhite', 110: 'squareblack', 111: 'squareshadowlowerrightwhite', 112: 'squareshadowupperrightwhite', 113: 'squarelowerrightshadowedwhite', 114: 'squareupperrightshadowedwhite', 115: 'triangleupblack', 116: 'triangledownblack', 117: 'gmtr:diamondblack', 118: 'diamondminusxblackwhite', 119: 'halfcirclerightblack', 120: 'verticalbarlight', 121: 'verticalbarmedium', 122: 'verticalbarheavy', 123: 'commaheavyturnedornament', 124: 'commaheavyornament', 125: 'commaheavydoubleturnedornament', 126: 'commaheavydoubleornament', 161: 'curvedstemparagraphsignornament', 162: 'exclamationheavyornament', 163: 'heartexclamationheavyornament', 164: 'heartblackheavy', 165: 'heartbulletrotatedblackheavy', 166: 'floralheart', 167: 'floralheartbulletrotated', 168: 'clubblack', 169: 'misc:diamondblack', 170: 'heartblack', 171: 'spadeblack', 172: 'onecircle', 173: 'twocircle', 174: 'threecircle', 175: 'fourcircle', 176: 'fivecircle', 177: 'sixcircle', 178: 'sevencircle', 179: 'eightcircle', 180: 'ninecircle', 181: 'tencircle', 182: 'onenegativecircled', 183: 'twonegativecircled', 184: 'threenegativecircled', 185: 'fournegativecircled', 186: 'fivenegativecircled', 187: 'sixnegativecircled', 188: 'sevennegativecircled', 189: 'eightnegativecircled', 190: 'ninenegativecircled', 191: 'tennegativecircled', 192: 'onesanscircled', 193: 'twosanscircled', 194: 'threesanscircled', 195: 'foursanscircled', 196: 'fivesanscircled', 197: 'sixsanscircled', 198: 'sevensanscircled', 199: 'eightsanscircled', 200: 'ninesanscircled', 201: 'tensanscircled', 202: 'onesansnegativecircled', 203: 'twosansnegativecircled', 204: 'threesansnegativecircled', 205: 'foursansnegativecircled', 206: 'fivesansnegativecircled', 207: 'sixsansnegativecircled', 208: 'sevensansnegativecircled', 209: 'eightsansnegativecircled', 210: 'ninesansnegativecircled', 211: 'tensansnegativecircled', 212: 'arrowrightwideheavy', 213: 'arrowright', 214: 'arrowleftright', 215: 'arrowupdown', 216: 'arrowheavySE', 217: 'arrowrightheavy', 218: 'arrowheavyNE', 219: 'arrowrightpointed', 220: 'arrowrightroundheavy', 221: 'arrowrighttriangle', 222: 'arrowrighttriangleheavy', 223: 'arrowrighttriangledashed', 224: 'arrowrighttriangledashedheavy', 225: 'arrowrightblack', 226: 'arrowheadrightthreeDtoplight', 227: 'arrowheadrightthreeDbottomlight', 228: 'arrowheadrightblack', 229: 'arrowrightcurvedownblackheavy', 230: 'arrowrightcurveupblackheavy', 231: 'arrowrightsquatblack', 232: 'arrowrightpointedblackheavy', 233: 'arrowrightrightshadedwhite', 234: 'arrowrightleftshadedwhite', 235: 'arrowrightbacktiltedshadowedwhite', 236: 'arrowrightfronttiltedshadowedwhite', 237: 'arrowshadowrightlowerwhiteheavy', 238: 'arrowshadowrightupperwhiteheavy', 239: 'arrowshadowrightnotchedlowerwhite', 241: 'arrowshadowrightnotchedupperwhite', 242: 'arrowrightcircledwhiteheavy', 243: 'arrowrightfeatheredwhite', 244: 'arrowfeatheredblackSE', 245: 'arrowrightfeatheredblack', 246: 'arrowfeatheredblackNE', 247: 'arrowfeatheredblackheavySE', 248: 'arrowrightfeatheredblackheavy', 249: 'arrowfeatheredblackheavyNE', 250: 'arrowteardropright', 251: 'arrowteardroprightheavy', 252: 'arrowrightwedge', 253: 'arrowrightwedgeheavy', 254: 'arrowrightoutlinedopen'}
    ZAPFDINGBATS_CHARACTER_NAME_TO_CHARACTER_CODE = {v:k for k,v in ZAPFDINGBATS_CHARACTER_CODE_TO_CHARACTER_NAME.items()}
    # fmt: on
